import re
import math
import numpy as np
from itertools import chain
from collections import Counter
import nltk
from nltk.util import ngrams # This is the ngram magic.
from textblob import TextBlob
import pandas as pd

NGRAM = 2

re_sent_ends_naive = re.compile(r'[.\n]')
re_stripper_alpha = re.compile('[^a-zA-Z]+')
re_stripper_naive = re.compile('[^a-zA-Z\.\n]')

splitter_naive = lambda x: re_sent_ends_naive.split(re_stripper_naive.sub(' ', x))

def get_tuples_nosentences(txt):
    """Get tuples that ignores all punctuation (including sentences)."""
    if not txt: return None
    ng = ngrams(re_stripper_alpha.sub(' ', txt).split(), NGRAM)
    return list(ng)

def cosine_similarity_ngrams(a, b):
    a = get_tuples_nosentences(a)
    b = get_tuples_nosentences(b)
    vec1 = Counter(a)
    vec2 = Counter(b)
    
    intersection = set(vec1.keys()) & set(vec2.keys())
    numerator = sum([vec1[x] * vec2[x] for x in intersection])
    sum1 = sum([vec1[x]**2 for x in vec1.keys()])
    sum2 = sum([vec2[x]**2 for x in vec2.keys()])
    denominator = math.sqrt(sum1) * math.sqrt(sum2)

    if not denominator:
        return 0.0
    return float(numerator) / denominator

def get_unitids(dataframe):
    dta = dataframe
    dictionary = {'unitid': {'A T Still University of Health Sciences': 177834, 'Aaniiih Nakoda College': 180203, 'ABC Adult School': 491464, 'ABC Beauty Academy': 459523, 'ABCO Technology': 485500, 'Abcott Institute': 461892, 'Abilene Christian University': 222178, 'Abraham Baldwin Agricultural College': 138558, 'Abraham Lincoln University': 488031, 'Academia Serrant Inc': 421896, 'Academy College': 172866, 'Academy Di Capelli-School of Cosmetology': 449463, 'Academy di Firenze': 476957, 'Academy for Careers and Technology': 457989, 'Academy for Five Element Acupuncture': 451079, 'Academy for Jewish Religion-California': 457271, 'Academy for Nursing and Health Occupations': 412173, 'Academy for Salon Professionals': 462062, 'Academy of Art University': 108232, 'Academy of Career Training': 451097, 'Academy of Careers and Technology': 237729, 'Academy of Chinese Culture and Health Sciences': 108269, 'Academy of Cosmetology': 179991, 'Academy of Cosmetology and Esthetics': 488165, 'Academy of Cosmetology and Esthetics NYC': 457855, 'Academy of Esthetics and Cosmetology': 454722, 'Academy of Hair Design-Beaumont': 434283, 'Academy of Hair Design-Grenada': 175722, 'Academy of Hair Design-Jackson': 374316, 'Academy of Hair Design-Jasper': 447449, 'Academy of Hair Design-Las Vegas': 181880, 'Academy of Hair Design-Lufkin': 434274, 'Academy of Hair Design-Oklahoma City': 455929, 'Academy of Hair Design-Pearl': 382461, 'Academy of Hair Design-Springfield': 451334, 'Academy of Hair Technology': 376446, 'Academy of Interactive Entertainment': 487658, 'Academy of Massage and Bodywork': 451051, 'Academy of Natural Therapy Inc': 449454, 'Academy of Professional Cosmetology': 486619, 'Academy of Salon and Spa': 107293, 'Academy of Salon Professionals': 480879, 'Academy of Vocal Arts': 210508, 'Acaydia School of Aesthetics': 461342, 'Access Careers': 483708, 'Access Careers-Islandia': 494904, 'Ace Cosmetology and Barber Training Center': 480736, 'Ace Institute of Technology': 449676, 'Acupuncture and Integrative Medicine College-Berkeley': 384306, 'Acupuncture and Massage College': 439969, 'Adams State University': 126182, 'Adelphi University': 188429, 'Adirondack Community College': 188438, 'Adler Graduate School': 374024, 'Adler University': 142832, 'Adrian College': 168528, "Adrian's College of Beauty Turlock": 262369, 'Adult and Community Education-Hudson': 203030, 'Adult and Continuing Education-BCTS': 183983, 'Advance Beauty College': 400187, 'Advance Beauty Techs Academy': 479974, 'Advance Science International College': 444334, 'Advanced Barber College and Hair Design': 437608, 'Advanced Beauty College': 458052, 'Advanced Career Institute': 480019, 'Advanced College': 444343, 'Advanced College of Cosmetology': 461786, 'Advanced College-Stockton': 491163, 'Advanced Technology Institute': 231411, 'Advanced Training Associates': 444361, 'Advanced Training Institute': 461430, 'Advanced Welding Institute': 456001, 'Advantage Career Institute': 490896, 'Advantage Technical College': 423397, 'AdventHealth University': 133872, 'Aesthetic Science Institute': 476878, 'Agnes Scott College': 138600, 'AI Miami International University of Art and Design': 134811, 'Aiken School of Cosmetology and Barbering': 457998, 'Aiken Technical College': 217615, 'Aims Community College': 126207, 'Air Force Institute of Technology-Graduate School of Engineering & Management': 200697, 'Alabama A & M University': 100654, 'Alabama College of Osteopathic Medicine': 483975, 'Alabama School of Nail Technology & Cosmetology': 488916, 'Alabama State College of Barber Styling': 371034, 'Alabama State University': 100724, 'Alamance Community College': 199786, 'Alamo City Barber College': 482981, 'Alamo Community College District Central Office': 222497, 'Alaska Bible College': 102580, 'Alaska Career College': 103501, 'Alaska Christian College': 442523, 'Alaska Pacific University': 102669, 'Alaska Vocational Technical Center': 102711, 'Albany BOCES-Adult Practical Nursing Program': 418038, 'Albany College of Pharmacy and Health Sciences': 188526, 'Albany Law School': 188535, 'Albany Medical College': 188580, 'Albany State University': 138716, 'Albany Technical College': 138682, 'Albert Einstein College of Medicine': 385415, 'Albertus Magnus College': 128498, 'Albion College': 168546, 'Albright College': 210571, 'Alcorn State University': 175342, 'Alderson Broaddus University': 237118, 'Alexander Academy': 476735, 'Alexander Paul Institute of Hair Design': 483425, 'Alexandria School of Scientific Therapeutics': 368036, 'Alexandria Technical & Community College': 172918, 'Alfred University': 188641, 'Alhambra Beauty College': 393524, 'Alhambra Medical University': 487995, 'Alice Lloyd College': 156189, 'All Beauty College': 459125, 'All-State Career School': 210599, 'All-State Career School-Health Sciences': 474997, 'All-State Career School-Pittsburgh': 418658, 'All-State Career-Baltimore': 373784, 'Allan Hancock College': 108807, 'Allegany College of Maryland': 161688, 'Allegheny College': 210669, 'Allegheny Wesleyan College': 200873, 'Allen College': 152798, 'Allen County Community College': 154642, 'Allen School-Brooklyn': 188650, 'Allen School-Jamaica': 415987, 'Allen School-Phoenix': 469610, 'Allen University': 217624, 'Allgood Beauty Institute': 490522, 'Alliance Career Center': 369109, 'Alliance Computing Solutions': 483850, 'Alliant International University-San Diego': 110468, 'Allied Health Careers Institute': 490151, 'Allstate Hairstyling & Barber College': 461111, 'Alma College': 168591, 'Alpena Community College': 168607, 'Altierus Career College-Bissonnet': 445461, 'Altierus Career College-Norcross': 443748, 'Altierus Career College-Tampa': 137801, 'Altierus Career College-Thornton': 127787, 'Altoona Beauty School Inc': 210748, 'Alvernia University': 210775, 'Alverno College': 238193, 'Alvin Community College': 222567, 'Amarillo College': 222576, 'Amberton University': 222628, 'Ambiance Beauty & Barber Academy Inc': 476771, 'Ambria College of Nursing': 457527, 'America Evangelical University': 490081, 'American Academy McAllister Institute of Funeral Service': 188687, 'American Academy of Acupuncture and Oriental Medicine': 446002, 'American Academy of Art': 142887, 'American Academy of Cosmetology': 457396, 'American Academy of Dramatic Arts-Los Angeles': 108852, 'American Academy of Dramatic Arts-New York': 188678, 'American Academy of Health and Beauty': 461290, 'American Advanced Technicians Institute': 444370, 'American Baptist College': 219505, 'American Baptist Seminary of the West': 108861, 'American Barber Academy': 490258, 'American Beauty Academy': 459541, 'American Beauty Academy-West Valley Campus': 489247, 'American Beauty College': 108977, 'American Beauty School': 189477, 'American Beauty Schools': 490391, 'American Business and Technology University': 457688, 'American Career College-Anaheim': 441052, 'American Career College-Los Angeles': 109040, 'American Career College-Ontario': 447768, 'American College for Medical Careers': 461005, 'American College of Acupuncture and Oriental Med': 429085, 'American College of Barbering': 486169, 'American College of Education': 449889, 'American College of Financial Services': 210809, 'American College of Hair Design Inc': 179229, 'American College of Hairstyling-Des Moines': 153588, 'American College of Healthcare and Technology': 483009, 'American College of Healthcare Sciences': 443599, 'American College of the Building Arts': 485698, 'American Conservatory Theater': 109086, 'American Educational College': 241146, 'American Film Institute Conservatory': 108870, 'American Fitness and Nutrition Academy': 493503, 'American Hair Academy': 153463, 'American Indian OIC Inc': 172927, 'American Institute of Alternative Medicine': 487852, 'American Institute of Beauty': 447883, 'American Institute of Healthcare & Technology': 493682, 'American Institute of Interior Design': 404037, 'American Institute of Massage Therapy': 447795, 'American Institute of Medical Sciences & Education': 455202, 'American Institute of Medical Technology': 449728, 'American Institute-Clifton': 184092, 'American Institute-Somerset': 490869, 'American Institute-Toms River': 482963, 'American Institute-West Hartford': 129482, 'American InterContinental University': 445027, 'American InterContinental University-Atlanta': 438586, 'American InterContinental University-Houston': 445133, 'American International College': 164447, 'American Islamic College': 142957, 'American Jewish University': 116846, 'American Massage & Bodywork Institute': 492643, 'American Medical Academy': 475714, 'American Medical Sciences Center': 461263, 'American Musical and Dramatic Academy': 188854, 'American National University': 232797, 'American National University-Dayton': 453455, 'American National University-Lexington': 157021, 'American Public University System': 449339, 'American River College': 109208, 'American Samoa Community College': 240736, 'American School of Nursing and Medical Careers': 460570, 'American Sentinel University': 460738, 'American Technical Institute': 461625, 'American Trade School': 461573, 'American University': 131159, 'American University of Health Sciences': 433004, 'American University of Puerto Rico': 241100, 'AmeriTech College-Draper': 447263, 'AmeriTech College-Provo': 229957, 'AMG School of Licensed Practical Nursing': 486415, 'Amherst College': 164465, 'Amridge University': 100690, 'Amslee Institute': 492032, 'Anabaptist Mennonite Biblical Seminary': 151865, 'Ancilla College': 150048, 'Anderson University': 217633, 'Andover Newton Theological School': 164474, 'Andrew College': 138761, 'Andrews University': 168740, 'Angeles College': 457299, 'Angeles Institute': 457314, 'Angelina College': 222822, 'Angelo State University': 222831, 'Ann Webb Skin Institute': 490425, 'Anna Maria College': 164492, 'Anne Arundel Community College': 161767, 'Annenberg School of Nursing': 475705, 'Anoka Technical College': 172954, 'Anoka-Ramsey Community College': 172963, 'Another Level Barbering and Cosmetology School': 491978, 'Anousheh School of Hair': 491969, 'Anson College of Cosmetology': 434292, 'Antelope Valley College': 109350, 'Antilles School of Technical Careers': 241182, 'Antioch College': 483018, 'Antioch University Online': 485908, 'Antioch University-Los Angeles': 245838, 'Antioch University-Midwest': 245892, 'Antioch University-New England': 245865, 'Antioch University-PhD Program in Leadership and Change': 442392, 'Antioch University-Santa Barbara': 245847, 'Antioch University-Seattle': 245883, 'Antioch University-System Administration': 440138, 'Antonelli College-Cincinnati': 201016, 'Antonelli College-Hattiesburg': 383950, 'Antonelli College-Jackson': 175528, 'AOMA Graduate School of Integrative Medicine': 429094, 'Aparicio-Levy Technical College': 485342, 'Apex Academy Hair Skin Nails School of Cosmetology': 490434, 'Apex School of Theology': 441511, 'Apex Technical School': 188890, 'Apollo Career Center': 201034, 'Appalachian Beauty School': 237127, 'Appalachian Bible College': 237136, 'Appalachian College of Pharmacy': 449922, 'Appalachian School of Law': 432348, 'Appalachian State University': 197869, 'Applied Technology Services': 417716, 'Aquinas College': 168786, 'Aquinas Institute of Theology': 176600, 'Arapahoe Community College': 126289, 'Arcadia University': 211088, 'Arclabs': 487791, 'Aria Health School of Nursing': 212568, 'Arizona Academy of Beauty-East': 103954, 'Arizona Board of Regents': 420802, 'Arizona Christian University': 105899, 'Arizona College-Dallas': 494162, 'Arizona College-Glendale': 421708, 'Arizona College-Las Vegas': 487375, 'Arizona College-Mesa': 482990, 'Arizona College-Tempe': 494171, 'Arizona Culinary Institute': 450951, 'Arizona School of Acupuncture and Oriental Medicine': 446039, 'Arizona School of Integrative Studies': 484163, 'Arizona State University-Downtown Phoenix': 448886, 'Arizona State University-Polytechnic': 420574, 'Arizona State University-Skysong': 483124, 'Arizona State University-Tempe': 104151, 'Arizona State University-West': 407009, 'Arizona Western College': 104160, 'Arkansas Baptist College': 106306, 'Arkansas Beauty College': 106324, 'Arkansas Beauty School-Little Rock': 106315, 'Arkansas College of Barbering and Hair Design': 106351, 'Arkansas Colleges of Health Education': 488527, 'Arkansas Northeastern College': 107327, 'Arkansas State University Mid-South': 107318, 'Arkansas State University System': 448336, 'Arkansas State University Three Rivers': 107521, 'Arkansas State University-Beebe': 106449, 'Arkansas State University-Main Campus': 106458, 'Arkansas State University-Mountain Home': 420538, 'Arkansas State University-Newport': 440402, 'Arkansas Tech University': 106467, 'Arkansas Welding Academy': 491075, 'Arlington Baptist University': 222877, 'Arlington Career Institute': 222886, 'Arnolds Beauty School': 219587, 'Arnot Ogden Medical Center': 188915, 'Arrojo Cosmetology School': 482194, 'Art Academy of Cincinnati': 201061, 'Art Center College of Design': 109651, "Arthur's Beauty College Inc-Fort Smith": 106360, "Arthur's Beauty College Inc-Jacksonville": 106494, "Arthur's Beauty College-Jonesboro": 489830, "Arthur's Beauty School Inc-Conway": 445540, 'Artistic Academy of Hair Design': 414063, 'Artistic Nails and Beauty Academy-Lakeland': 460701, 'Artistic Nails and Beauty Academy-Tampa': 378886, 'ASA College': 404994, 'Asbury Theological Seminary': 156222, 'Asbury University': 156213, 'Asher College': 447777, 'Asheville-Buncombe Technical Community College': 197887, 'Ashford University': 154022, 'Ashland Community and Technical College': 156231, 'Ashland County-West Holmes Career Center': 201098, 'Ashland University': 201104, 'Ashtabula County Technical and Career Campus': 201131, 'ASI Career Institute': 475431, 'Asian-American International Beauty College': 393861, 'ASM Beauty World Academy': 391546, 'Asnuntuck Community College': 128577, 'Aspen Beauty Academy of Laurel': 480994, 'Aspen University': 454829, 'Assabet Valley Regional Technical School': 164535, 'Associated Barber College of San Diego': 485494, 'Associated Beth Rivkah Schools': 188942, 'Associated Technical College-Los Angeles': 109721, 'Associated Technical College-San Diego': 109730, 'Assumption College': 164562, 'Assumption College for Sisters': 183600, 'Astrodome Career Centers': 379746, 'ATA Career Education': 446127, 'ATA College': 447935, 'ATA College - Cincinnati': 452373, 'Atelier Esthetique Institute of Esthetics': 461768, 'Atenas College': 440651, 'Athena Career Academy': 476683, 'Athenaeum of Ohio': 201140, 'Athens State University': 100812, 'Athens Technical College': 246813, 'ATI College-Norwalk': 444325, 'Atlanta Institute of Music and Media': 419244, 'Atlanta Metropolitan State College': 138901, 'Atlanta School of Massage': 138938, 'Atlanta Technical College': 138840, "Atlanta's John Marshall Law School": 138929, 'Atlantic Beauty & Spa Academy LLC': 186593, 'Atlantic Cape Community College': 183655, 'Atlantic Institute of Oriental Medicine': 439446, 'Atlantic Technical College': 132374, 'Atlantic University College': 241216, 'Atlantis University': 485768, 'Auburn Career Center': 201159, 'Auburn University': 100858, 'Auburn University at Montgomery': 100830, 'Augsburg University': 173045, 'Augusta School of Massage': 447917, 'Augusta Technical College': 138956, 'Augusta University': 482149, 'Augustana College': 143084, 'Augustana University': 219000, 'Auguste Escoffier School of Culinary Arts-Austin': 444556, 'Auguste Escoffier School of Culinary Arts-Boulder': 454810, 'Aultman College of Nursing and Health Sciences': 201177, 'Aurora University': 143118, 'Austin College': 222983, 'Austin Community College District': 222992, 'Austin Graduate School of Theology': 247825, 'Austin Kade Academy': 476869, 'Austin Peay State University': 219602, 'Austin Presbyterian Theological Seminary': 223001, "Austin's Beauty College Inc": 219851, 'Automeca Technical College-Aguadilla': 418782, 'Automeca Technical College-Bayamon': 419703, 'Automeca Technical College-Caguas': 419712, 'Automeca Technical College-Ponce': 419721, 'Automotive Training Center-Exton': 211006, 'Automotive Training Center-Warminster': 448770, 'Autry Technology Center': 365213, 'Avalon School of Cosmetology': 457679, 'Avalon School of Cosmetology-Alameda': 108649, 'Avalon School of Cosmetology-Aurora': 372356, 'Avalon School of Cosmetology-Layton': 474924, 'Avalon School of Cosmetology-Mesa': 104568, 'Avalon School of Cosmetology-Phoenix': 474915, 'Ave Maria School of Law': 442295, 'Ave Maria University': 446048, 'Aveda Arts & Sciences Institute-Baton Rouge': 159513, 'Aveda Arts & Sciences Institute-Covington': 160320, 'Aveda Arts & Sciences Institute-Lafayette': 159522, 'Aveda Arts & Sciences Institute-San Antonio': 455354, "Aveda Fredric's Institute-Cincinnati": 451468, "Aveda Fredric's Institute-Indianapolis": 457563, 'Aveda Institute Portland-Vancouver Campus': 487348, 'Aveda Institute-Boise': 461652, 'Aveda Institute-Chapel Hill': 455141, 'Aveda Institute-Chicago': 455877, 'Aveda Institute-Columbus': 455275, 'Aveda Institute-Denver': 459277, 'Aveda Institute-Des Moines': 475015, 'Aveda Institute-Los Angeles': 469957, 'Aveda Institute-Madison': 487506, 'Aveda Institute-Maryland': 162830, 'Aveda Institute-Minneapolis': 173744, 'Aveda Institute-New Mexico': 461555, 'Aveda Institute-New York': 448071, 'Aveda Institute-Phoenix': 484899, 'Aveda Institute-Portland': 460862, 'Aveda Institute-Provo': 451574, 'Aveda Institute-South Florida': 451149, 'Aveda Institute-Tallahassee': 451158, 'Aveda Institute-Tucson': 476753, 'Aveda Institute-Twin Falls': 142407, 'Avenue Academy  A Cosmetology Institute': 491826, 'Avenue Five Institute': 458070, 'Avenue Five Institute-South Austin Campus': 494524, 'Avera McKennan Hospital School of Radiologic Technology': 219170, 'Avera Sacred Heart Hospital': 219338, 'Averett University': 231420, 'Averett University-Non-Traditional Programs': 449931, 'Avery James School of Cosmetology': 158778, 'Avi Career Training': 448257, 'Aviation Institute of Maintenance': 486558, 'Aviation Institute of Maintenance-Atlanta': 440059, 'Aviation Institute of Maintenance-Charlotte': 494764, 'Aviation Institute of Maintenance-Chesapeake': 427973, 'Aviation Institute of Maintenance-Dallas': 441788, 'Aviation Institute of Maintenance-Houston': 227748, 'Aviation Institute of Maintenance-Indianapolis': 438735, 'Aviation Institute of Maintenance-Kansas City': 441496, 'Aviation Institute of Maintenance-Las Vegas': 482255, 'Aviation Institute of Maintenance-Manassas': 445762, 'Aviation Institute of Maintenance-Orlando': 457411, 'Aviation Institute of Maintenance-Philadelphia': 250285, 'Aviator College of Aeronautical Science and Technology': 447847, 'Avila University': 176628, 'Award Beauty School': 161800, 'Ayers Career College': 158246, 'Azusa Pacific University': 109785, 'B M Spurr School of Practical Nursing': 237145, 'B-Unique Beauty and Barber Academy': 487898, 'Babson College': 164580, 'Bacone College': 206817, 'Bais Binyomin Academy': 128586, 'Bais HaMedrash and Mesivta of Baltimore': 476601, 'Bais Medrash Elyon': 245777, 'Bais Medrash Mayan Hatorah': 490513, 'Bais Medrash Toras Chesed': 449658, 'Baker College': 168847, 'Baker University': 154688, 'Bakersfield College': 109819, 'Bakke Graduate University': 420705, 'Baldwin Beauty School-North Austin': 414489, 'Baldwin Beauty School-South Austin': 223056, 'Baldwin Park Adult & Community Education': 417105, 'Baldwin Wallace University': 201195, 'Baldy View Regional Occupational Program': 490212, 'Ball State University': 150136, 'Baltimore City Community College': 161864, 'Baltimore Studio of Hair Design': 161855, 'Bancroft School of Massage Therapy': 164599, 'Bank Street College of Education': 189015, 'Baptist Bible College': 176664, 'Baptist Health College Little Rock': 106546, 'Baptist Health System School of Health Professions': 223083, 'Baptist Memorial College of Health Sciences': 219639, 'Baptist Missionary Association Theological Seminary': 223117, 'Baptist Theological Seminary at Richmond': 366793, 'Baptist University of the Americas': 444398, 'Barber & Beauty Institute of New York': 476610, 'Barber Institute of Texas': 484048, 'Barber School of Pittsburgh': 483054, 'Barber Tech Academy': 488022, 'Barclay College': 155070, 'Bard College': 189088, "Bard College at Simon's Rock": 167792, 'Barnard College': 189097, 'Barnes-Jewish College Goldfarb School of Nursing': 177719, 'Barrett and Company School of Hair Design': 156277, 'Barry University': 132471, 'Barstow Community College': 109907, 'Barton College': 197911, 'Barton County Community College': 154697, 'Bastyr University': 235547, 'Bates College': 160977, 'Bates Technical College': 235671, 'Baton Rouge Community College': 437103, 'Baton Rouge General Medical Center-School of Nursing': 158325, 'Baton Rouge School of Computers': 158343, 'Bay Area Medical Academy': 483878, 'Bay de Noc Community College': 168883, 'Bay Mills Community College': 380359, 'Bay Path University': 164632, 'Bay State College': 164641, 'Bay State School of Technology': 164678, 'Bayamon Community College': 444194, 'Baylor College of Medicine': 223223, 'Baylor University': 223232, 'Bayshire Academy of Beauty Craft Inc': 168892, "Be'er Yaakov Talmudic Seminary": 476717, 'Beacon College': 384254, 'Beal College': 160995, 'Beau Monde Academy of Cosmetology': 485166, 'Beaufort County Community College': 197966, 'Beaumont Adult School': 449357, 'Beauty Academy of South Florida': 460969, 'Beauty School of Middletown': 374927, 'Beauty Schools of America-Hialeah': 419660, 'Beauty Schools of America-Homestead': 456861, 'Beauty Schools of America-Miami': 135771, 'Beauty Schools of America-North Miami Beach': 450182, 'Beauty Technical College Inc': 207272, 'Beaver Falls Beauty Academy': 215336, 'Becker College': 164720, 'Beckfield College-Florence': 247065, 'Beis Medrash Heichal Dovid': 444413, 'Bel-Rea Institute of Animal Technology': 126359, 'Belanger School of Nursing': 190956, 'Belhaven University': 175421, 'Bell Mar Beauty College': 364760, 'Bella Academy of Cosmetology': 486309, 'Bella Capelli Academy': 461193, 'Bella Cosmetology College': 483559, 'Bellarmine University': 156286, 'Bellasa Professional Institute': 493567, 'Belle Academy of Cosmetology LLC': 481571, 'Bellevue College': 234669, 'Bellevue University': 180814, 'Bellin College': 238324, 'Bellingham Technical College': 234696, 'Bellus Academy': 478953, 'Bellus Academy-Chula Vista': 109934, 'Bellus Academy-El Cajon': 116563, 'Bellus Academy-Poway': 377722, 'Belmont Abbey College': 197984, 'Belmont College': 201283, 'Belmont University': 219709, 'Beloit College': 238333, 'Bemidji State University': 173124, 'Ben Franklin Career Center': 237172, "Bene's Career Academy": 137591, 'Benedict College': 217721, 'Benedictine College': 154712, 'Benedictine University': 145619, 'Benjamin Franklin Institute of Technology': 165884, 'Bennett Career Institute': 439473, 'Bennett College': 197993, 'Bennington College': 230816, 'Bentley University': 164739, 'Berea College': 156295, 'Bergen Community College': 183743, 'Bergin University of Canine Studies': 461643, 'Berk Trade and Business School': 189219, 'Berkeley City College': 125170, 'Berkeley College-New York': 189228, 'Berkeley College-Woodland Park': 183789, 'Berklee College of Music': 164748, 'Berkowits School of Electrolysis': 189255, 'Berks Career & Technology Center': 481021, 'Berkshire Community College': 164775, 'Berry College': 139144, 'Best Care College': 461865, 'Bet Medrash Gadol Ateret Torah': 485999, 'Beth Hamedrash Shaarei Yosher Institute': 189273, 'Beth Hatalmud Rabbinical College': 189264, 'Beth Medrash Govoha': 183804, 'Beth Medrash Meor Yitzchok': 486196, 'Beth Medrash of Asbury Park': 488314, 'Bethany College': 154721, 'Bethany Global University': 486284, 'Bethany Lutheran College': 173142, 'Bethany Theological Seminary': 143233, 'Bethel College': 458113, 'Bethel College-North Newton': 154749, 'Bethel Seminary-San Diego': 262022, 'Bethel Seminary-St Paul': 173179, 'Bethel University': 173160, 'Bethesda University': 110060, 'Bethlehem College & Seminary': 486053, 'Bethune-Cookman University': 132602, 'Beulah Heights University': 139153, 'Beverly Hills Design Institute': 475635, 'Bevill State Community College': 102429, 'Bexley Hall Seabury Western Theological Seminary Federation  Inc.': 443702, 'Beyond 21st Century Beauty Academy': 457253, 'Beyond Measure Barbering Institute': 484020, 'Beyond The Basics School of Cosmetology': 487870, 'Bidwell Training Center Inc': 211149, 'Big Bend Community College': 234711, 'Big Bend Technical College': 137856, 'Big Sandy Community and Technical College': 157553, 'Binghamton University': 196079, 'Biola University': 110097, 'Birmingham-Southern College': 100937, 'Birthingway College of Midwifery': 442949, 'Birthwise Midwifery School': 442213, 'Bishop State Community College': 102030, 'Bismarck State College': 200022, 'Bitterroot School of Cosmetology': 457721, "BJ's Beauty & Barber College": 236018, 'BK Cosmo College of Cosmetology': 224013, 'Black Hawk College': 143279, 'Black Hills Beauty College': 219037, 'Black Hills State University': 219046, 'Black River Technical College': 106625, 'Blackburn College': 143288, 'Blackfeet Community College': 180054, 'Blackhawk Technical College': 238397, 'Blackstone Valley Vocational Regional School District': 457615, 'Bladen Community College': 198011, 'Blades School of Hair Design': 366438, 'Blake Austin College': 447810, "Blalock's Professional Beauty College": 373456, 'Blessing Hospital School of Medical Laboratory Technology': 433165, 'Blessing Hospital School of Radiologic Technology': 143303, 'Blessing Rieman College of Nursing and Health Sciences': 143297, 'Blinn College': 223427, 'Bloomfield College': 183822, 'Bloomsburg University of Pennsylvania': 211158, 'Blue Cliff Career College': 444440, 'Blue Cliff College-Alexandria': 450128, 'Blue Cliff College-Fayetteville': 450119, 'Blue Cliff College-Gulfport': 441502, 'Blue Cliff College-Houma': 450021, 'Blue Cliff College-Lafayette': 439491, 'Blue Cliff College-Metairie': 434821, 'Blue Cliff College-Shreveport': 439482, 'Blue Hills Regional Technical School': 243799, 'Blue Mountain College': 175430, 'Blue Mountain Community College': 208275, 'Blue Ridge Community and Technical College': 446774, 'Blue Ridge Community College': 231536, 'Bluefield College': 231554, 'Bluefield State College': 237215, 'Bluegrass Community and Technical College': 156392, 'Bluffton University': 201371, 'Blush School of Makeup': 491482, 'Bnos Zion Of Bobov Seminary': 491446, 'Board of Trustees-Mississippi State Institutions of Higher Learning': 175999, 'Bob Jones University': 217749, 'Boca Beauty Academy': 481483, 'Boca Beauty Academy-Parkland': 489238, 'Boise Barber College': 476850, 'Boise Bible College': 142090, 'Boise State University': 142115, 'Bold Beauty Academy': 444316, 'Bolivar Technical College': 490203, 'Bon Secours Memorial College of Nursing': 233356, "Bon Secours St Mary's Hospital School of Medical Imaging": 233480, 'Bonnie Joseph Academy of Cosmetology & Barbering': 481456, 'Boricua College': 189413, "Borner's Barber College": 454759, "Bos-Man's Barber College": 483948, 'Bossier Parish Community College': 158431, 'Boston Architectural College': 164872, 'Boston Baptist College': 164614, 'Boston College': 164924, 'Boston Graduate School of Psychoanalysis Inc': 164915, 'Boston University': 164988, 'Bowdoin College': 161004, 'Bowie State University': 162007, 'Bowling Green State University-Firelands': 201432, 'Bowling Green State University-Main Campus': 201441, 'Bradford School': 202161, 'Bradley University': 143358, 'Brand College': 479992, 'Brandeis University': 165015, 'Brandman University': 262086, 'Branford Academy of Hair and Cosmetology': 451042, 'Branford Hall Career Institute-Albany Campus': 448974, 'Branford Hall Career Institute-Amityville': 484385, 'Branford Hall Career Institute-Bohemia Campus': 195933, 'Branford Hall Career Institute-Branford Campus': 128674, 'Branford Hall Career Institute-Jersey City': 249140, 'Branford Hall Career Institute-Parsippany': 184047, 'Branford Hall Career Institute-Southington Campus': 434520, 'Branford Hall Career Institute-Springfield Campus': 438805, 'Brazosport College': 223506, 'Brenau University': 139199, 'Brescia University': 156356, 'Brevard College': 198066, 'Brewster Technical College': 367875, 'Brewton-Parker College': 139205, 'Briar Cliff University': 152992, 'Bridgerland Technical College': 230010, 'BridgeValley Community & Technical College': 484932, 'Bridgewater College': 231581, 'Bridgewater State University': 165024, 'Brigham Young University-Hawaii': 230047, 'Brigham Young University-Idaho': 142522, 'Brigham Young University-Provo': 230038, "Brighton Center's Center for Employment Training": 442976, 'Brighton Institute of Cosmetology': 477002, 'Bristol Community College': 165033, 'Bristol School of Hair Design': 493530, 'Bristol Technical Education Center': 431187, 'Brite Divinity School': 450304, 'Brittany Beauty Academy': 189404, 'Broadview University-West Jordan': 230056, 'Broken Arrow Beauty College': 448424, 'Broken Arrow Beauty College-Broken Arrow': 206880, 'Brookdale Community College': 183859, 'Brookhaven College': 223524, 'Brookline College-Albuquerque': 444088, 'Brookline College-Phoenix': 104090, 'Brookline College-Tempe': 404055, 'Brookline College-Tucson': 438179, 'Brooklyn Law School': 189501, 'Broome Delaware Tioga BOCES-Practical Nursing Program': 418010, 'Broward College': 132709, 'Brown Aveda Institute-Mentor': 441645, 'Brown Aveda Institute-Strongsville': 450395, 'Brown Beauty Barber School': 491695, 'Brown College of Court Reporting': 139214, 'Brown University': 217156, 'Brownson Technical School': 110194, 'Brunswick Community College': 198084, 'Bryan College of Health Sciences': 180878, 'Bryan College-Dayton': 219790, 'Bryan University': 110219, 'Bryant & Stratton College-Akron': 475699, 'Bryant & Stratton College-Albany': 188517, 'Bryant & Stratton College-Amherst': 189556, 'Bryant & Stratton College-Bayshore': 458502, 'Bryant & Stratton College-Buffalo': 189583, 'Bryant & Stratton College-Cleveland': 202684, 'Bryant & Stratton College-Greece': 189592, 'Bryant & Stratton College-Hampton': 459107, 'Bryant & Stratton College-Henrietta': 410496, 'Bryant & Stratton College-Online': 480091, 'Bryant & Stratton College-Parma': 201469, 'Bryant & Stratton College-Racine': 492458, 'Bryant & Stratton College-Richmond': 231828, 'Bryant & Stratton College-Solon': 369905, 'Bryant & Stratton College-Southtowns': 374972, 'Bryant & Stratton College-Syracuse': 189574, 'Bryant & Stratton College-Syracuse North': 189565, 'Bryant & Stratton College-Virginia Beach': 231785, 'Bryant & Stratton College-Wauwatosa': 451750, 'Bryant University': 217165, 'Bryn Athyn College of the New Church': 210492, 'Bryn Mawr College': 211273, 'Buckeye Hills Career Center': 201478, 'Buckeye Joint Vocational School': 383312, 'Bucknell University': 211291, 'Buckner Barber School': 461740, 'Bucks County Community College': 211307, 'Bucks County School of Beauty Culture Inc': 211316, 'Buena Vista University': 153001, 'Bull City Durham Beauty and Barber College': 490948, 'Bunker Hill Community College': 165112, 'Burrell College of Osteopathic Medicine': 488554, 'Butler Beauty Academy': 211334, 'Butler Beauty Academy-Kittanning Beauty Academy': 213330, 'Butler Beauty Academy-New Castle Beauty Academy': 367431, 'Butler Community College': 154800, 'Butler County Community College': 211343, 'Butler Technology and Career Development Schools': 201496, 'Butler University': 150163, 'Butte Academy of Beauty Culture': 180063, 'Butte College': 110246, 'Butte County Regional Occupational Program': 487773, 'Byzantine Catholic Seminary of Saints Cyril and Methodius': 444103, 'C. Alexander School of Cosmetology': 490364, 'CAAN Academy of Nursing': 487968, 'Cabarrus College of Health Sciences': 198109, 'Cabell County Career Technology Center': 237242, 'Cabrillo College': 110334, 'Cabrini University': 211352, 'Caddo Kiowa Technology Center': 364946, 'Cadillac Institute of Cosmetology': 421665, 'Cairn University-Langhorne': 215114, 'CALC Institute of Technology': 446084, 'Caldwell Community College and Technical Institute': 198118, 'Caldwell University': 183910, 'California Aeronautical University': 433420, 'California Baptist University': 110361, 'California Barber and Beauty College': 486497, 'California Beauty School': 110875, 'California Career College': 447713, 'California Career Institute': 481386, 'California Career School': 262402, 'California Christian College': 110918, 'California College of Barbering and Cosmetology': 492661, 'California College of the Arts': 110370, 'California College San Diego': 478634, 'California Graduate School of Theology': 111045, 'California Hair Design Academy': 111054, 'California Healing Arts College': 442985, 'California Health Sciences University': 488572, 'California Institute of Advanced Management': 487649, 'California Institute of Arts & Technology': 490285, 'California Institute of Integral Studies': 110316, 'California Institute of Medical Science': 491507, 'California Institute of Technology': 110404, 'California Institute of the Arts': 111081, 'California Intercontinental University': 485546, 'California International Business University': 483586, 'California Jazz Conservatory': 486488, 'California Lutheran University': 110413, 'California Miramar University': 480781, 'California Nurses Educational Institute': 455734, 'California Polytechnic State University-San Luis Obispo': 110422, 'California State Polytechnic University-Pomona': 110529, 'California State University Maritime Academy': 111188, 'California State University-Bakersfield': 110486, 'California State University-Chancellors Office': 110501, 'California State University-Channel Islands': 441937, 'California State University-Chico': 110538, 'California State University-Dominguez Hills': 110547, 'California State University-East Bay': 110574, 'California State University-Fresno': 110556, 'California State University-Fullerton': 110565, 'California State University-Long Beach': 110583, 'California State University-Los Angeles': 110592, 'California State University-Monterey Bay': 409698, 'California State University-Northridge': 110608, 'California State University-Sacramento': 110617, 'California State University-San Bernardino': 110510, 'California State University-San Marcos': 366711, 'California State University-Stanislaus': 110495, 'California Technical Academy': 483443, 'California University of Management and Sciences': 460075, 'California University of Pennsylvania': 211361, 'California Western School of Law': 111391, 'Calumet College of Saint Joseph': 150172, 'Calvary University': 176789, 'Calvin Theological Seminary': 169099, 'Calvin University': 169080, 'Cambridge College': 165167, 'Cambridge College of Healthcare & Technology': 454865, 'Cambridge Institute of Allied Health & Technology': 446109, 'Cambridge Junior College-Yuba City': 446093, 'Cambridge Technical Institute': 444264, 'Camden County College': 183938, 'Camelot College': 417549, 'Cameo Beauty Academy': 143464, 'Cameo College of Essential Beauty': 230065, 'Cameron University': 206914, 'Campbell University': 198136, 'Campbellsville University': 156365, 'Canada College': 111434, 'Canadian Valley Technology Center': 365374, 'Canisius College': 189705, 'Cankdeska Cikana Community College': 200208, 'Cannella School of Hair Design-Blue Island': 401481, 'Cannella School of Hair Design-Chicago': 143482, 'Cannella School of Hair Design-Villa Park': 143473, 'Canton City Schools Adult Career and Technical Education': 201539, 'Cape Cod Community College': 165194, 'Cape Coral Technical College': 431558, 'Cape Fear Community College': 198154, 'Cape Girardeau Career and Technology Center': 176798, 'Capella University': 413413, 'Capilo School of Hair Design': 461704, 'Capital Area School of Practical Nursing': 367972, 'Capital Community College': 129367, 'Capital University': 201548, 'Capitol School of Hairstyling and Esthetics': 365693, 'Capitol Technology University': 162061, 'Capri Beauty College': 457031, 'Capri College-Cedar Rapids': 153083, 'Capri College-Davenport': 154448, 'Capri College-Dubuque': 153074, 'Capri Cosmetology Learning Centers': 189714, 'Capri Institute of Hair Design-Brick': 407391, 'Capri Institute of Hair Design-Clifton': 363077, 'Capri Institute of Hair Design-Kenilworth': 407407, 'Capri Institute of Hair Design-Paramus': 407425, 'Capstone College': 377759, 'Cardiac and Vascular Institute of Ultrasound': 455707, 'Cardinal Stritch University': 238430, 'Career Academy of Beauty': 111513, 'Career Academy of Hair Design': 107220, 'Career and Technology Education Centers of Licking County': 418205, 'Career Beauty College': 444468, 'Career Care Institute': 446118, 'Career Center of Southern Illinois': 417442, 'Career College of Northern Nevada': 181941, 'Career Development Institute Inc': 454801, 'Career Networks Institute': 433013, 'Career Quest Learning Center-Bay City Branch': 493424, 'Career Quest Learning Center-Mt. Pleasant': 490568, 'Career Quest Learning Centers-Jackson': 454306, 'Career Quest Learning Centers-Lansing': 446136, 'Career School of NY': 455220, 'Career Technical Institute': 420370, 'Career Technology Center of Lackawanna County': 246071, 'Careers Institute of America': 493734, 'Careers Unlimited': 448239, 'Caribbean Aviation Training Institute Inc': 489256, 'Caribbean Forensic and Technical College': 441706, 'Caribbean University-Bayamon': 241377, 'Caribbean University-Carolina': 241386, 'Caribbean University-Ponce': 363907, 'Caribbean University-Vega Baja': 363916, 'Caris College': 491941, 'Carl Albert State College': 206923, 'Carl Sandburg College': 143613, 'Carleton College': 173258, 'Carlos Albizu University-Miami': 132842, 'Carlos Albizu University-San Juan': 241331, 'Carlow University': 211431, 'Carlson College of Massage Therapy': 451194, 'Carnegie Institute': 169187, 'Carnegie Mellon University': 211440, 'Carolina Career College': 491455, 'Carolina Christian College': 199971, 'Carolina College of Biblical Studies': 461032, 'Carolina College of Hair Design': 460765, 'Carolina School of Broadcasting': 198190, 'Carolinas College of Health Sciences': 433174, 'Carrington College-Administrative Office': 485467, 'Carrington College-Albuquerque': 442602, 'Carrington College-Boise': 142054, 'Carrington College-Citrus Heights': 450702, 'Carrington College-Las Vegas': 457101, 'Carrington College-Mesa': 103909, 'Carrington College-Mesquite': 475750, 'Carrington College-Phoenix East': 250601, 'Carrington College-Phoenix North': 103893, 'Carrington College-Pleasant Hill': 438258, 'Carrington College-Pomona': 467368, 'Carrington College-Portland': 246035, 'Carrington College-Reno': 457110, 'Carrington College-Sacramento': 125532, 'Carrington College-San Jose': 437936, 'Carrington College-San Leandro': 246974, 'Carrington College-Spokane': 439118, 'Carrington College-Stockton': 450696, 'Carrington College-Tucson': 103927, 'Carroll College': 180106, 'Carroll Community College': 405872, 'Carroll University': 238458, 'Carson-Newman University': 219806, 'Carsten Institute of Cosmetology': 447430, 'Carteret Community College': 198206, 'Carthage College': 238476, 'Carthage R9 School District-Carthage Technical Center': 481049, 'Carver Career Center': 430795, 'Casa Loma College-Van Nuys': 111638, 'Casal Aveda Institute': 203438, 'Casal Institute of Nevada': 455211, 'Cascadia College': 439190, 'Case Western Reserve University': 201645, 'Casper College': 240505, 'Cass Career Center': 417682, 'Castleton University': 230834, 'Catawba College': 198215, 'Catawba Valley Community College': 198233, 'Catherine Hinds Institute of Esthetics': 165255, 'Catholic Distance University': 475398, 'Catholic Theological Union at Chicago': 143659, 'Cattaraugus Allegany BOCES-Practical Nursing Program': 417983, 'Cayce/Reilly School of Massage': 430306, 'Cayuga County Community College': 189839, 'Cayuga Onondaga BOCES-Practical Nursing Program': 430883, 'Cazenovia College': 189848, 'CBD College': 439367, 'CCI Training Center-Arlington': 449773, 'CDA Technical Institute': 447874, 'CDE Career Institute': 451495, 'Cecil College': 162104, 'Cedar Crest College': 211468, 'Cedar Valley College': 223773, 'Cedarville University': 201654, 'Celebrity Barber School': 487621, 'Celebrity School of Beauty': 454917, 'Celebrity Stylist Beauty School': 160126, 'CEM College-Bayamon': 451741, 'CEM College-Humacao': 376224, 'CEM College-Mayaguez': 484835, 'CEM College-San Juan': 241517, 'Centenary College of Louisiana': 158477, 'Centenary University': 183974, 'Center for Advanced Legal Studies': 379782, 'Center for Advanced Studies On Puerto Rico and the Caribbean': 241793, 'Center for Allied Health Education': 451413, 'Center for Massage': 455910, 'Center for Natural Wellness School of Massage Therapy': 449667, 'Center for Neurosomatic Studies': 488226, 'Center for Ultrasound Research & Education': 486381, 'CenterPoint Massage & Shiatsu Therapy School & Clinic': 457651, 'Centra College of Nursing': 232618, 'Central Alabama Community College': 100760, 'Central Arizona College': 104346, 'Central Baptist College': 106713, 'Central California School of Continuing Education': 419183, 'Central Career Institute LLC': 436003, 'Central Carolina Community College': 198251, 'Central Carolina Technical College': 218858, 'Central Christian College of Kansas': 154855, 'Central Christian College of the Bible': 176910, 'Central Coast College': 378105, 'Central College': 153108, 'Central College of Cosmetology': 417725, 'Central Community College': 180902, 'Central Connecticut State University': 128771, 'Central Georgia Technical College': 483045, 'Central Lakes College-Brainerd': 173203, 'Central Louisiana Technical Community College': 158088, 'Central Maine Community College': 161077, 'Central Methodist University-College of Graduate and Extended Studies': 445267, 'Central Methodist University-College of Liberal Arts and Sciences': 176947, 'Central Michigan University': 169248, 'Central New Mexico Community College': 187532, 'Central Ohio Technical College': 201672, 'Central Oklahoma College': 206932, 'Central Oregon Community College': 208318, 'Central Penn College': 211477, 'Central Pennsylvania Diesel Institute': 493558, 'Central Pennsylvania Institute of Science and Technology': 369668, 'Central Piedmont Community College': 198260, 'Central School of Practical Nursing': 201681, 'Central State University': 201690, 'Central Susquehanna Intermediate Unit LPN Career': 406422, 'Central Technology Center': 246017, 'Central Texas Beauty College-Round Rock': 246460, 'Central Texas Beauty College-Temple': 383464, 'Central Texas College': 223816, 'Central Virginia Community College': 231697, 'Central Washington University': 234827, 'Central Wyoming College': 240514, 'Central Yeshiva Beth Joseph': 488004, 'Central Yeshiva Tomchei Tmimim Lubavitz': 189857, 'Centralia Beauty College': 491260, 'Centralia College': 234845, 'Centre College': 156408, 'Centura College-Chesapeake': 420024, 'Centura College-Columbia': 444972, 'Centura College-Newport News': 377449, 'Centura College-Norfolk': 377458, 'Centura College-Richmond Main': 427982, 'Centura College-Virginia Beach': 232016, 'Century College': 436553, 'Cerritos College': 111887, 'Cerro Coso Community College': 111896, 'CES College': 444510, 'CET-Alexandria': 427894, 'CET-Coachella': 381255, 'CET-Colton': 111744, 'CET-El Centro': 111726, 'CET-El Paso': 432269, 'CET-Oxnard': 381282, 'CET-Salinas': 111799, 'CET-San Diego': 111708, 'CET-San Jose': 111717, 'CET-Santa Maria': 381325, 'CET-Soledad': 468769, 'CET-Watsonville': 111762, 'Chabot College': 111920, 'Chadron State College': 180948, 'Chaffey College': 111939, 'Chamberlain University-Administrative Office': 454218, 'Chamberlain University-Arizona': 454245, 'Chamberlain University-California': 489353, 'Chamberlain University-Florida': 457129, 'Chamberlain University-Georgia': 475732, 'Chamberlain University-Illinois': 454227, 'Chamberlain University-Indiana': 475741, 'Chamberlain University-Louisiana': 492759, 'Chamberlain University-Michigan': 486947, 'Chamberlain University-Missouri': 466921, 'Chamberlain University-Nevada': 486938, 'Chamberlain University-New Jersey': 486956, 'Chamberlain University-North Carolina': 489344, 'Chamberlain University-Ohio': 454236, 'Chamberlain University-Texas': 466930, 'Chamberlain University-Virginia': 460871, 'Chambersburg Beauty School': 446996, 'Chaminade University of Honolulu': 141486, "Champ's Barber School": 483753, 'Champion Beauty College': 449782, 'Champion Christian College': 492069, 'Champion Institute of Cosmetology': 422190, 'Champlain College': 230852, 'Chandler-Gilbert Community College': 364025, 'Chapman University': 111948, 'Charles A Jones Career and Education Center': 123493, 'Charles and Sues School of Hair Design': 223852, 'Charles H McCann Technical School': 419095, 'Charles of Italy Beauty College': 104391, 'Charles R Drew University of Medicine and Science': 111966, 'Charles Stuart School of Diamond Setting': 418171, 'Charleston Cosmetology Institute': 217794, 'Charleston School of Beauty Culture': 237303, 'Charleston School of Law': 451510, 'Charleston Southern University': 217688, "Charlie's Guard-Detective Bureau and Academy Inc": 443951, 'Charlotte Christian College and Theological Seminary': 444778, 'Charlotte Technical College': 132976, 'Charter College': 102845, 'Charter Oak State College': 128780, 'Charzanne Beauty College': 217828, 'Chatfield College': 201751, 'Chatham University': 211556, 'Chattahoochee Technical College': 140331, 'Chattahoochee Valley Community College': 101028, 'Chattanooga College Medical Dental and Technical Careers': 220118, 'Chattanooga State Community College': 219824, 'Cheeks Beauty Academy': 381699, 'Chemeketa Community College': 208390, 'Cheryl Fells School of Business': 189954, 'Chesapeake College': 162168, 'Chester Career College': 437769, 'Chester County Intermediate Unit': 418427, 'Chestnut Hill College': 211583, 'Cheyney University of Pennsylvania': 211608, 'CHI Health School of Radiologic Technology': 181145, 'Chicago School of Professional Psychology at Dallas': 492607, 'Chicago State University': 144005, 'Chicago Theological Seminary': 144014, 'Chief Dull Knife College': 180160, 'Chipola College': 133021, 'Chippewa Valley Technical College': 240116, 'Chisholm Trail Technology Center': 375656, 'Choffin Career  and Technical Center': 201803, 'Chowan University': 198303, 'Chris Beauty College': 175494, 'Christ Mission College': 494630, 'Christ the King Seminary': 189981, 'Christian Brothers University': 219833, 'Christian Culinary Academy': 488590, 'Christian Life College': 260947, 'Christian Theological Seminary': 150215, "Christie's Education": 475510, 'Christina and Company Education Center': 491552, 'Christine Valmy International School for Esthetics  Skin Care & Makeup': 189990, 'Christine Valmy International School of Esthetics & Cosmetology': 475468, 'Christopher Newport University': 231712, 'Church Divinity School of the Pacific': 112127, 'Cincinnati Christian University': 201858, 'Cincinnati College of Mortuary Science': 201867, 'Cincinnati School of Barbering & Hair Design Inc': 490692, 'Cincinnati State Technical and Community College': 201928, 'Cinta Aveda Institute': 461829, 'Circle in the Square Theatre School': 190008, 'Cisco College': 223898, 'Citadel Military College of South Carolina': 217864, 'Citizens School of Nursing': 211635, 'Citrus College': 112172, 'Citrus Heights Beauty College': 112181, 'City College of San Francisco': 112190, 'City College-Altamonte Springs': 417327, 'City College-Fort Lauderdale': 244233, 'City College-Gainesville': 406547, 'City College-Hollywood': 475477, 'City College-Miami': 434539, 'City Colleges of Chicago-District Office': 144500, 'City Colleges of Chicago-Harold Washington College': 144209, 'City Colleges of Chicago-Harry S Truman College': 144184, 'City Colleges of Chicago-Kennedy-King College': 144157, 'City Colleges of Chicago-Malcolm X College': 144166, 'City Colleges of Chicago-Olive-Harvey College': 144175, 'City Colleges of Chicago-Richard J Daley College': 144193, 'City Colleges of Chicago-Wilbur Wright College': 144218, 'City Pointe Beauty Academy': 481517, 'City University of Seattle': 234915, 'City Vision University': 457697, 'Clackamas Community College': 208406, 'Claflin University': 217873, 'Claremont Graduate University': 112251, 'Claremont Lincoln University': 488387, 'Claremont McKenna College': 112260, 'Claremont School of Theology': 124283, 'Clarendon College': 223922, 'Clarion County Career Center Practical Nursing Program': 418603, 'Clarion University of Pennsylvania': 211644, 'Clark Atlanta University': 138947, 'Clark College': 234933, 'Clark State Community College': 201973, 'Clark University': 165334, 'Clarke University': 153126, 'Clarks Summit University': 211024, 'Clarksburg Beauty Academy and School of Massage Therapy': 237321, 'Clarkson College': 180832, 'Clarkson University': 190044, 'Clary Sage College': 450401, 'Clatsop Community College': 208415, 'Clayton  State University': 139311, 'Clear Creek Baptist Bible College': 156417, 'Clearfield County Career and Technology Center': 430908, 'Cleary University': 169327, 'Clemson University': 217882, 'Cleveland Clinic Health System-School of Diagnostic Imaging': 411754, 'Cleveland Community College': 198321, 'Cleveland Institute of Art': 202046, 'Cleveland Institute of Music': 202073, 'Cleveland State Community College': 219879, 'Cleveland State University': 202134, 'Cleveland University-Kansas City': 177038, 'Clinton College': 217891, 'Clinton Community College': 190053, 'Clinton Essex Warren Washington BOCES': 417868, 'Clinton Technical School': 260336, 'Cloud County Community College': 154907, 'Clover Park Technical College': 234951, 'Clovis Adult Education': 112367, 'Clovis Community College': 489201, "Cloyd's Barber School 2 Inc": 366155, "Cloyd's Beauty School 1 Inc": 158538, "Cloyd's Beauty School 3 Inc": 248527, 'Coachella Valley Beauty College': 449393, 'Coachella Valley Beauty College-Hemet': 485412, 'Coahoma Community College': 175519, 'Coast Community College District Office': 112376, 'Coastal Alabama Community College': 101161, 'Coastal Bend College': 223320, 'Coastal Carolina Community College': 198330, 'Coastal Carolina University': 218724, 'Coastal Pines Technical College': 485458, 'Coastline Beauty College': 450988, 'Coastline Community College': 112385, 'Coba Academy': 112455, 'Cobb Beauty College Inc': 417406, 'Cochise County Community College District': 104425, 'Cochran School of Nursing': 190071, 'Coconino Community College': 404426, 'Coe College': 153144, 'Coffeyville Community College': 154925, 'Cogswell College': 112394, 'Coker University': 217907, 'Colby College': 161086, 'Colby Community College': 154934, 'Colby-Sawyer College': 182634, 'Colegio de Cinematografía Artes y Television': 430935, 'Colegio Educativo Tecnologico Industrial Inc': 443100, 'Colegio Mayor de Tecnologia Inc': 376242, 'Colegio Tecnico de Electricidad Galloza': 445498, 'Colegio Universitario de San Juan': 241720, 'Colgate Rochester Crozer Divinity School': 190080, 'Colgate University': 190099, 'Collectiv Academy': 230144, "Colleen O'Haras Beauty Academy": 420608, 'College for Creative Studies': 169442, 'College of Alameda': 108667, 'College of Biblical Studies': 439613, 'College of Biblical Studies-Houston': 388520, 'College of Business and Technology-Cutler Bay': 456977, 'College of Business and Technology-Hialeah': 449092, 'College of Business and Technology-Main Campus': 449083, 'College of Business and Technology-Miami Campus': 417318, 'College of Business and Technology-Miami Gardens': 482024, 'College of Central Florida': 132851, 'College of Charleston': 217819, 'College of Coastal Georgia': 139250, 'College of Cosmetology': 210340, 'College of Court Reporting Inc': 150251, 'College of DuPage': 144865, 'College of Eastern Idaho': 142179, 'College of Hair Design Careers': 208433, 'College of Hair Design-Downtown': 180957, 'College of Hair Design-East Campus': 456287, 'College of International Esthetics Inc': 476586, 'College of Lake County': 146472, 'College of Marin': 118347, 'College of Massage Therapy': 460808, 'College of Menominee Nation': 413617, 'College of Micronesia-FSM': 243638, 'College of Mount Saint Vincent': 193399, 'College of Our Lady of the Elms': 167394, 'College of Saint Benedict': 174747, 'College of Saint Elizabeth': 186618, 'College of Saint Mary': 181604, 'College of San Mateo': 122791, 'College of Southern Idaho': 142559, 'College of Southern Maryland': 162122, 'College of Southern Nevada': 182005, 'College of St Joseph': 231077, 'College of Staten Island CUNY': 190558, 'College of the Albemarle': 197814, 'College of the Atlantic': 160959, 'College of the Canyons': 111461, 'College of the Desert': 113573, 'College of the Holy Cross': 166124, 'College of the Mainland': 226408, 'College of the Marshall Islands': 376695, 'College of the Muscogee Nation': 480967, 'College of the Ozarks': 178697, 'College of the Redwoods': 121707, 'College of the Sequoias': 123217, 'College of the Siskiyous': 123484, 'College of Western Idaho': 455114, 'College of Wilmington': 199078, 'College Unbound': 493822, 'CollegeAmerica-Colorado Springs': 448752, 'CollegeAmerica-Denver': 126872, 'CollegeAmerica-Flagstaff': 103945, 'CollegeAmerica-Fort Collins': 448761, 'CollegeAmerica-Phoenix': 474890, 'Collin County Community College District': 247834, 'Colorado Academy of Veterinary Technology': 461953, 'Colorado Christian University': 126669, 'Colorado College': 126678, 'Colorado Media School': 443632, 'Colorado Mesa University': 127556, 'Colorado Mountain College': 126711, 'Colorado Northwestern Community College': 126748, 'Colorado School of Healing Arts': 381732, 'Colorado School of Mines': 126775, 'Colorado School of Trades': 126784, 'Colorado School of Traditional Chinese Medicine': 381352, 'Colorado State University-Fort Collins': 126818, 'Colorado State University-Global Campus': 476975, 'Colorado State University-Pueblo': 128106, 'Colorado State University-System Office': 446978, 'Colorado Technical University-Colorado Springs': 126827, 'Columbia Area Career Center': 177056, 'Columbia Basin College': 234979, 'Columbia Central University-Caguas': 241304, 'Columbia Central University-Yauco': 404806, 'Columbia College': 479248, 'Columbia College Chicago': 144281, 'Columbia College Hollywood': 112570, 'Columbia College of Nursing': 238573, 'Columbia Gorge Community College': 420556, 'Columbia Institute': 480693, 'Columbia International University': 217925, 'Columbia Southern University': 450933, 'Columbia State Community College': 219888, 'Columbia Theological Seminary': 139348, 'Columbia University in the City of New York': 190150, 'Columbia-Greene Community College': 190169, 'Columbiana County Career and Technical Center': 202152, 'Columbus College of Art and Design': 202170, 'Columbus State Community College': 202222, 'Columbus State University': 139366, 'Columbus Technical College': 139357, 'Commonwealth Institute of Funeral Service': 366261, 'Commonwealth Technical Institute': 212975, 'Community Care College': 439570, 'Community Christian College': 446163, 'Community College of Allegheny County': 210605, 'Community College of Aurora': 126863, 'Community College of Baltimore County': 434672, 'Community College of Beaver County': 211079, 'Community College of Denver': 126942, 'Community College of Philadelphia': 215239, 'Community College of Rhode Island': 217475, 'Community College of Vermont': 230861, 'Community Technology Learning Center of Portage': 452540, 'Compass Career College': 447962, 'Compass College of Cinematic Arts': 459417, 'Compton College': 112686, 'Compu-Med Vocational Careers Corp': 423120, 'Conception Seminary College': 177083, 'Concord University': 237330, 'Concorde Career College-Aurora': 126687, 'Concorde Career College-Dallas': 460181, 'Concorde Career College-Garden Grove': 123679, 'Concorde Career College-Grand Prairie': 441742, 'Concorde Career College-Kansas City': 155283, 'Concorde Career College-Memphis': 219903, 'Concorde Career College-North Hollywood': 124937, 'Concorde Career College-Portland': 208479, 'Concorde Career College-San Antonio': 460206, 'Concorde Career College-San Bernardino': 124706, 'Concorde Career College-San Diego': 120661, 'Concorde Career College-Southaven': 487588, 'Concorde Career Institute-Jacksonville': 133845, 'Concorde Career Institute-Miramar': 133854, 'Concorde Career Institute-Orlando': 460190, 'Concorde Career Institute-Tampa': 133863, 'Concordia College at Moorhead': 173300, 'Concordia College-New York': 190248, 'Concordia Seminary': 177092, 'Concordia Theological Seminary': 150288, 'Concordia University Texas': 224004, 'Concordia University-Ann Arbor': 169363, 'Concordia University-Chicago': 144351, 'Concordia University-Irvine': 112075, 'Concordia University-Nebraska': 180984, 'Concordia University-Portland': 208488, 'Concordia University-Saint Paul': 173328, 'Concordia University-Wisconsin': 238616, 'Congregation Talmidei Mesivta Tiferes Shmiel Aleksander': 493600, 'Connecticut College': 128902, 'Connors State College': 206996, 'Conservatory of Music of Puerto Rico': 241766, 'Conservatory of Recording Arts and Sciences': 262341, 'Construction Training Center': 488040, 'Continental Academie of Hair Design-Hudson': 182652, 'Continental School of Beauty Culture-Mattydale': 467094, 'Continental School of Beauty Culture-Olean': 374990, 'Continental School of Beauty Culture-Rochester': 190318, 'Continental School of Beauty Culture-West Seneca': 194435, 'Contra Costa College': 112826, 'Contra Costa Community College District Office': 112817, 'Contra Costa Medical Career College': 491950, 'Converse College': 217961, 'Conway School of Landscape Design': 165495, 'Cooper Union for the Advancement of Science and Art': 190372, 'Copiah-Lincoln Community College': 175573, 'Copper Mountain Community College': 395362, 'Coppin State University': 162283, 'Corban University': 210331, 'Corinth Academy of Cosmetology': 451343, 'Cornell College': 153162, 'Cornell University': 190415, 'Cornerstone University': 170037, 'Cornish College of the Arts': 235024, 'Cortiva Institute-Arlington': 486770, 'Cortiva Institute-Aurora': 469160, 'Cortiva Institute-Baltimore': 434308, 'Cortiva Institute-Chicago': 244561, 'Cortiva Institute-Cromwell': 128896, 'Cortiva Institute-Dallas': 476346, 'Cortiva Institute-Florida': 134574, 'Cortiva Institute-Groton': 443483, 'Cortiva Institute-Houston': 481942, 'Cortiva Institute-King of Prussia': 215044, 'Cortiva Institute-Las Vegas': 469124, 'Cortiva Institute-Maitland': 438285, 'Cortiva Institute-Miami': 420103, 'Cortiva Institute-New Jersey': 460640, 'Cortiva Institute-Orem': 436270, 'Cortiva Institute-Phoenix': 469142, 'Cortiva Institute-Pompano': 387925, 'Cortiva Institute-Salt Lake': 380474, 'Cortiva Institute-Scottsdale': 105482, 'Cortiva Institute-Seattle': 419411, 'Cortiva Institute-Tempe': 469133, 'Cortiva Institute-Tucson': 104504, 'Cortiva Institute-Westminster': 469151, 'Cortiva Institute-Westport': 407054, 'Cortiva Institute-York': 469586, 'Cosmetology & Spa Academy': 144795, 'Cosmetology Academy of Texarkana': 482200, 'Cosmetology Career Center LLC': 224156, 'Cosmetology Careers Unlimited College of Hair Skin and Nails': 173470, 'Cosmetology School of Arts and Science LLC': 445780, 'Cosmetology Training Center': 407142, 'Cosmo Beauty Academy': 459189, 'Cosmo Factory Cosmetology Academy': 481395, 'Cossatot Community College of the University of Arkansas': 106795, 'Cosumnes River College': 113096, 'Cottey College': 177117, 'County College of Morris': 184180, 'Covenant College': 139393, 'Covenant School of Nursing and Allied Health': 226675, 'Covenant Theological Seminary': 177126, 'Cowley County Community College': 154952, 'Cox College': 176770, 'Coyne College': 144485, 'Cozmo Beauty School': 454874, 'Crafton Hills College': 113111, 'Cranbrook Academy of Art': 169424, 'Crave Beauty Academy': 417503, 'Craven Community College': 198367, 'Crawford County Career and Technical Center Practical Nursing Program': 419484, 'Creative Hair School of Cosmetology': 169813, 'Creative Images Institute of Cosmetology-North Dayton': 434830, 'Creative Images Institute of Cosmetology-South Dayton': 444051, 'Creative Touch Cosmetology School': 483911, 'Creighton University': 181002, 'Crescent City Bartending School': 158617, "Crevier's Academy of Cosmetology Arts": 180090, 'Criswell College': 475608, 'Crowder College': 177135, "Crowley's Ridge College": 106810, "Crowley's Ridge Technical Institute": 106829, 'Crown College': 174862, 'CRU Institute of Cosmetology and Barbering': 371830, 'CT Aero Tech School': 417248, 'Cuesta College': 113193, 'Culinary Institute Inc': 444565, 'Culinary Institute of America': 190503, 'Culinary Tech Center': 486390, 'Culpeper Cosmetology Training Center': 446206, 'Culver-Stockton College': 177144, 'Cumberland County College': 184205, 'Cumberland University': 219949, 'CUNY Bernard M Baruch College': 190512, 'CUNY Borough of Manhattan Community College': 190521, 'CUNY Bronx Community College': 190530, 'CUNY Brooklyn College': 190549, 'CUNY City College': 190567, 'CUNY Graduate School and University Center': 190576, 'CUNY Hostos Community College': 190585, 'CUNY Hunter College': 190594, 'CUNY John Jay College of Criminal Justice': 190600, 'CUNY Kingsborough Community College': 190619, 'CUNY LaGuardia Community College': 190628, 'CUNY Lehman College': 190637, 'CUNY Medgar Evers College': 190646, 'CUNY New York City College of Technology': 190655, 'CUNY Queens College': 190664, 'CUNY Queensborough Community College': 190673, 'CUNY School of Law': 190682, 'CUNY Stella and Charles Guttman Community College': 475565, 'CUNY System Office': 190035, 'CUNY York College': 190691, 'Curry College': 165529, 'Curtis Institute of Music': 211893, 'Curve Metric School of Hair Design': 476674, 'Cutting Edge Academy': 490300, 'Cuyahoga Community College District': 202356, 'Cuyahoga Valley Career Center': 204981, 'Cuyamaca College': 113218, 'CVPH Medical Center School of Radiologic Technology': 190707, 'CyberTex Institute of Technology': 480888, 'Cypress College': 113236, 'D A Dorsey Technical College': 461306, 'D&S School of Cosmetology': 492096, "D'Jay's Institute of Cosmetology and Esthiology": 158644, "D'Mart Institute": 418773, "D'Youville College": 190716, 'Dabney S Lancaster Community College': 231873, 'Daemen College': 190725, 'Dakota College at Bottineau': 200314, 'Dakota County Technical College': 173416, 'Dakota State University': 219082, 'Dakota Wesleyan University': 219091, 'Dallas Baptist University': 224226, 'Dallas Barber & Stylist College': 443021, 'Dallas Christian College': 224244, 'Dallas County Community College District': 224253, 'Dallas Institute of Funeral Service': 224271, 'Dallas Nursing Institute': 437732, 'Dallas Theological Seminary': 224305, 'Dalton Institute of Esthetics and Cosmetology': 487959, 'Dalton State College': 139463, 'Daniel Morgan Graduate School of National Security': 492102, 'Danville Area Community College': 144564, 'Danville Community College': 231882, 'Daoist Traditions College of Chinese Medical Arts': 455178, 'Dartmouth College': 182670, 'Davenport University': 169479, 'David Pressley School of Cosmetology': 169503, 'Davidson College': 198385, 'Davidson County Community College': 198376, 'Davis & Elkins College': 237358, 'Davis College': 194569, 'Davis Technical College': 230162, 'Dawn Career Institute LLC': 130873, 'Dawson Community College': 180151, 'Dayton Barber College': 202453, 'Dayton School of Medical Massage': 449700, 'Daytona College': 447014, 'Daytona State College': 133386, 'DCI Career Institute': 406413, 'De Anza College': 113333, 'Dean College': 165574, 'Dean Institute of Technology': 211909, 'Debutantes School of Cosmetology and Nail Technology': 484084, 'Defiance College': 202514, 'DeHart Technical School': 488192, 'Del Mar College': 224350, 'Delaware Chenango Madison Otsego BOCES-Practical Nursing Program': 406361, 'Delaware College of Art and Design': 432524, 'Delaware County Community College': 211927, 'Delaware County Technical School-Practical Nursing Program': 430971, 'Delaware Learning Institute of Cosmetology': 449472, 'Delaware State University': 130934, 'Delaware Technical Community College-Central Office': 130882, 'Delaware Technical Community College-Terry': 130907, 'Delaware Valley University': 211981, 'Delgado Community College': 158662, "Dell'Arte International School of Physical Theatre": 113537, 'Delmarva Beauty Academy': 162335, 'Delta Beauty College': 175607, 'Delta College': 169521, 'Delta College Inc': 402563, 'Delta College of Arts & Technology': 366270, 'Delta College of Arts & Technology-Lafayette Campus': 483355, 'Delta College-Slidell Campus': 483364, 'Delta Designs Cosmetology School': 490540, 'Delta State University': 175616, 'Delta Technical College': 447023, 'Deluxe Barber College': 493804, 'Denham Springs Beauty School': 158787, 'Denison University': 202523, 'Denmark College': 449603, 'Denmark Technical College': 217989, 'Dental Assistant Pro LLC-Columbus': 452771, 'Dental Assistant Pro-Lebanon': 452780, 'Denver College of Nursing': 454856, 'Denver Seminary': 126979, 'DePaul University': 144740, 'DePauw University': 150400, 'Derech Hachaim Seminary': 494463, 'Dermal Science International Aesthetics and Nail Academy': 484923, 'Des Moines Area Community College': 153214, 'Des Moines University-Osteopathic Medical Center': 154156, 'DeSales University': 210739, 'Design Institute of San Diego': 113582, "Design's School of Cosmetology": 441256, 'Designer Barber & Stylist School': 480921, 'Detroit Business Institute-Downriver': 169576, 'DeVry College of New York': 482413, 'DeVry University-Administrative Office': 144777, 'DeVry University-Arizona': 482422, 'DeVry University-California': 482431, 'DeVry University-Colorado': 482440, 'DeVry University-Florida': 482459, 'DeVry University-Georgia': 482468, 'DeVry University-Illinois': 482477, 'DeVry University-Indiana': 482486, 'DeVry University-Missouri': 482538, 'DeVry University-Nevada': 482547, 'DeVry University-New Jersey': 482556, 'DeVry University-North Carolina': 482565, 'DeVry University-Ohio': 482574, 'DeVry University-Pennsylvania': 482608, 'DeVry University-Tennessee': 482617, 'DeVry University-Texas': 482635, 'DeVry University-Virginia': 482653, 'Dewey University-Carolina': 434900, 'Dewey University-Hato Rey': 443562, 'Dewey University-Juana Díaz': 449135, 'Dewey University-Manati': 469416, 'Diablo Valley College': 113634, 'Diamond Beauty College': 476780, 'Diamonds Cosmetology College': 461388, 'Dickinson College': 212009, 'Dickinson State University': 200059, 'Diesel Driving Academy-Baton Rouge': 373526, 'Diesel Driving Academy-Shreveport': 260664, 'DigiPen Institute of Technology': 443410, 'Digital Film Academy': 480028, 'Digital Media Institute at InterTech': 490498, 'DiGrigoli School of Cosmetology': 451255, 'Dillard University': 158802, 'Diman Regional Technical Institute': 165608, 'Dine College': 105297, 'Divers Academy International': 184278, 'Divers Institute of Technology': 235088, 'Diversified Vocational College': 395690, 'Divine Crown Barber & Beauty Academy': 483346, 'Divine Mercy University': 445869, 'Divine Word College': 153241, 'Dixie State University': 230171, 'Dixie Technical College': 451583, 'DLP Conemaugh Memorial Medical Center': 211802, 'Doane University': 181020, 'Doane University-Graduate and Professional Studies': 448284, 'Dodge City Community College': 154998, 'Dolce LLC The Academy': 485607, 'Dominican College of Blauvelt': 190761, 'Dominican School of Philosophy & Theology': 113704, 'Dominican University': 148496, 'Dominican University of California': 113698, 'Don Roberts Beauty School': 150437, 'Don Roberts School of Hair Design': 150428, 'Dongguk University-Los Angeles': 122117, 'Donnelly College': 155007, 'Dordt University': 153250, 'Dorsey School of Business-Dearborn': 483504, 'Dorsey School of Business-Madison Heights': 169734, 'Dorsey School of Business-Roseville': 250744, 'Dorsey School of Business-Roseville Culinary Academy': 455558, 'Dorsey School of Business-Saginaw': 460482, 'Dorsey School of Business-Waterford Pontiac': 458380, 'Dorsey School of Business-Wayne': 247153, 'Dorsey School of Business-Woodhaven': 169761, 'Douglas Education Center': 212045, 'Douglas J Aveda Institute': 261436, 'Downey Adult School': 371690, 'Dragon Rises College of Oriental Medicine': 449481, 'Drake University': 153269, 'Drew University': 184348, 'Drexel University': 212054, 'Drury University': 177214, 'Drury University-College of Continuing Professional Studies': 492801, 'DSDT': 492139, 'Duke University': 198419, 'Dunwoody College of Technology': 175227, 'Duquesne University': 212106, 'Durham Beauty Academy': 417804, 'Durham Technical Community College': 198455, 'Dutchess BOCES-Practical Nursing Program': 431105, 'Dutchess Community College': 190840, "DuVall's School of Cosmetology": 458043, 'Dyersburg State Community College': 220057, 'E Q School of Hair Design': 154466, "Ea La Mar's Cosmetology & Barber College": 488174, 'Eagle Gate College-Layton': 447421, 'Eagle Gate College-Murray': 230366, 'Eagle Rock College': 451006, 'Earlham College': 150455, 'East Arkansas Community College': 106883, 'East Carolina University': 198464, 'East Central College': 177250, 'East Central Community College': 175643, 'East Central University': 207041, 'East Georgia State College': 139621, 'East Los Angeles College': 113856, 'East Mississippi Community College': 175652, 'East San Gabriel Valley Regional Occupational Program': 413802, 'East Stroudsburg University of Pennsylvania': 212115, 'East Tennessee State University': 220075, 'East Texas Baptist University': 224527, 'East Valley Institute of Technology': 441210, 'East West College of Natural Medicine': 439394, 'East West College of the Healing Arts': 208637, 'East-West Healing Arts Institute': 483799, 'East-West University': 144883, 'Eastern Arizona College': 104577, 'Eastern Center for Arts and Technology': 375966, 'Eastern College of Health Vocations-Little Rock': 106892, 'Eastern College of Health Vocations-New Orleans': 364751, 'Eastern Connecticut State University': 129215, 'Eastern Florida State College': 132693, 'Eastern Gateway Community College': 203331, 'Eastern Illinois University': 144892, 'Eastern International College-Belleville': 448354, 'Eastern International College-Jersey City': 421878, 'Eastern Iowa Community College District': 153311, 'Eastern Kentucky University': 156620, 'Eastern Maine Community College': 161138, 'Eastern Mennonite University': 232043, 'Eastern Michigan University': 169798, 'Eastern Nazarene College': 165644, 'Eastern New Mexico University Ruidoso Branch Community College': 383996, 'Eastern New Mexico University-Main Campus': 187648, 'Eastern New Mexico University-Roswell Campus': 187666, 'Eastern Oklahoma County Technology Center': 418348, 'Eastern Oklahoma State College': 207050, 'Eastern Oregon University': 208646, 'Eastern School of Acupuncture and Traditional Medicine': 446224, 'Eastern Shore Community College': 232052, 'Eastern Suffolk BOCES': 418065, 'Eastern University': 212133, 'Eastern Virginia Career College': 441858, 'Eastern Virginia Medical School': 231970, 'Eastern Washington University': 235097, 'Eastern West Virginia Community and Technical College': 438708, 'Eastern Wyoming College': 240596, 'Eastfield College': 224572, 'Eastland-Fairfield Career and Technical Schools': 407461, 'Eastwick College-Hackensack': 183488, 'Eastwick College-Nutley': 185721, 'Eastwick College-Ramsey': 184959, 'Ecclesia College': 446233, 'Eckerd College': 133492, 'eClips School of Cosmetology and Barbering': 446534, 'ECPI University': 248934, 'Ecumenical Theological Seminary': 247162, 'Eden Theological Seminary': 177278, 'Edgecombe Community College': 198491, 'Edgewood College': 238661, 'EDIC College': 376321, 'Edinboro University of Pennsylvania': 212160, 'Edison State Community College': 202648, 'Edmonds Community College': 235103, 'EDP School': 457794, 'EDP University of Puerto Rico Inc-San Juan': 243832, 'EDP University of Puerto Rico Inc-San Sebastian': 241836, 'EDP University of Puerto Rico-Humacao': 494278, 'EDP University of Puerto Rico-Manati': 494287, 'EDP University of Puerto Rico-Villalba': 492476, 'Educational Technical College': 494834, 'Educational Technical College-Recinto de Bayamon': 240985, 'Educational Technical College-Recinto de Coamo': 448707, 'Educators of Beauty College of Cosmetology-Peru': 146454, 'Educators of Beauty College of Cosmetology-Rockford': 260965, 'Educators of Beauty College of Cosmetology-Sterling': 149204, 'EduMed Partners': 490461, 'Edward Via College of Osteopathic Medicine': 442806, 'Edward Waters College': 133526, 'EHOVE Career Center': 202657, 'EINE Inc': 410964, 'El Camino Community College District': 113980, 'El Centro College': 224615, 'El Paso Community College': 224642, 'Elaine Sterling Institute': 476887, 'Elaine Steven Beauty College': 177287, 'Electrical Training Center': 483382, 'Elegance International': 114044, 'Elevate Salon Institute': 457891, 'Elevate Salon Institute-Chubbuck': 142489, 'Elevate Salon Institute-Westminster': 479983, 'Elgin Community College': 144944, 'Elim Bible Institute and College': 488305, 'Elite Academy of Hair Design': 492005, 'Elite College of Cosmetology': 451529, 'Elite Cosmetology School': 461607, 'Elite Cosmetology  Barber & Spa Academy': 490294, 'Elite Institute of Cosmetology': 490188, 'Elite School of Cosmetology': 461999, 'Elite Welding Academy LLC': 452887, 'Elizabeth City State University': 198507, 'Elizabeth Grady School of Esthetics and Massage Therapy': 362782, 'Elizabethtown College': 212197, 'Elizabethtown College School of Continuing and Professional Studies': 480134, 'Elizabethtown Community and Technical College': 156648, 'Ellsworth Community College': 153296, 'Elmezzi Graduate School of Molecular Medicine': 486080, 'Elmhurst College': 144962, 'Elmira Business Institute': 190974, 'Elmira College': 190983, 'Elon University': 198516, 'Elyon College': 490346, 'Embry-Riddle Aeronautical University-Daytona Beach': 133553, 'Embry-Riddle Aeronautical University-Prescott': 104586, 'Embry-Riddle Aeronautical University-Worldwide': 426314, 'Emerald Coast Technical College': 457378, 'Emerson College': 165662, 'Emily Griffith Technical College': 127158, "Emma's Beauty Academy-Juana Diaz": 404684, "Emma's Beauty Academy-Mayaguez": 241906, 'Emmanuel College': 165671, 'Emmaus Bible College': 153302, 'Emory & Henry College': 232025, 'Emory University': 139658, 'Emory University-Oxford College': 487092, "Emperor's College of Traditional Oriental Medicine": 114114, 'Empire Beauty  School-Lehigh Valley': 212328, 'Empire Beauty School-Augusta': 481678, 'Empire Beauty School-Aurora': 447175, 'Empire Beauty School-Avondale': 447148, 'Empire Beauty School-Bloomfield': 368230, 'Empire Beauty School-Bloomington': 174978, 'Empire Beauty School-Bordentown': 430218, 'Empire Beauty School-Boston': 164845, 'Empire Beauty School-Brooklyn': 383765, 'Empire Beauty School-Buffalo': 485014, 'Empire Beauty School-Center City Philadelphia': 375984, 'Empire Beauty School-Chandler': 104443, 'Empire Beauty School-Charlotte': 459019, 'Empire Beauty School-Cheltenham': 485397, 'Empire Beauty School-Chenoweth': 157614, 'Empire Beauty School-Cherry Hill': 184816, 'Empire Beauty School-Cincinnati': 407470, 'Empire Beauty School-Concord': 450614, 'Empire Beauty School-Dixie': 157669, 'Empire Beauty School-Dunwoody': 417381, 'Empire Beauty School-E Greensboro': 459037, 'Empire Beauty School-E Memphis': 458803, 'Empire Beauty School-Elizabethtown': 157650, 'Empire Beauty School-Flagstaff': 104434, 'Empire Beauty School-Florence': 157678, 'Empire Beauty School-Framingham': 443678, 'Empire Beauty School-Glen Burnie': 480310, 'Empire Beauty School-Green Bay': 407735, 'Empire Beauty School-Gwinnett': 212337, 'Empire Beauty School-Hanover': 415039, 'Empire Beauty School-Hanover Park': 143543, 'Empire Beauty School-Harrisburg': 212382, 'Empire Beauty School-Hooksett': 450641, 'Empire Beauty School-Hurstborne': 248305, 'Empire Beauty School-Indianapolis': 151652, 'Empire Beauty School-Jackson': 458821, 'Empire Beauty School-Kennesaw': 440101, 'Empire Beauty School-Laconia': 182704, 'Empire Beauty School-Lakeland': 491145, 'Empire Beauty School-Lancaster': 212276, 'Empire Beauty School-Lauderhill': 456126, 'Empire Beauty School-Lebanon': 212230, 'Empire Beauty School-Littleton': 447166, 'Empire Beauty School-Maine': 161493, 'Empire Beauty School-Malden': 407179, 'Empire Beauty School-Manhattan': 195067, 'Empire Beauty School-Michigan': 169284, 'Empire Beauty School-Midlothian': 444282, 'Empire Beauty School-Milwaukee': 448798, 'Empire Beauty School-Monroeville': 430227, 'Empire Beauty School-Morrow': 458867, 'Empire Beauty School-Nashville': 458812, 'Empire Beauty School-NE Philadelphia': 212753, 'Empire Beauty School-North Hills': 450605, 'Empire Beauty School-Northlake': 486691, 'Empire Beauty School-NW Phoenix': 106111, 'Empire Beauty School-Owings Mills': 444291, 'Empire Beauty School-Paramus': 458849, 'Empire Beauty School-Peekskill': 193991, 'Empire Beauty School-Pineville': 459064, 'Empire Beauty School-Pottsville': 212300, 'Empire Beauty School-Queens': 190239, 'Empire Beauty School-Reading': 212391, 'Empire Beauty School-Richmond': 450599, 'Empire Beauty School-Rochester': 481845, 'Empire Beauty School-S Memphis': 459000, 'Empire Beauty School-Savannah': 478582, 'Empire Beauty School-Shamokin Dam': 212294, 'Empire Beauty School-Somersworth': 182722, 'Empire Beauty School-Speedway': 458858, 'Empire Beauty School-Spring Lake Park': 456135, 'Empire Beauty School-Springfield': 458830, 'Empire Beauty School-Stone Park': 481748, 'Empire Beauty School-Tampa': 491136, 'Empire Beauty School-Thornton': 128337, 'Empire Beauty School-Tucson': 103741, 'Empire Beauty School-Union': 184506, 'Empire Beauty School-Vernon Hills': 481739, 'Empire Beauty School-Virginia Beach': 476179, 'Empire Beauty School-Warminster': 212373, 'Empire Beauty School-Warwick': 217581, 'Empire Beauty School-West Greensboro': 478616, 'Empire Beauty School-West Mifflin': 444307, 'Empire Beauty School-West Palm': 459055, 'Empire Beauty School-Winston-Salem': 459046, 'Empire Beauty School-Wyoming Valley': 212355, 'Empire Beauty School-York': 212267, 'Empire College': 114123, 'Employment Solutions-College for Technical Education': 446242, 'Emporia State University': 155025, 'Endicott College': 165699, 'Enid Beauty College': 207087, 'Enterprise State Community College': 101143, 'Entourage Institute of Beauty and Esthetics': 461801, 'Epic Bible College': 124487, 'Episcopal Theological Seminary of the Southwest': 224712, 'Eric Fisher Academy': 457581, 'Erie 1 BOCES': 439622, 'Erie 2 Chautauqua Cattaraugus BOCES-Practical Nursing Program': 383525, 'Erie Community College': 191083, 'Erie Institute of Technology Inc': 212434, 'Erikson Institute': 409254, 'Erskine College': 217998, 'Erwin Technical College': 369419, 'Escondido Adult School': 492306, 'Escuela de Artes Plasticas y Diseno de Puerto Rico': 241951, 'Escuela de Peritos Electricistas de Isabela Inc': 420255, 'Escuela De Troqueleria Y Herramentaje': 452106, 'Escuela Hotelera de San Juan': 444583, 'Escuela Tecnica de Electricidad': 431123, 'Essex County College': 184481, 'Esteem Academy of Beauty': 494649, 'Estelle Medical Academy': 446251, 'Estelle Skin Care and Spa Institute': 461582, 'Estes Institute of Cosmetology Arts and Science': 417062, 'Estrella Mountain Community College': 384333, 'ETI School of Skilled Trades': 244613, 'ETI Technical College': 200590, 'Euphoria Institute of Beauty Arts & Sciences-Summerlin': 450720, 'Eureka College': 144971, 'European Academy of Cosmetology and Hairdressing': 457332, 'European Massage Therapy School-Las Vegas': 458423, 'European Medical School of Massage': 491598, 'Evangel University': 177339, 'Evangelical Theological Seminary': 212443, 'Evans Hairstyling College-Cedar City': 230199, 'Evans Hairstyling College-Rexburg': 454935, 'Evans Hairstyling College-St George': 230205, 'Everett Community College': 235149, 'Everglades University': 385619, 'Evergreen Beauty and Barber College-Everett': 446260, 'Evergreen Valley College': 114266, 'Eves College of Hairstyling': 207102, 'Evolve Beauty Academy': 461537, 'Excelsior College': 196680, 'Expertise Cosmetology Institute': 444592, 'Exposito School of Hair Design': 224758, 'Fairfield University': 129242, 'Fairleigh Dickinson University-Florham Campus': 184694, 'Fairleigh Dickinson University-Metropolitan Campus': 184603, 'Fairmont State University': 237367, 'Faith Baptist Bible College and Theological Seminary': 153320, 'Faith International University': 443049, 'Faith Theological Seminary': 212452, 'Faith Theological Seminary and Christian College': 494597, 'Falcon Institute of Health and Science': 493813, 'Family of Faith Christian University': 443058, 'Farmingdale State College': 196042, 'Fashion Institute of Technology': 191126, 'Faulkner University': 101189, 'Faust Institute of Cosmetology-Spirit Lake': 381486, 'Faust Institute of Cosmetology-Storm Lake': 153339, 'Fayette County Career & Technical Institute Practical Nursing Program': 248624, 'Fayette Institute of Technology': 413176, 'Fayetteville State University': 198543, 'Fayetteville Technical Community College': 198534, 'Feather River Community College District': 114433, 'Federico Beauty Institute': 114460, 'Felbry College School of Nursing': 487861, 'Felician University': 184612, 'Ferris State University': 169910, 'Ferrum College': 232089, 'FIDM-Fashion Institute of Design & Merchandising-Los Angeles': 114354, 'FIDM-Fashion Institute of Design & Merchandising-Orange County': 114415, 'FIDM-Fashion Institute of Design & Merchandising-San Diego': 248846, 'FIDM-Fashion Institute of Design & Merchandising-San Francisco': 114390, 'Fielding Graduate University': 114549, 'FINE Mortuary College': 436599, 'Finger Lakes Community College': 191199, 'Finger Lakes Health College of Nursing & Health Sciences': 475422, 'Finger Lakes School of Massage': 460552, 'Finlandia University': 172440, 'Firelands Regional Medical Center School of Nursing': 205090, 'First Class Cosmetology School': 461874, 'First Coast Barber Academy': 484075, 'First Coast Technical College': 137023, 'First Institute of Travel  Inc.': 145099, 'Fisher College': 165802, 'Fisk University': 220181, 'Fitchburg State University': 165820, 'Five Branches University': 114585, 'Five Towns College': 191205, 'Flagler College-St Augustine': 133711, 'Flagler College-Tallahassee': 444990, 'Flagler Technical Institute': 461245, 'Flair Beauty College': 476513, 'Flathead Valley Community College': 180197, 'Fletcher Technical Community College': 160481, 'Flint Hills Technical College': 155052, 'Flint Institute of Barbering Inc': 169947, 'Florence-Darlington Technical College': 218025, 'Florida Academy': 462035, 'Florida Academy of Health & Beauty': 447908, 'Florida Agricultural and Mechanical University': 133650, 'Florida Atlantic University': 133669, 'Florida Barber Academy': 441380, 'Florida Career College': 487384, 'Florida Career College-Boynton Beach': 487445, 'Florida Career College-Hialeah': 487409, 'Florida Career College-Houston Campus': 487490, 'Florida Career College-Jacksonville': 487436, 'Florida Career College-Lauderdale Lakes': 487418, 'Florida Career College-Margate': 487454, 'Florida Career College-Miami': 133997, 'Florida Career College-Orlando': 487472, 'Florida Career College-Tampa': 487427, 'Florida Career College-West Palm Beach': 487393, 'Florida Coastal School of Law': 434715, 'Florida College': 133809, 'Florida College of Integrative Medicine': 434441, 'Florida Education Institute': 441423, 'Florida Gateway College': 135160, 'Florida Gulf Coast University': 433660, 'Florida Institute of Recording Sound and Technology': 476814, 'Florida Institute of Technology': 133881, 'Florida Institute of Technology-Online': 480569, 'Florida Institute of Ultrasound Inc': 133942, 'Florida International Training Institute': 486512, 'Florida International University': 133951, 'Florida Memorial University': 133979, 'Florida National University-Main Campus': 408844, 'Florida Panhandle Technical College': 138284, 'Florida Polytechnic University': 482936, 'Florida School of Massage': 134024, 'Florida School of Traditional Midwifery': 457350, 'Florida Southern College': 134079, 'Florida SouthWestern State College': 133508, 'Florida State College at Jacksonville': 133702, 'Florida State University': 134097, 'Florida Technical College': 134112, 'Florida Vocational Institute': 476939, 'Focus Personal Training Institute': 488253, 'Folsom Lake College': 444219, 'Fond du Lac Tribal and Community College': 380368, 'Fontbonne University': 177418, 'Foothill College': 114716, 'Foothill-De Anza Community College District': 114831, 'Forbes Road Career and Technology Center': 419332, 'Fordham University': 191241, 'Formations Institute of Cosmetology & Barbering': 208044, 'Forrest College': 218043, 'Forsyth Technical Community College': 198552, 'Fort Hays State University': 155061, 'Fort Lewis College': 127185, 'Fort Myers Technical College': 135267, 'Fort Peck Community College': 180212, 'Fort Pierce Beauty Academy': 134228, 'Fort Scott Community College': 155098, 'Fort Valley State University': 139719, 'Fort Worth Beauty School': 224828, 'Fortis College': 371052, 'Fortis College-Baton Rouge': 439738, 'Fortis College-Centerville': 205179, 'Fortis College-Cincinnati': 450067, 'Fortis College-Columbia': 460020, 'Fortis College-Columbus': 450058, 'Fortis College-Cutler Bay': 490975, 'Fortis College-Cuyahoga Falls': 487302, 'Fortis College-Dothan': 455460, 'Fortis College-Foley': 436641, 'Fortis College-Grand Prairie': 458478, 'Fortis College-Indianapolis': 458681, 'Fortis College-Landover': 494843, 'Fortis College-Montgomery': 455488, 'Fortis College-Norfolk': 233329, 'Fortis College-Orange Park': 439792, 'Fortis College-Phoenix': 456180, 'Fortis College-Ravenna': 201399, 'Fortis College-Richmond': 382957, 'Fortis College-Salt Lake City': 456454, 'Fortis College-Smyrna': 372921, 'Fortis Institute': 459958, 'Fortis Institute-Birmingham': 455628, 'Fortis Institute-Cookeville': 418870, 'Fortis Institute-Erie': 216418, 'Fortis Institute-Forty Fort': 249609, 'Fortis Institute-Lawrenceville': 475024, 'Fortis Institute-Nashville': 452124, 'Fortis Institute-Pensacola': 455479, 'Fortis Institute-Port Saint Lucie': 445744, 'Fortis Institute-Scranton': 385503, 'Fortis Institute-Towson': 163347, 'Fortis Institute-Wayne': 183725, 'Fosbre Academy of Hair Design': 488271, 'Fosters Cosmetology College': 175698, 'Fountain of Youth Academy of Cosmetology': 485236, 'Four County Career Center': 457873, 'Four Rivers Career Center': 177436, 'Fox College': 145239, 'Fox Valley Technical College': 238722, 'Framingham State University': 165866, 'Francis Marion University': 218061, 'Francis Tuttle Technology Center': 245999, 'Franciscan Missionaries of Our Lady University': 160074, 'Franciscan School of Theology': 114734, 'Franciscan University of Steubenville': 205957, 'Frank Phillips College': 224891, 'Franklin Academy': 404718, 'Franklin and Marshall College': 212577, 'Franklin College': 150604, 'Franklin County Career and Technology Center': 248633, 'Franklin Hair Academy School of Cosmetology': 483577, 'Franklin Pierce University': 182795, 'Franklin Technology Center Adult Education': 409120, 'Franklin University': 202806, 'Franklin W Olin College of Engineering': 441982, 'Fred D. Learey Technical College': 485351, 'Fred K Marchman Technical College': 459329, 'Fred W Eberle Technical Center': 237844, 'Frederick Community College': 162557, 'Frederick School of Cosmetology': 455017, 'Fredrick and Charles Beauty College': 114761, 'Freed-Hardeman University': 220215, 'Fremont College': 372073, 'French Academy of Cosmetology': 455062, 'Fresno City College': 114789, 'Fresno Pacific University': 114813, 'Friends University': 155089, 'Front Range Community College': 127200, 'Frontier Community College': 403469, 'Frontier Nursing University': 156727, 'Frostburg State University': 162584, 'Full Sail University': 134237, 'Fuller Theological Seminary': 114840, 'Fullerton College': 114859, 'Fulton-Montgomery Community College': 191302, 'Furman University': 218070, 'Futura Career Institute': 476498, 'Future Generations University': 481030, 'Future-Tech Institute': 459310, 'G Skin & Beauty Institute': 407090, 'GA Beauty & Barber School': 485926, 'Gadsden State Community College': 101240, 'Gadsden Technical Institute': 490090, 'Galaxy Medical College': 461254, 'Galen College of Nursing-ARH': 491181, 'Galen College of Nursing-Cincinnati': 452948, 'Galen College of Nursing-Louisville': 156471, 'Galen College of Nursing-San Antonio': 406033, 'Galen College of Nursing-Tampa Bay': 406024, 'Gallaudet University': 131450, 'Galveston College': 224961, 'Gannon University': 212601, 'Garden City Community College': 155104, 'Garden State Science and Technology Institute': 488013, 'Gardner-Webb University': 198561, 'Garnet Career Center': 431169, 'Garrett College': 162609, 'Garrett-Evangelical Theological Seminary': 145275, 'Gary Manuel Aveda Institute': 458131, 'Gaston College': 198570, 'Gateway Community and Technical College': 157438, 'Gateway Community College': 130396, 'GateWay Community College': 105145, 'GateWay Community College-Central City': 246895, 'Gateway Technical College': 238759, 'Gavilan College': 114938, 'GDS Institute': 486099, 'Geisinger Commonwealth School of Medicine': 456542, 'Geisinger-Lewistown Hospital School of Nursing': 460385, 'Gem City College': 145309, 'Gemini School of Visual Arts & Communication': 480912, 'Gemological Institute of America-Carlsbad': 114947, 'Gemological Institute of America-New York': 191311, 'Gene Juarez Academy': 235583, 'Genesee Community College': 191339, 'Genesee Valley BOCES-Practical Nursing Program': 431196, 'Genesis Career College-Cookeville': 220765, 'Genesis Career College-Lebanon': 382780, 'Geneva College': 212656, 'George C Wallace Community College-Dothan': 101286, 'George C Wallace State Community College-Hanceville': 101295, 'George C Wallace State Community College-Selma': 101301, 'George Fox University': 208822, 'George Mason University': 232186, 'George Stone Technical College': 134291, 'George T Baker Aviation Technical College': 134307, 'George Washington University': 131469, 'Georgetown College': 156745, 'Georgetown University': 131496, 'Georgia Career Institute': 138822, 'Georgia College & State University': 139861, 'Georgia Gwinnett College': 447689, 'Georgia Highlands College': 139700, 'Georgia Institute of Cosmetology': 408862, 'Georgia Institute of Technology-Main Campus': 139755, 'Georgia Military College': 485111, 'Georgia Northwestern Technical College': 139384, 'Georgia Piedmont Technical College': 244446, 'Georgia Southern University': 139931, 'Georgia Southwestern State University': 139764, 'Georgia State University': 139940, 'Georgia State University-Perimeter College': 244437, 'Georgian Court University': 184773, 'Gerbers Akron Beauty School': 202888, 'Germanna Community College': 232195, 'Gettysburg College': 212674, 'Glasgow Caledonian New York College': 494551, 'Glen Dow Academy of Hair Design': 235307, 'Glen Oaks Community College': 169974, 'Glendale Career College': 115010, 'Glendale Career College-Brightwood Teachout': 494746, 'Glendale Community College': 104708, 'Glenville State College': 237385, 'Glitz School of Cosmetology': 488651, 'Global Medical & Technical Training Institute': 492935, 'Global Tech College': 493521, 'Gnomon': 449384, 'Goddard College': 230889, 'Gods Bible School and College': 202903, 'Gogebic Community College': 169992, 'Golden Gate University-San Francisco': 115083, 'Golden West College': 115126, 'Goldey-Beacom College': 130989, 'Gonzaga University': 235316, 'Good Samaritan College of Nursing and Health Science': 202912, 'GoodFellas Barber College': 492281, 'Goodwin College': 129154, 'Gordon College': 165936, 'Gordon Cooper Technology Center': 375683, 'Gordon State College': 139968, 'Gordon-Conwell Theological Seminary': 165945, 'Goshen College': 150668, 'Goshen School of Cosmetology': 491729, 'Goucher College': 162654, "Gould's Academy": 486530, 'Governors State University': 145336, 'Grabber School of Hair Design': 363679, 'Grace Christian University': 170000, 'Grace College and Theological Seminary': 150677, 'Grace College of Divinity': 461528, 'Grace International Beauty School': 483841, 'Grace Mission University': 481058, 'Grace School of Theology': 481401, 'Graceland University-Lamoni': 153366, 'Graduate Theological Union': 115214, 'Grady Health System Professional Schools': 139746, 'Graham Hospital School of Nursing': 145354, 'Grambling State University': 159009, 'Grand Canyon University': 104717, 'Grand Rapids Community College': 170055, 'Grand River Technical School': 176983, 'Grand Valley State University': 170082, 'Grand View University': 153375, 'Granite State College': 183257, 'Grantham University': 442569, 'Gratz College': 212771, 'Grays Harbor College': 235334, 'Grayson College': 225070, 'Great Basin College': 182306, 'Great Bay Community College': 183150, 'Great Falls College Montana State University': 180249, 'Great Lakes Christian College': 170091, 'Great Lakes Institute of Technology': 213181, 'Great Lakes Truck Driving School': 490072, 'Great Oaks Career Campuses': 202949, 'Great Plains Technology Center': 364548, 'Greater Altoona Career & Technology Center': 383367, 'Greater Johnstown Career and Technology Center': 418454, 'Greater Lowell Technical School': 382416, 'Green Country Technology Center': 428019, 'Green Mountain College': 230898, 'Green River College': 235343, 'Greene County Career and Technology Center': 260363, 'Greene County Vocational School District': 365240, 'Greenfield Community College': 165981, 'Greensboro College': 198598, 'Greenville Technical College': 218113, 'Greenville University': 145372, 'Grinnell College': 153384, 'Grossmont College': 115296, 'Grossmont-Cuyamaca Community College District': 115287, 'Grove City College': 212805, 'Guam Community College': 240745, 'Guidance College': 494560, 'Guilford College': 198613, 'Guilford Technical Community College': 198622, 'Gulf Coast State College': 134343, 'Gupton Jones College of Funeral Service': 139995, 'Gurnick Academy of Medical Arts': 459213, 'Gustavus Adolphus College': 173647, "Guy's Shreveport Academy of Cosmetology Inc": 159027, 'Gwinnett College': 436632, 'Gwinnett College-Lilburn': 140003, 'Gwinnett College-Marietta Campus': 444714, 'Gwinnett College-Sandy Springs': 425250, 'Gwinnett Institute': 490559, 'Gwinnett Technical College': 140012, 'Gwynedd Mercy University': 212832, 'H Councill Trenholm State Community College': 102313, 'Hacienda La Puente Adult Education': 383084, 'Hagerstown Community College': 162690, 'Hair Academy II': 436030, 'Hair Academy Inc-New Carrollton': 163541, 'Hair Academy School of Barbering & Beauty': 488262, 'Hair Expressions Academy': 447971, 'Hair Professionals Career College': 145424, 'Hair Professionals School of Cosmetology': 145433, 'Hairmasters Institute of Cosmetology': 367051, 'Halifax Community College': 198640, 'Hallmark University': 225201, 'Hamilton College': 191515, 'Hamilton Technical College': 153427, 'Hamline University': 173665, 'Hampden-Sydney College': 232256, 'Hampshire College': 166018, 'Hampton University': 232265, 'Hamrick School': 369950, 'Hands on Therapy': 455327, 'Hannah E Mullins School of Practical Nursing': 202985, 'Hannibal-LaGrange University': 177542, 'Hanover College': 150756, 'Harcum College': 212869, 'Hardin-Simmons University': 225247, 'Harding University': 107044, 'Harford Community College': 162706, 'Harmony Health Care Institute': 490382, 'Harris School of Business-Cherry Hill Campus': 184870, 'Harris School of Business-Danbury': 489399, 'Harris School of Business-Dover Campus': 444200, 'Harris School of Business-Linwood Campus': 448983, 'Harris School of Business-Sanford Campus': 433970, 'Harris School of Business-Upper Darby Campus': 460598, 'Harris School of Business-Voorhees Campus': 185332, 'Harris School of Business-Wilmington Campus': 441362, 'Harris-Stowe State University': 177551, 'Harrisburg Area Community College': 212878, 'Harrisburg University of Science and Technology': 446640, 'Hartford Seminary': 129491, 'Hartnell College': 115393, 'Hartwick College': 191533, 'Harvard University': 166027, 'Harvey Mudd College': 115409, 'Haskell Indian Nations University': 155140, 'Hastings Beauty School': 417600, 'Hastings College': 181127, 'Haverford College': 212911, 'Hawaii Community College': 383190, 'Hawaii Institute of Hair Design': 141608, 'Hawaii Medical College': 460756, 'Hawaii Pacific University': 141644, 'Hawkeye Community College': 153445, 'Hays Academy of Hair Design': 478917, 'Haywood Community College': 198668, 'Hazard Community and Technical College': 156790, 'Hazelden Betty Ford Graduate School of Addiction Studies': 173683, 'Hazleton Area Career Center': 418612, 'HCI College': 490054, 'HDS Truck Driving Institute': 439668, 'Headlines Academy Inc': 219125, 'Headmasters School of Hair Design': 247010, 'Healing Arts Center': 455071, 'Healing Arts Institute': 381866, 'Healing Hands School of Holistic Health': 454795, 'Healing Mountain Massage School': 441830, 'Health And Style Institute': 456968, 'Health and Technology Training Institute': 493585, 'Health Works Institute': 444644, 'Health-Tech Institute of Memphis': 493752, 'Healthcare Career College': 450960, 'Healthcare Training Institute': 446303, 'Heartland Community College': 384342, 'Hebrew College': 166045, 'Hebrew Theological College': 145497, 'Hebrew Union College-Jewish Institute of Religion': 203067, 'Heidelberg University': 203085, 'Helena College University of Montana': 180276, 'Helene Fuld College of Nursing': 191597, 'Hellenic College-Holy Cross Greek Orthodox School of Theology': 166054, 'Helms College': 481155, 'Henderson Community College': 156851, 'Henderson State University': 107071, 'Hendrix College': 107080, 'Hennepin Technical College': 173708, 'Henrico County-Saint Marys Hospital School of Practical Nursing': 431266, 'Henry Ford College': 170240, 'Heritage Bible College': 198677, 'Heritage Christian University': 101453, 'Heritage University': 235422, 'Herkimer County BOCES-Practical Nursing Program': 431275, 'Herkimer County Community College': 191612, 'Herzing University-Akron': 200785, 'Herzing University-Atlanta': 140340, 'Herzing University-Birmingham': 101365, 'Herzing University-Brookfield': 459851, 'Herzing University-Kenner': 433536, 'Herzing University-Kenosha': 459842, 'Herzing University-Madison': 240392, 'Herzing University-Minneapolis': 174154, 'Herzing University-Toledo': 457022, 'Herzing University-Winter Park': 386472, 'Hesston College': 155177, 'Hibbing Community College': 173735, 'High Desert Medical College': 484002, 'High Plains Technology Center': 208053, 'High Point University': 198695, 'High Tech High Graduate School of Education': 485403, 'Highland Community College': 155186, 'Highlands College of Montana Tech': 180081, 'Highline College': 235431, 'Hilbert College': 191621, 'Hill College': 225371, 'Hillsborough Community College': 134495, 'Hillsdale Beauty College': 168555, 'Hillsdale College': 170286, 'Hilltop Beauty School': 115658, 'Hillyard Technical Center': 178466, 'Hinds Community College': 175786, 'Hinton Barber and Beauty College': 480000, 'Hiram College': 203128, 'Hiwassee College': 220312, 'Hobart Institute of Welding Technology': 203146, 'Hobart William Smith Colleges': 191630, 'Hobe Sound Bible College': 134510, 'Hocking College': 203155, 'Hodges University': 367884, 'Hofstra University': 191649, 'Hogan Institute of Cosmetology and Esthetics': 490407, 'Hohokus School of Trade and Technical Sciences': 184746, 'Holistic Massage Training Institute': 461379, 'Hollins University': 232308, 'Hollywood Institute': 443234, 'Hollywood Institute of Beauty Careers': 134529, 'Hollywood Institute of Beauty Careers-Casselberry': 485388, 'Hollywood Institute of Beauty Careers-West Palm Beach': 485379, 'Holmes Community College': 175810, 'Holy Apostles College and Seminary': 129534, 'Holy Cross College': 150774, 'Holy Family College': 239743, 'Holy Family University': 212984, 'Holy Name Medical Center-Sister Claire Tynan School of Nursing': 184968, 'Holy Names University': 115728, 'Holyoke Community College': 166133, 'Homestead Schools': 457086, 'Hondros College of Nursing': 203386, 'Honolulu Community College': 141680, 'Hood College': 162760, 'Hood Theological Seminary': 443076, 'Hope College': 170301, 'Hope College of Arts and Sciences': 488332, 'Hope International University': 120537, 'Hopkinsville Community College': 156860, 'Horizon University': 457226, 'Horry-Georgetown Technical College': 218140, 'Hoss Lee Academy': 488411, 'Hot Springs Beauty College': 107099, 'Houghton College': 191676, 'Housatonic Community College': 129543, 'House of Heavilin Beauty College-Academy of Beauty Professionals': 489122, 'House of Heavilin Beauty College-Blue Springs': 176716, 'House of Heavilin Beauty College-Kansas City': 177588, 'House of Heavilin Beauty College-Raymore': 421771, 'Houston Baptist University': 225399, 'Houston Barber School': 493743, 'Houston Community College': 225423, 'Houston Graduate School of Theology': 246345, 'Houston International College Cardiotech Ultrasound School': 458034, 'Houston School of Carpentry': 492157, 'Houston Training School-Gulfgate': 383792, 'Houston Training School-Main Campus': 380067, 'Houston Training Schools-Gessner': 484996, 'Howard College': 225520, 'Howard Community College': 162779, 'Howard Payne University': 225548, 'Howard University': 131520, "HSHS St. John's Hospital School of Clinical Laboratory Science": 364122, 'Hudson County Community College': 184995, 'Hudson Valley Community College': 191719, 'Huertas College': 242112, 'Hult International Business School': 164368, 'Humacao Community College': 242121, 'Humboldt State University': 115755, 'Humphreys University-Stockton and Modesto Campuses': 115773, 'Hunter Business School': 191728, 'Huntingdon College': 101435, 'Huntingdon County Career and Technology Center': 440217, 'Huntington Junior College': 237437, 'Huntington School of Beauty Culture': 377643, 'Huntington University': 150941, 'Huntington University of Health Sciences': 488068, 'Huntsville Bible College': 449348, 'Hussian College School of Art': 212993, 'Hussian College-Daymar College Bowling Green': 363439, 'Hussian College-Daymar College Clarksville': 368443, 'Hussian College-Daymar College Columbus': 205559, 'Hussian College-Daymar College Murfreesboro': 444255, 'Hussian College-Daymar College Nashville': 220002, 'Hussian College-Studio School Los Angeles': 486965, 'Husson University': 487524, 'Huston-Tillotson University': 225575, 'Hutchinson Community College': 155195, 'HVAC Technical Institute': 486345, 'Hypnosis Motivation Institute': 368771, 'IBMC College': 372329, 'IBS School of Cosmetology and Massage': 491738, 'Icahn School of Medicine at Mount Sinai': 193405, 'ICOHS College': 491659, 'ICPR Junior College-Arecibo': 242130, 'ICPR Junior College-General Institutional': 243841, 'ICPR Junior College-Manati': 460677, 'ICPR Junior College-Mayaguez': 242149, 'Idaho College of Osteopathic Medicine': 493947, 'Idaho State University': 142276, 'Ideal Beauty Academy': 449597, 'IGlobal University': 483780, 'Iliff School of Theology': 127273, 'Ilisagvik College': 434584, 'Illinois Central College': 145682, 'Illinois College': 145691, 'Illinois College of Optometry': 145628, 'Illinois Eastern Community College-System Office': 443368, 'Illinois Institute of Technology': 145725, 'Illinois Media School': 419253, 'Illinois Media School-Chicago Campus': 460145, 'Illinois State University': 145813, 'Illinois Valley Community College': 145831, 'Illinois Wesleyan University': 145646, 'Image Maker Beauty Institute': 487922, 'Imagine-Paul Mitchell Partner School': 106908, 'Immaculata University': 213011, 'Immokalee Technical College': 457387, 'Imperial Valley College': 115861, 'Independence Community College': 155201, 'Independence University': 465812, 'Independent Training & Apprenticeship Program': 491880, 'Indian Capital Technology Center-Muskogee': 418296, 'Indian Hills Community College': 153472, 'Indian River State College': 134608, 'Indiana County Technology Center': 418560, 'Indiana Institute of Technology': 151290, 'Indiana Institute of Technology-College of Professional Studies': 492962, 'Indiana State University': 151324, 'Indiana University of Pennsylvania-Main Campus': 213020, 'Indiana University-Bloomington': 151351, 'Indiana University-East': 151388, 'Indiana University-Kokomo': 151333, 'Indiana University-Northwest': 151360, 'Indiana University-Purdue University-Indianapolis': 151111, 'Indiana University-South Bend': 151342, 'Indiana University-Southeast': 151379, 'Indiana Wellness College': 488420, 'Indiana Wesleyan University-Marion': 151801, 'Indiana Wesleyan University-National & Global': 488679, 'Industrial Management Training Institute': 415057, 'Industrial Technical College': 444671, 'Infinity College': 485564, 'Inland Massage Institute': 451635, 'Inner State Beauty School': 388663, 'Innovate Salon Academy': 492731, 'Innovations Design Academy': 457554, 'Installer Institute': 491932, 'Institucion Chaviano de Mayaguez': 376288, 'Institute for Business and Technology': 115931, 'Institute for Clinical Social Work': 145886, 'Institute for Doctoral Studies in the Visual Arts': 462044, 'Institute for Therapeutic Massage': 441548, 'Institute of Advanced Medical Esthetics': 458122, 'Institute of American Indian and Alaska Native Culture and Arts Development': 187745, 'Institute of Beauty Careers': 240879, 'Institute of Beauty Occupation and Technology Course': 444680, 'Institute of Beauty Occupations and Technology Course-San Sebastian': 489414, 'Institute of Buddhist Studies': 489335, 'Institute of Clinical Acupuncture & Oriental Med': 444699, 'Institute of Culinary Education': 457819, 'Institute of Health & Technology': 448017, 'Institute of Health Sciences': 481207, 'Institute of Lutheran Theology': 493363, 'Institute of Medical Careers': 461218, 'Institute of Medical Ultrasound': 491570, 'Institute of Production and Recording': 454616, 'Institute of Professional Careers': 448044, 'Institute of Taoist Education and Acupuncture': 454838, 'Institute of Technology': 441663, 'Institute of World Politics': 455804, 'Instituto de Banca y Comercio Inc': 242422, 'Instituto Educativo Premier': 451501, 'Instituto Tecnologico de Puerto Rico-Recinto de Guayama': 242556, 'Instituto Tecnologico de Puerto Rico-Recinto de Manati': 242042, 'Instituto Tecnologico de Puerto Rico-Recinto de Ponce': 242565, 'Instituto Tecnologico de Puerto Rico-Recinto de San Juan': 242583, 'Integrity College of Health': 483373, 'Intellitec College-Colorado Springs': 128179, 'Intellitec College-Grand Junction': 128188, 'Inter American University of Puerto Rico-Aguadilla': 242626, 'Inter American University of Puerto Rico-Arecibo': 242635, 'Inter American University of Puerto Rico-Barranquitas': 242644, 'Inter American University of Puerto Rico-Bayamon': 242705, 'Inter American University of Puerto Rico-Central Office': 242671, 'Inter American University of Puerto Rico-Fajardo': 242680, 'Inter American University of Puerto Rico-Guayama': 242699, 'Inter American University of Puerto Rico-Metro': 242653, 'Inter American University of Puerto Rico-Ponce': 242662, 'Inter American University of Puerto Rico-San German': 242617, 'Inter American University of Puerto Rico-School of Law': 242723, 'Inter American University of Puerto Rico-School of Optometry': 404222, 'Interactive College of Technology': 440776, 'Interactive College of Technology-Chamblee': 138655, 'Interactive College of Technology-Gainesville': 442435, 'Interactive College of Technology-Morrow': 138664, 'Interactive College of Technology-Newport': 367103, 'InterAmerican Technical Institute': 483869, 'InterCoast Colleges-Fairfield': 481960, 'InterCoast Colleges-Rancho Cordova': 457208, 'InterCoast Colleges-Riverside': 442888, 'InterCoast Colleges-Santa Ana': 366289, 'InterCoast Colleges-West Covina': 443571, 'Interdenominational Theological Center': 140146, 'Interior Designers Institute': 116226, 'International Academy': 134714, 'International Academy of Style': 457785, 'International Air and Hospitality Academy': 235501, 'International Baptist College and Seminary': 436614, 'International Barber College': 491686, 'International Beauty College': 431284, 'International Beauty Education Center': 488378, 'International Beauty School 4': 238005, 'International Business College-El Paso': 225788, 'International Business College-Fort Wayne': 151458, 'International Business College-Indianapolis': 151467, 'International College of Beauty Arts & Sciences': 462336, 'International College of Broadcasting': 203289, 'International College of Cosmetology': 461175, 'International Cosmetology Academy': 455053, 'International Culinary Arts and Sciences Institute': 453297, 'International Culinary Center-California': 475097, 'International Diving Institute': 488925, 'International Hair and Barber Academy': 485528, 'International Institute for Restorative Practices': 448691, 'International Institute of Cosmetology': 457341, 'International Salon and Spa Academy': 127316, 'International School of Beauty Inc': 113449, 'International School of Cosmetology-Toni & Guy Hairdressing Academy': 480347, 'International School of Skin Nailcare & Massage Therapy': 365091, 'International Sports Sciences Association': 485519, 'International Technical College': 242750, 'International Technological University': 443128, 'International Training Careers': 439686, 'Inver Hills Community College': 173799, 'Iona College': 191931, 'Iowa Central Community College': 153524, 'Iowa Lakes Community College': 153533, 'Iowa School of Beauty-Des Moines': 153597, 'Iowa School of Beauty-Marshalltown': 153171, 'Iowa School of Beauty-Ottumwa': 154165, 'Iowa School of Beauty-Sioux City': 154457, 'Iowa State University': 153603, 'Iowa Wesleyan University': 153621, 'Iowa Western Community College': 153630, 'Irell & Manella Graduate School of Biological Sciences at City of Hope': 441238, "Irene's Myomassology Institute": 443137, 'Irvine Valley College': 116439, 'Isabella Graham Hart School of Practical Nursing': 191940, 'Island Drafting and Technical Institute': 191959, 'Isothermal Community College': 198710, 'Itasca Community College': 173805, 'Itawamba Community College': 175829, 'Ithaca College': 191968, 'ITI Technical College': 159197, 'IVAEM College': 438984, 'Ivy Tech Community College': 150987, 'IYRS School of Technology & Trades': 437237, 'J D Academy of Salon and Spa': 481474, 'J F Ingram State Technical College': 101471, 'J Michael Harrold Beauty Academy': 150765, 'J Sargeant Reynolds Community College': 232414, "J's Barber College": 490416, 'J. F. Drake State Community and Technical College': 101462, 'Jackson College': 170444, 'Jackson State Community College': 220400, 'Jackson State University': 175856, 'Jacksonville College-Main Campus': 225876, 'Jacksonville State University': 101480, 'Jacksonville University': 134945, 'James A Rhodes State College': 203678, 'James Madison University': 232423, 'James Rumsey Technical Institute': 237473, 'James Sprunt Community College': 198729, 'Jamestown Business College': 192004, 'Jamestown Community College': 191986, 'Jarvis Christian College': 225885, "Jay's Technical Institute": 443146, "JB's Hair Design and Barber College": 483276, 'Jean Madeline Aveda Institute': 414540, 'Jefferson College': 177676, 'Jefferson Community and Technical College': 156921, 'Jefferson Community College': 192022, 'Jefferson County Dubois Area Vocational Technical Practical Nursing Program': 418445, 'Jefferson Lewis BOCES-Practical Nursing Program': 417886, 'Jefferson Regional Medical Center School of Nursing': 107123, 'Jefferson State Community College': 101505, 'Jenks Beauty College': 207704, 'Jenny Lea Academy of Cosmetology': 248192, 'Jersey College': 455196, 'Jewish Theological Seminary of America': 192040, 'JFK Muhlenberg Harold B. and Dorothy A. Snyder Schools-School of Imaging': 185651, 'JFK Muhlenberg Harold B. and Dorothy A. Snyder Schools-School of Nursing': 185679, 'Jna Institute of Culinary Arts': 419341, 'Joe Kubert School of Cartoon and Graphic Art': 185174, 'Joffrey Ballet School': 188696, 'John A Gupton College': 220464, 'John A Logan College': 146205, 'John Amico School of Hair Design': 401764, 'John Brown University': 107141, 'John C Calhoun State Community College': 101514, 'John Carroll University': 203368, 'John D Rockefeller IV Career Center': 446349, 'John F. Kennedy University': 116712, 'John Jay Beauty College': 159328, "John Paolo's Xtreme Beauty Institute-Goldwell Product Artistry": 455239, 'John Paul the Great Catholic University': 462354, 'John Tyler Community College': 232450, 'John Wesley International Barber and Beauty College': 428125, 'John Wood Community College': 146278, "Johnny Matthew's Hairdressing Training School": 491242, 'Johns Hopkins University': 162928, 'Johnson & Wales University-Charlotte': 445708, 'Johnson & Wales University-Denver': 439288, 'Johnson & Wales University-North Miami': 414823, 'Johnson & Wales University-Online': 460349, 'Johnson & Wales University-Providence': 217235, 'Johnson C Smith University': 198756, 'Johnson College': 213233, 'Johnson County Community College': 155210, 'Johnson University': 220473, 'Johnson University Florida': 132879, 'Johnston Community College': 198774, 'Jolie Hair and Beauty Academy-Hazleton': 210474, 'Jolie Hair and Beauty Academy-Ludlow': 431099, 'Jolie Hair and Beauty Academy-Northfield': 478661, 'Jolie Hair and Beauty Academy-Wilkes-Barre': 213215, 'Jolie Health & Beauty Academy-Cherry Hill': 486734, 'Jolie Health and Beauty Academy-Turnersville': 484321, 'Joliet Junior College': 146296, 'Jones County Junior College': 175883, 'Jose Maria Vargas University': 461281, "Josef's School of Hair  Skin & Body-Fargo": 456551, "Josef's School of Hair  Skin & Body-Grand Forks": 200110, 'Joseph F McCloskey School of Nursing': 215479, "Joseph's College Cosmetology": 181190, 'Judson College': 101541, 'Judson University': 146339, 'Jung Tao School of Classical Chinese Medicine': 461139, 'Juniata College': 213251, 'Jupiter Beauty Academy': 484057, 'JZ Trend Academy Paul Mitchell Partner School': 200387, 'K & G 5 Star Barber College': 485810, 'Kaizen Beauty Academy': 481313, 'Kalamazoo College': 170532, 'Kalamazoo Valley Community College': 170541, 'Kankakee Community College': 146348, 'Kansas Christian College': 155308, 'Kansas City Art Institute': 177746, 'Kansas City Kansas Community College': 155292, 'Kansas City University of Medicine and Biosciences': 179812, 'Kansas City University of Medicine and Biosciences-Joplin': 490601, 'Kansas State University': 155399, 'Kansas Wesleyan University': 155414, 'Kapiolani Community College': 141796, 'Kaskaskia College': 146366, 'Kauai Community College': 141802, 'KC Beauty Academy': 494658, "KC's School of Hair Design": 374343, 'KCK Beauty & Barber Academy': 492652, 'KD Conservatory College of Film and Dramatic Arts': 225991, 'Kean University': 185262, 'Keck Graduate Institute': 440031, 'Keene Beauty Academy': 182892, 'Keene State College': 183062, 'Kehilath Yakov Rabbinical Seminary': 192165, 'Keiser University-Ft Lauderdale': 135081, 'Kellogg Community College': 170550, 'Kennebec Valley Community College': 161192, 'Kennesaw State University': 486840, 'Kenneth Shuler School of Cosmetology and Nails-Columbia': 218195, 'Kenneth Shuler School of Cosmetology-Columbia': 445850, 'Kenneth Shuler School of Cosmetology-Florence': 460011, 'Kenneth Shuler School of Cosmetology-Goose Creek': 489159, 'Kenneth Shuler School of Cosmetology-Greenville': 467906, 'Kenneth Shuler School of Cosmetology-North Augusta': 218159, 'Kenneth Shuler School of Cosmetology-Rock Hill': 432117, 'Kenneth Shuler School of Cosmetology-Spartanburg': 445841, "Kenny's Academy of Barbering": 488439, "Kenny's Beauty Academy": 493497, 'Kenrick Glennon Seminary': 177816, 'Kent State University at Ashtabula': 203447, 'Kent State University at East Liverpool': 203456, 'Kent State University at Geauga': 203526, 'Kent State University at Kent': 203517, 'Kent State University at Salem': 203492, 'Kent State University at Stark': 203465, 'Kent State University at Trumbull': 203474, 'Kent State University at Tuscarawas': 203483, 'Kentucky Christian University': 157100, 'Kentucky Community and Technical College System': 157854, 'Kentucky Horseshoeing School': 487904, 'Kentucky Mountain Bible College': 157030, 'Kentucky State University': 157058, 'Kentucky Wesleyan College': 157076, 'Kenyon College': 203535, 'Keser Torah-Mayan Hatalmud': 461847, 'Kettering College': 203544, 'Kettering University': 169983, 'Keuka College': 192192, 'Keune Academy by 124': 457475, 'Keweenaw Bay Ojibwa Community College': 461315, 'Keystone College': 213303, 'Kiamichi Technology Center-McAlester': 375726, 'Kilgore College': 226019, 'King University': 220516, "King's College": 213321, 'Kirksville Area Technical Center': 417628, 'Kirkwood Community College': 153737, 'Kirtland Community College': 170587, 'Kishwaukee College': 146418, 'Klamath Community College': 428392, 'Knox College': 146427, 'Knox County Career Center': 375373, 'Kor Beauty Academy': 490452, 'Kutztown University of Pennsylvania': 213349, 'Kuyper College': 171881, 'L Makeup Institute': 490717, "L'esprit Academy": 457633, 'L3 Commercial Training Solutions Airline Academy': 429012, 'La Belle Beauty Academy': 383163, 'La Belle Beauty School': 135142, 'La James College of Hairstyling and Cosmetology': 153773, 'La James International College-Cedar Falls': 153746, 'La James International College-Davenport': 154332, 'La James International College-East Moline': 143695, 'La James International College-Ft Dodge': 153782, 'La James International College-Iowa City': 154341, 'La James International College-Johnston': 153764, 'La Roche University': 213358, 'La Salle University': 213367, 'La Sierra University': 117627, "La'James International College": 180771, 'LaBarberia Institute of Hair': 483920, 'Labette Community College': 155450, 'Laboure College': 165264, 'Lac Courte Oreilles Ojibwe College': 260372, 'Lackawanna College': 213376, 'Lafayette College': 213385, 'LaGrange College': 140234, 'Laguna College of Art and Design': 117168, 'Lake Area Technical Institute': 219143, 'Lake Career and Technical Center': 177870, 'Lake Erie College': 203580, 'Lake Erie College of Osteopathic Medicine': 407629, 'Lake Forest College': 146481, 'Lake Forest Graduate School of Management': 146490, 'Lake Land College': 146506, 'Lake Michigan College': 170620, 'Lake Region State College': 200192, 'Lake Superior College': 173461, 'Lake Superior State University': 170639, 'Lake Tahoe Community College': 117195, 'Lake Technical College': 135179, 'Lake Washington Institute of Technology': 235699, 'Lake-Sumter State College': 135188, 'Lakeland Community College': 203599, 'Lakeland University': 238980, 'Lakes Region Community College': 183123, 'Lakeshore Technical College': 239008, 'Lakeview College of Nursing': 146533, 'Lakewood School of Therapeutic Massage': 451291, 'Lamar Community College': 127389, 'Lamar Institute of Technology': 441760, 'Lamar State College-Orange': 226107, 'Lamar State College-Port Arthur': 226116, 'Lamar University': 226091, 'Lamson Institute': 456214, 'Lancaster Beauty School': 117238, 'Lancaster Bible College': 213400, 'Lancaster County Career and Technology Center': 418533, 'Lancaster School of Cosmetology & Therapeutic Bodywork': 213455, 'Lancaster Theological Seminary': 213446, 'Lander University': 218229, 'Landmark College': 247649, 'Lane College': 220598, 'Lane Community College': 209038, 'Laney College': 117247, 'Langston University': 207209, 'Lanier Technical College': 140243, 'Lansdale School of Business': 213473, 'Lansdale School of Cosmetology Inc': 213491, 'Lansing Community College': 170657, 'Laramie County Community College': 240620, 'Laredo Beauty College Inc': 226125, 'Laredo CHI Academy Beauty School': 486503, 'Laredo College': 226134, "Larry's Barber College": 476489, 'Las Positas College': 366401, 'Las Vegas College': 182148, 'LaSalle Tech': 160472, 'Lasell University': 166391, 'Lassen Community College': 117274, 'Latin Beauty Academy': 485485, 'Laurel Business Institute': 250027, 'Laurel Technical Institute': 408729, 'Laurus College': 454786, 'Lawrence & Company College of Cosmetology': 483957, 'Lawrence Memorial Hospital School of Nursing': 166407, 'Lawrence Technological University': 170675, 'Lawrence University': 239017, 'Lawson State Community College': 101569, 'LDS Business College': 230418, 'Le Moyne College': 192323, 'Le Moyne-Owen College': 220604, 'Learnet Academy Inc': 483221, 'Learning Bridge Career Institute': 488138, 'Lebanon College of Cosmetology': 488235, 'Lebanon County Area Vocational Technical School': 418542, 'Lebanon Valley College': 213507, 'Lee College': 226204, 'Lee Professional Institute': 484172, 'Lee University': 220613, 'Leech Lake Tribal College': 413626, 'Lees-McRae College': 198808, 'Leeward Community College': 141811, 'LeGrand Institute of Cosmetology Inc': 444228, 'Lehigh Carbon Community College': 213525, 'Lehigh University': 213543, 'Lehigh Valley Barber School': 491677, 'Lenape Technical School Practical Nursing Program': 418515, 'Lenoir Community College': 198817, 'Lenoir-Rhyne University': 198835, 'Leon Studio One School of Beauty Knowledge': 441618, 'Leons Beauty School Inc': 198844, 'Lesley University': 166452, 'Leston College': 444732, 'LeTourneau University': 226231, 'Levittown Beauty Academy': 213552, 'Lewis & Clark College': 209056, 'Lewis and Clark Community College': 146603, 'Lewis University': 146612, 'Lewis-Clark State College': 142328, 'Lex La-Ray Technical Center': 177931, 'Lexington Healing Arts Academy': 450632, 'Lexington Theological Seminary': 157207, 'Lia Schorr Institute of Cosmetic Skin Care Training': 427335, 'Liberty Junior College': 455956, 'Liberty University': 232557, 'Liceo de Arte y Tecnologia': 242820, 'Liceo de Arte-Dise-O y Comercio': 376330, 'Life Chiropractic College West': 117520, 'Life Pacific University': 117104, 'Life University': 140252, "Lil Lou's Beauty and Barber College LLC": 475574, "Lil Lou's Beauty and Barber College-Hammond": 494029, 'LIM College': 192271, 'Limestone College': 218238, 'Lincoln Christian University': 146667, 'Lincoln College': 146676, 'Lincoln College of Technology-Columbia': 163028, 'Lincoln College of Technology-Denver': 126951, 'Lincoln College of Technology-Grand Prairie': 226277, 'Lincoln College of Technology-Indianapolis': 151661, 'Lincoln College of Technology-Marietta': 434159, 'Lincoln College of Technology-Melrose Park': 146700, 'Lincoln College of Technology-Nashville': 221148, 'Lincoln Land Community College': 146685, 'Lincoln Law School of Sacramento': 117548, 'Lincoln Memorial University': 220631, 'Lincoln Technical Institute-Allentown': 213570, 'Lincoln Technical Institute-East Windsor': 129181, 'Lincoln Technical Institute-Iselin': 184056, 'Lincoln Technical Institute-Lincoln': 433101, 'Lincoln Technical Institute-Mahwah': 420343, 'Lincoln Technical Institute-Moorestown': 374574, 'Lincoln Technical Institute-New Britain': 129923, 'Lincoln Technical Institute-Paramus': 442073, 'Lincoln Technical Institute-Philadelphia': 213589, 'Lincoln Technical Institute-Shelton': 445911, 'Lincoln Technical Institute-Somerville': 165556, 'Lincoln Technical Institute-South Plainfield': 184427, 'Lincoln Technical Institute-Union': 185396, 'Lincoln Technical Institute-Whitestone': 449320, 'Lincoln Trail College': 403478, 'Lincoln University': 213598, 'Lindenwood University': 177968, 'Lindsey Hopkins Technical College': 135294, 'Lindsey Institute of Cosmetology': 461722, 'Lindsey Wilson College': 157216, 'Linfield College-McMinnville Campus': 209065, 'Linfield College-Online and Continuing Education': 437325, 'Linfield College-School of Nursing': 437316, 'Linn-Benton Community College': 209074, 'Lipscomb University': 219976, 'Little Big Horn College': 180328, 'Little Priest Tribal College': 434016, 'Lively Technical College': 135276, 'Living Arts College': 421832, 'Livingstone College': 198862, 'Lock Haven University': 213613, 'Logan University': 177986, 'Loma Linda University': 117636, 'Lone Star College System': 227182, 'Long Beach City College': 117645, 'Long Island Beauty School-Hauppauge': 383297, 'Long Island Beauty School-Hempstead': 192484, 'Long Island Business Institute': 192509, 'Long Island Nail Skin & Hair Institute': 461838, 'Long Island University': 192448, 'Longwood University': 232566, 'Longy School of Music of Bard College': 166489, 'Lorain County Community College': 203748, 'Lorain County Joint Vocational School District': 409591, 'Loraines Academy & Spa': 135337, 'Loras College': 153825, 'Lord Fairfax Community College': 232575, 'Lorenzo Walker Technical College': 133155, 'Los Angeles Academy of Figurative Art': 490124, 'Los Angeles City College': 117788, 'Los Angeles College of Music': 446385, 'Los Angeles Community College District Office': 117681, 'Los Angeles County College of Nursing and Allied Health': 117803, 'Los Angeles Film School': 436429, 'Los Angeles Harbor College': 117690, 'Los Angeles Mission College': 117867, 'Los Angeles ORT College-Los Angeles Campus': 368780, 'Los Angeles Pacific College': 400558, 'Los Angeles Pacific University': 474863, 'Los Angeles Pierce College': 117706, 'Los Angeles Southwest College': 117715, 'Los Angeles Trade Technical College': 117724, 'Los Angeles Valley College': 117733, 'Los Medanos College': 117894, 'Los Rios Community College District Office': 117900, 'Lotus School of Integrated Professions': 494621, 'Louisburg College': 198871, 'Louisiana Academy of Beauty': 159531, 'Louisiana College': 159568, 'Louisiana Culinary Institute': 449612, 'Louisiana Delta Community College': 483212, 'Louisiana State University and Agricultural & Mechanical College': 159391, 'Louisiana State University Health Sciences Center-New Orleans': 159373, 'Louisiana State University Health Sciences Center-Shreveport': 435000, 'Louisiana State University-Alexandria': 159382, 'Louisiana State University-Eunice': 159407, 'Louisiana State University-Shreveport': 159416, 'Louisiana Tech University': 159647, 'Louisville Presbyterian Theological Seminary': 157298, 'Lourdes University': 203757, 'Love Beauty School Inc': 458007, 'Lowell Academy Hairstyling Institute': 166498, 'Lower Columbia College': 235750, 'Loyola Marymount University': 117946, 'Loyola University Chicago': 146719, 'Loyola University Maryland': 163046, 'Loyola University New Orleans': 159656, 'Lu Ross Academy': 117955, 'Lubbock Christian University': 226383, 'Luckes Beauty Academy LLC': 483726, 'Luna Community College': 363633, 'Lurleen B Wallace Community College': 101602, 'Luther College': 153834, 'Luther Rice College & Seminary': 135364, 'Luther Seminary': 173896, 'Lutheran School of Nursing': 178004, 'Lutheran School of Theology at Chicago': 146728, 'Luzerne County Community College': 213659, 'Lycoming College': 213668, "Lyle's College of  Beauty": 118143, "Lyle's College of Beauty": 118134, 'Lynn University': 132657, 'Lynnes Welding Training': 482246, 'Lynnes Welding Training-Bismarck': 492379, 'Lyon College': 106342, 'Lytles Redwood Empire Beauty College Inc': 118161, 'M J Murphy Beauty College of Mount Pleasant': 170736, 'M T Training Center': 481003, 'M-DCPS The English Center': 441414, 'Macalester College': 173902, 'MacCormac College': 146816, 'Machzikei Hadath Rabbinical College': 192624, 'MacMurray College': 146825, 'Macomb Community College': 170790, 'Madison Adult Career Center': 375407, 'Madison Area Technical College': 238263, 'Madison Media Institute': 364168, 'Madison Media Institute-Rockford Career College': 148399, 'Madison Oneida BOCES-Practical Nursing Program': 379621, 'Madisonville Community College': 157304, 'Madonna University': 170806, 'Magdalen College': 182917, 'Magnolia College of Cosmetology': 176390, 'Maharishi University of Management': 153861, 'Mahoning County Career and Technical Center': 407489, 'Maine College of Art': 161509, 'Maine College of Health Professions': 161022, 'Maine Maritime Academy': 161299, 'Maine Media College': 490753, 'MAK Beauty Institute': 490221, 'Make-up Designory': 449366, 'Malone University': 203775, 'Manatee Technical College': 135407, 'Manchester Community College': 183132, 'Manchester University': 151777, 'Mandalyn Academy': 461272, 'Mandl School-The College of Allied Health': 192688, 'Manhattan Area Technical College': 155487, 'Manhattan Christian College': 155496, 'Manhattan College': 192703, 'Manhattan Institute': 461351, 'Manhattan School of Computer Technology': 420981, 'Manhattan School of Music': 192712, 'Manhattanville College': 192749, 'Manor College': 213774, 'Mansfield University of Pennsylvania': 213783, "Manuel and Theresa's School of Hair Design": 490674, "Manuel and Theresa's School of Hair Design-Bryan": 451547, "Manuel and Theresa's School of Hair Design-Victoria": 470296, 'Maple Springs Baptist Bible College and Seminary': 446394, 'Maranatha Baptist University': 239071, 'Margaret H Rollins School of Nursing at Beebe Medical Center': 130837, 'Maria College of Albany': 192785, 'Marian Health Careers Center-Los Angeles Campus': 411684, 'Marian Health Careers Center-Van Nuys Campus': 475282, 'Marian University': 151786, 'Maricopa Community College System Office': 105136, 'Marietta College': 203845, 'Marion Military Institute': 101648, 'Marion S Whelan School of Nursing of Geneva General Hospital': 192800, 'Marion Technical College': 419226, 'Marist College': 192819, 'Marketti Academy of Cosmetology': 457642, 'Marlboro College': 230940, 'Marlboro College Graduate & Professional Studies': 440411, 'Marquette University': 239105, 'Mars Hill University': 198899, 'Marshall B Ketchum University': 123943, 'Marshall University': 237525, 'Marshalltown Community College': 153922, 'Martin Community College': 198905, 'Martin Luther College': 173452, 'Martin Methodist College': 220701, 'Martin University': 151810, 'Martinsburg College': 487977, 'Mary Baldwin University': 232672, 'Marygrove College': 170842, 'Maryland Beauty Academy of Essex': 163815, 'Maryland Institute College of Art': 163295, 'Maryland University of Integrative Health': 164085, 'Marymount California University': 118541, 'Marymount Manhattan College': 192864, 'Marymount University': 232706, 'Maryville College': 220710, 'Maryville University of Saint Louis': 178059, 'Marywood University': 213826, 'Massachusetts Bay Community College': 166647, 'Massachusetts College of Art and Design': 166674, 'Massachusetts College of Liberal Arts': 167288, 'Massachusetts Institute of Technology': 166683, 'Massachusetts Maritime Academy': 166692, 'Massachusetts School of Barbering': 166805, 'Massachusetts School of Law': 369002, 'Massage Institute of Memphis': 490470, 'Massage Therapy Institute of Colorado': 381361, 'Massasoit Community College': 166823, "Master's Barber & Styling College": 490267, 'Mauna Loa Helicopters': 461333, 'Mayfield College': 454698, 'Mayland Community College': 198914, 'Mayo Clinic College of Medicine and Science': 173957, 'Maysville Community and Technical College': 157331, 'Mayville State University': 200226, 'McAllen Careers Institute': 493549, 'McCormick Theological Seminary': 146977, 'McDaniel College': 164270, 'McDougle Technical  Institute': 484039, 'McDowell Technical Community College': 198923, 'McHenry County College': 147004, 'McKendree University': 147013, 'McLennan Community College': 226578, 'McMurry University': 226587, 'McNeese State University': 159717, 'McPherson College': 155511, 'MCPHS University': 166656, 'MDT College of Health Sciences': 439455, 'Meadville Lombard Theological School': 147031, 'Mech-Tech College': 414461, "Mechon L'hoyroa": 490328, 'Med Academy': 488059, 'Medaille College': 192925, 'MediaTech Institute-Dallas': 455336, 'MediaTech Institute-Houston': 456153, 'Medical Allied Career Center': 476595, 'Medical Career & Technical College': 488217, 'Medical Career College of Northern California': 493479, 'Medical Career Institute': 479965, 'Medical College of Wisconsin': 239169, 'Medical Institute of Palm Beach': 455831, 'Medical Prep Institute of Tampa Bay': 490179, 'Medical Training College': 436650, 'Medical University of South Carolina': 218335, 'Medina County Career Center': 203942, 'MedQuest College': 484066, 'Medspa Academies': 476993, 'Meharry Medical College': 220792, 'Memorial Hospital School of Radiation Therapy Technology': 192970, 'Memphis College of Art': 220808, 'Memphis Institute of Barbering': 451538, 'Memphis Theological Seminary': 220871, 'Mendocino College': 118684, 'Menlo College': 118693, 'Merced College': 118718, 'Mercer County Career Center': 366632, 'Mercer County Community College': 185509, 'Mercer County Technical Education Center': 237543, 'Mercer University': 140447, 'Mercy College': 193016, 'Mercy College of Health Sciences': 153977, 'Mercy College of Ohio': 203960, 'Mercy Hospital School of Practical Nursing-Plantation General Hospital': 419217, "Mercy-St Luke's School of Radiologic Technology": 366571, 'Mercyhurst University': 213987, 'Mercyhurst University-North East Campus': 480189, 'Meredith College': 198950, 'Meredith Manor International Equestrian Center': 237552, 'Meridian College': 244279, 'Meridian Community College': 175935, 'Meridian Institute of Surgical Assisting': 461324, 'Meridian Technology Center': 365480, 'Meridian University': 491808, 'Merkaz Bnos-Business School': 427308, 'Merrell University of Beauty Arts and Science': 178077, 'Merrimack College': 166850, 'Merritt College': 118772, 'Merryfield School of Pet Grooming': 135559, 'Mesa Community College': 105154, 'Mesabi Range College': 173993, 'Mesalands Community College': 188261, 'Mesivta of Eastern Parkway-Yeshiva Zichron Meilech': 193061, 'Mesivta Torah Vodaath Rabbinical Seminary': 193052, 'Mesivtha Tifereth Jerusalem of America': 193070, 'Messenger College': 417752, 'Messiah College': 213996, 'Methodist College': 147129, 'Methodist Theological School in Ohio': 203997, 'Methodist University': 198969, 'Metro Beauty Academy': 457952, 'Metro Business College-Cape Girardeau': 178110, 'Metro Business College-Jefferson City': 245430, 'Metro Business College-Rolla': 245421, 'Metro Detroit Barber College': 490489, 'Metro Technology Centers': 363165, 'Metropolitan College of New York': 190114, 'Metropolitan Community College Area': 181303, 'Metropolitan Community College-Kansas City': 177995, 'Metropolitan Learning Institute': 441575, 'Metropolitan State University': 174020, 'Metropolitan State University of Denver': 127565, 'MGH Institute of Health Professions': 166869, 'Miami Ad School - Atlanta': 140827, 'Miami Ad School-New York': 476355, 'Miami Ad School-San Francisco': 440819, 'Miami Ad School-Wynwood': 428000, 'Miami Dade College': 135717, 'Miami International University of Art & Design-Art Institute Dallas': 224776, 'Miami Lakes Educational Center and Technical College': 135647, 'Miami Media School': 480851, 'Miami Regional University': 451103, 'Miami University-Hamilton': 204006, 'Miami University-Middletown': 204015, 'Miami University-Oxford': 204024, 'Miami Valley Career Technology Center': 204158, 'MIAT College of Technology': 169655, "Michael's Barber & Hair Stylist Academy": 494728, 'Michaels School of Hair Design and Esthetics-Paul Mitchell Partner School': 182953, 'Michigan Barber School Inc': 171012, 'Michigan Career and Technical Institute': 172422, 'Michigan College of Beauty-Monroe': 170611, 'Michigan College of Beauty-Troy': 381370, 'Michigan School of Psychology': 169220, 'Michigan State University': 171100, 'Michigan State University-College of Law': 169628, 'Michigan Technological University': 171128, 'Mid Cities Barber College': 423412, 'Mid Michigan College': 171155, 'Mid-America Christian University': 245953, 'Mid-America College of Funeral Service': 151962, 'Mid-America Technology Center': 418320, 'Mid-Atlantic Christian University': 199458, 'Mid-Del Technology Center': 431017, 'Mid-EastCTC-Adult Education': 389860, 'Mid-Plains Community College': 181312, 'Mid-South Christian College': 481225, 'Mid-State Technical College': 239220, 'MidAmerica Nazarene University': 155520, 'Middle Georgia State University': 482158, 'Middle Tennessee School of Anesthesia Inc': 220996, 'Middle Tennessee State University': 220978, 'Middlebury College': 230959, 'Middlebury Institute of International Studies at Monterey': 119058, 'Middlesex Community College': 129756, 'Middlesex County College': 185536, 'Midfield Institute of Cosmetology': 487816, 'Midland College': 226806, 'Midland University': 181330, 'Midlands Technical College': 218353, 'Midstate College': 147165, 'Midway Paris Beauty School': 193186, 'Midway University': 157377, 'Midwest Barber College': 493831, 'Midwest College of Oriental Medicine-Evanston': 439020, 'Midwest College of Oriental Medicine-Racine': 383020, 'Midwest Institute': 178183, 'Midwest Technical Institute-East Peoria': 458265, 'Midwest Technical Institute-Moline': 469638, 'Midwest Technical Institute-Ridgeland': 475459, 'Midwest Technical Institute-Springfield': 482097, 'Midwestern Baptist Theological Seminary': 178208, 'Midwestern Career College': 457536, 'Midwestern State University': 226833, 'Midwestern University-Downers Grove': 143853, 'Midwestern University-Glendale': 423643, 'Midwives College of Utah': 480985, 'Mifflin County Academy of Science and Technology': 418481, 'Milan Institute of Cosmetology': 385549, 'Milan Institute of Cosmetology-El Paso': 460534, 'Milan Institute of Cosmetology-Fairfield': 454546, 'Milan Institute of Cosmetology-La Quinta': 460516, 'Milan Institute of Cosmetology-Reno': 454555, 'Milan Institute of Cosmetology-San Antonio Military': 449904, 'Milan Institute of Cosmetology-Visalia': 454573, 'Milan Institute-Amarillo': 440855, 'Milan Institute-Bakersfield': 457077, 'Milan Institute-Bakersfield West': 489760, 'Milan Institute-Boise': 460525, 'Milan Institute-Fresno': 448895, 'Milan Institute-Las Vegas': 475325, 'Milan Institute-Merced': 482060, 'Milan Institute-Palm Desert': 442657, 'Milan Institute-San Antonio Ingram': 437778, 'Milan Institute-Sparks': 443669, 'Milan Institute-Visalia': 112288, 'Mildred Elley School-Albany Campus': 193201, 'Mildred Elley-New York Campus': 461014, 'Mildred Elley-Pittsfield Campus': 425986, 'Miles College': 101675, 'Miles Community College': 180373, 'Millennia Atlantic University': 461883, 'Millennium Training Institute': 451264, 'Millersville University of Pennsylvania': 214041, 'Milligan College': 486901, 'Millikin University': 147244, 'Mills College': 118888, 'Millsaps College': 175980, 'Milwaukee Area Technical College': 239248, 'Milwaukee Career College': 449861, 'Milwaukee Institute of Art & Design': 239309, 'Milwaukee School of Engineering': 239318, 'Mind Body Institute': 483887, 'Mineral Area College': 178217, 'Mineral County Vocational Technical Center': 368647, 'Mingo Extended Learning Center': 486202, 'Minneapolis Business College': 174118, 'Minneapolis College of Art and Design': 174127, 'Minneapolis Community and Technical College': 174136, 'Minnesota School of Cosmetology-Plymouth Campus': 480170, 'Minnesota School of Cosmetology-Woodbury Campus': 174190, 'Minnesota State College Southeast': 175263, 'Minnesota State Colleges and Universities System Office': 428453, 'Minnesota State Community and Technical College': 173559, 'Minnesota State University Moorhead': 174358, 'Minnesota State University-Mankato': 173920, 'Minnesota West Community and Technical College': 173638, 'Minot State University': 200253, 'MiraCosta College': 118912, 'Mirrer Yeshiva Cent Institute': 193247, 'Misericordia University': 214069, 'Missio Theological Seminary': 211130, 'Mission Beauty Institute': 488299, 'Mission College': 118930, 'Mississippi College': 176053, 'Mississippi College of Beauty Culture': 176062, 'Mississippi Community College Board': 247737, 'Mississippi Delta Community College': 176008, 'Mississippi Gulf Coast Community College': 176071, 'Mississippi Institute of Aesthetics Nails & Cosmetology': 455105, 'Mississippi State University': 176080, 'Mississippi University for Women': 176035, 'Mississippi Valley State University': 176044, 'Missouri Baptist University': 178244, 'Missouri College of Cosmetology North': 440226, 'Missouri Southern State University': 178341, 'Missouri State University-Springfield': 179566, 'Missouri State University-West Plains': 179344, 'Missouri University of Science and Technology': 178411, 'Missouri Valley College': 178369, 'Missouri Western State University': 178387, 'Mitchell College': 129774, 'Mitchell Community College': 198987, 'Mitchell Hamline School of Law': 175281, 'Mitchell Technical Institute': 219189, 'Mitchells Academy': 199005, 'Mitsu Sato Hair Academy': 476902, 'MIXED Institute of Cosmetology & Barber': 493761, 'MKG Beauty & Business': 485582, 'Moberly Area Community College': 178448, 'Mobile Technical Training': 490249, 'Model College of Hair Design': 174321, 'Modern Beauty Academy': 118958, 'Modern Hairstyling Institute-Arecibo': 242954, 'Modern Hairstyling Institute-Bayamon': 242945, 'Modern Hairstyling Institute-Carolina': 438337, 'Modern Technology School': 371928, 'Modern Welding School': 193265, 'Modesto Junior College': 118976, 'Mohave Community College': 105206, 'Mohawk Valley Community College': 193283, 'Moler Barber College': 200262, 'Moler Hollywood Beauty Academy': 204121, 'Moler-Pickens Beauty Academy': 250902, 'Molloy College': 193292, 'Monmouth College': 147341, 'Monmouth County Vocational School District': 374592, 'Monmouth University': 185572, 'Monongalia County Technical Education Center': 237561, 'Monroe 2 Orleans BOCES-Center for Workforce Development': 451459, 'Monroe College': 193308, 'Monroe Community College': 193326, 'Monroe County Community College': 171225, 'Montana Academy of Salons': 457749, 'Montana Barber Institute': 493655, 'Montana Bible College': 262165, 'Montana State University': 180461, 'Montana State University Billings': 180179, 'Montana State University-Northern': 180522, 'Montana Technological University': 180416, 'Montcalm Community College': 171234, 'Montclair State University': 185590, 'Monteclaro Escuela de Hoteleria y Artes Culinarias': 437705, 'Montefiore School of Nursing': 193380, 'Monterey Peninsula College': 119067, 'Montessori Casa International': 451033, 'Montessori Education Center of the Rockies': 127954, 'Montessori Institute of Milwaukee': 436021, 'Montgomery Beauty School': 163408, 'Montgomery College': 163426, 'Montgomery Community College': 199023, 'Montgomery County Community College': 214111, 'Montreat College': 199032, 'Montserrat College of Art': 166911, 'Monty Tech': 433040, 'Moody Bible Institute': 147369, 'Moore Career College': 444662, 'Moore College of Art and Design': 214148, 'Moore Norman Technology Center': 248606, 'Moorpark College': 119137, 'Moraine Park Technical College': 239372, 'Moraine Valley Community College': 147378, 'Moravian College': 214157, 'More Tech Institute': 483470, 'Morehead State University': 157386, 'Morehouse College': 140553, 'Morehouse School of Medicine': 140562, 'Moreno Valley College': 460394, 'Morgan Community College': 127617, 'Morgan State University': 163453, 'Morgantown Beauty College Inc': 237570, 'Morningside College': 154004, 'Morris College': 218399, 'Morris County Vocational School District': 365763, 'Morrison Institute of Technology': 147396, 'Morton College': 147411, 'Motlow State Community College': 221096, 'Motoring Technical Training Institute': 414124, 'MotoRing Technical Training Institute': 479062, 'Mott Community College': 169275, 'Mount Aloysius College': 214166, 'Mount Angel Seminary': 209241, 'Mount Carmel College of Nursing': 204176, 'Mount Holyoke College': 166939, 'Mount Marty College': 219198, 'Mount Mary University': 239390, 'Mount Mercy University': 154013, 'Mount Saint Joseph University': 204200, 'Mount Saint Mary College': 193353, "Mount Saint Mary's University": 119173, "Mount St. Mary's University": 163462, 'Mount Vernon Nazarene University': 204194, 'Mount Wachusett Community College': 166957, 'Mountain Empire Community College': 232788, 'Mountain State College': 237598, 'Mountain State School of Massage': 448275, 'Mountain View College': 226930, 'Mountainland Technical College': 448248, 'Mountwest Community and Technical College': 444954, "Mr John's School of Cosmetology & Nails-Jacksonville": 443173, "Mr John's School of Cosmetology Esthetics & Nails-Decatur": 147439, "Mr Leon's School of Hair Design-Lewiston": 436100, "Mr Leon's School of Hair Design-Moscow": 142416, "Mr Wayne's School of Unisex Hair Design": 376631, 'Mt Hood Community College': 209250, 'Mt San Antonio College': 119164, 'Mt San Jacinto Community College District': 119216, 'Mt Sierra College': 398130, 'Mt. Diablo Adult Education-Mt. Diablo USD': 382258, 'MTI Business College Inc': 118189, 'MTI College': 118198, 'Muhlenberg College': 214175, 'Multnomah University': 209287, 'Murray State College': 207236, 'Murray State University': 157401, 'Musicians Institute': 119270, 'Muskegon Community College': 171304, 'Muskingum University': 204264, 'My Beauty & Barber College': 490337, "My Le's Beauty College": 457606, 'MyComputerCareer.com': 451228, 'MyComputerCareer.edu-Columbus': 451477, 'MyComputerCareer.edu-Raleigh': 480037, 'Myotherapy College of Utah': 406486, 'Myotherapy Institute': 434432, 'MyrAngel Beauty Institute': 448123, 'Mystros Barber Academy': 491589, 'Napa Valley College': 119331, 'Naropa University': 127653, 'NASCAR Technical Institute': 442611, 'Nash Community College': 199087, 'Nashotah House': 239424, 'Nashua Community College': 183141, 'Nashville College of Medical Careers': 221157, 'Nashville Film Institute': 490115, 'Nashville State Community College': 221184, 'Nassau Community College': 193478, 'National American University-Albuquerque West': 440758, 'National American University-Austin': 451875, 'National American University-Bellevue': 477996, 'National American University-Career Point College Teachout Site': 491118, 'National American University-Centennial': 466161, 'National American University-Colorado Springs South': 466189, 'National American University-Ellsworth AFB Extension': 440749, 'National American University-Garden City': 491093, 'National American University-Georgetown': 482325, 'National American University-Harold D. Buckingham Graduate School': 485290, 'National American University-Independence': 247700, 'National American University-Indianapolis': 482370, 'National American University-Killeen': 492573, 'National American University-Kings Bay': 494269, 'National American University-Mesquite': 478014, 'National American University-Overland Park': 442718, 'National American University-Rapid City': 219204, 'National American University-Richardson': 482334, 'National American University-Rochester': 482343, 'National American University-Roseville': 174385, 'National American University-Sioux Falls': 219213, 'National American University-Tulsa': 466152, 'National American University-Wichita': 451884, 'National Aviation Academy of New England': 165635, 'National Aviation Academy of Tampa Bay': 378956, 'National Beauty College': 454847, 'National Career College': 455868, 'National Career Education': 371964, 'National Career Institute': 457767, 'National College-Nashville': 388043, 'National Conservatory of Dramatic Arts': 131830, 'National Holistic Institute': 119553, 'National Latino Education Institute': 148955, 'National Louis University': 147536, 'National Paralegal College': 461023, 'National Park College': 106980, 'National Personal Training Institute': 488280, 'National Personal Training Institute of Colorado': 462327, 'National Personal Training Institute of Columbus': 481544, 'National Personal Training Institute-Tampa': 490018, 'National Polytechnic College': 447759, 'National Tractor Trailer School Inc-Buffalo': 375106, 'National Tractor Trailer School Inc-Liverpool': 367334, 'National University': 119605, 'National University College': 242972, 'National University of Health Sciences': 147590, 'National University of Natural Medicine': 209296, 'Natural Images Beauty College': 488110, 'Naugatuck Valley Community College': 129729, 'Navajo Technical University': 187596, 'Naval Postgraduate School': 119678, 'Navarro College': 227146, 'Nazarene Bible College': 127714, 'Nazarene Theological Seminary': 178518, 'Nazareth College': 193584, 'Nebraska Christian College of Hope International University': 181376, 'Nebraska College of Technical Agriculture': 181765, 'Nebraska Indian Community College': 181419, 'Nebraska Methodist College of Nursing & Allied Health': 181297, 'Nebraska Wesleyan University': 181446, "Neecee's Barber College": 483513, 'Neighborhood Playhouse School of the Theater': 193609, 'Neilson Beauty College': 227155, 'Neo-Esthetique European Institute': 491668, 'Neosho Beauty College': 178527, 'Neosho County Community College': 155566, 'Ner Israel Rabbinical College': 163532, 'Networks Barber College': 483258, 'Neumann University': 214272, 'Neumont College of Computer Science': 445692, 'Nevada Career Institute': 414939, 'Nevada Regional Technical Center': 417673, 'Nevada State College': 441900, 'Nevada System of Higher Education-System Office': 182519, 'New Age Training': 449685, 'New Beginning College of Cosmetology': 101277, 'New Beginnings Beauty Academy': 485591, 'New Brunswick Theological Seminary': 185758, 'New Castle School of Trades': 214290, 'New College of Florida': 262129, 'New Community Career & Technical Institute': 437723, 'New Concept Massage and Beauty School': 439774, 'New Dimensions Beauty Academy Inc': 476823, 'New Dimensions School of Hair Design': 419280, 'New England College': 182980, 'New England College of Business and Finance': 164438, 'New England College of Optometry': 167093, 'New England Culinary Institute': 230977, 'New England Hair Academy': 373678, 'New England Institute of Technology': 217305, 'New England Law-Boston': 167215, 'New England School of Hair Design': 182999, 'New England School of Photography': 167224, 'New England Tractor Trailer Training School of Connecticut': 129932, 'New England Tractor Trailer Training School of CT-Bridgeport': 480903, 'New England Tractor Trailer Training School of Massachusetts': 468963, 'New England Tractor Trailer Training School of Rhode Island': 217323, 'New Hampshire Institute for Therapeutic Arts': 183035, 'New Hampshire Institute of Art': 430810, 'New Hope Christian College-Eugene': 208725, 'New Horizons Medical Institute': 483638, 'New Horizons Medical Institute-Winder': 485120, 'New Jersey City University': 185129, 'New Jersey Institute of Technology': 185828, 'New Mexico Highlands University': 187897, 'New Mexico Institute of Mining and Technology': 187967, 'New Mexico Junior College': 187903, 'New Mexico Military Institute': 187912, 'New Mexico State University-Alamogordo': 187994, 'New Mexico State University-Carlsbad': 188003, 'New Mexico State University-Dona Ana': 187620, 'New Mexico State University-Grants': 188021, 'New Mexico State University-Main Campus': 188030, 'New Orleans Baptist Theological Seminary': 159948, 'New Professions Technical Institute': 434469, 'New River Community and Technical College': 447582, 'New River Community College': 232867, 'New Saint Andrews College': 440396, 'New Tyler Barber College Inc': 107442, 'New York Academy of Art': 366368, 'New York Automotive and Diesel Institute': 440262, 'New York Chiropractic College': 193751, 'New York College of Health Professions': 418126, 'New York College of Podiatric Medicine': 194073, 'New York College of Traditional Chinese Medicine': 439783, 'New York Conservatory for Dramatic Arts': 421841, 'New York Film Academy': 461148, 'New York Institute of Beauty': 481243, 'New York Institute of Massage Inc': 431071, 'New York Institute of Technology': 194091, 'New York Law School': 193821, 'New York Medical Career Training Center': 457800, 'New York Medical College': 193830, 'New York School for Medical and Dental Assistants': 193858, 'New York School of Esthetics & Day Spa': 475404, 'New York School of Interior Design': 194116, 'New York Seminary': 493798, 'New York Theological Seminary': 193894, 'New York University': 193900, 'Newberry College': 218414, 'Newberry School of Beauty': 119845, 'Newbury College': 167251, 'Newman University': 155335, 'Newschool of Architecture and Design': 119775, "NHTI-Concord's Community College": 183099, 'Niagara County Community College': 193946, 'Niagara University': 193973, 'Nicholls State University': 159966, 'Nichols College': 167260, 'Nicolet Area Technical College': 239442, 'Nightingale College': 444787, 'Niles School of Cosmetology': 147642, 'No Grease Barber School': 492421, 'Norco College': 460464, 'Norfolk State University': 232937, 'Normandale Community College': 174428, "North Adrian's College of Beauty Inc": 119951, 'North American Trade Schools': 162371, 'North American University': 461795, 'North Arkansas College': 107460, 'North Bennet Street School': 167297, 'North Carolina A & T State University': 199102, 'North Carolina Central University': 199157, 'North Carolina State University at Raleigh': 199193, 'North Carolina Wesleyan College': 199209, 'North Central College': 147660, 'North Central Institute': 418889, 'North Central Kansas Technical College': 155593, 'North Central Michigan College': 171395, 'North Central Missouri College': 179715, 'North Central State College': 204422, 'North Central Texas College': 224110, 'North Central University': 174437, 'North Country Community College': 194028, 'North Dakota State College of Science': 200305, 'North Dakota State University-Main Campus': 200332, 'North Florida College': 136145, 'North Florida Cosmetology Institute Inc': 447892, 'North Florida Technical College': 132675, 'North Georgia Technical College': 140678, 'North Greenville University': 218441, 'North Hennepin Community College': 174376, 'North Idaho College': 142443, 'North Iowa Area Community College': 154059, 'North Lake College': 227191, 'North Orange County Community College District': 120023, 'North Park University': 147679, 'North Seattle College': 236072, 'North Shore Community College': 167312, 'North-West College-Anaheim': 484367, 'North-West College-Glendale': 372028, 'North-West College-Long Beach': 484376, 'North-West College-Pomona': 120069, 'North-West College-Riverside': 445364, 'North-West College-Van Nuys': 120087, 'North-West College-West Covina': 120078, 'Northampton County Area Community College': 214379, 'Northcentral Technical College': 239460, 'Northcentral University': 444130, 'Northcoast Medical Training Academy': 449719, 'Northeast Alabama Community College': 101897, 'Northeast Community College': 181491, 'Northeast Iowa Community College': 154110, 'Northeast Lakeview College': 488730, 'Northeast Mississippi Community College': 176169, 'Northeast Ohio Medical University': 204477, 'Northeast State Community College': 221908, 'Northeast Technical Institute': 461962, 'Northeast Technology Center-Afton': 420459, 'Northeast Technology Center-Claremore': 456560, 'Northeast Technology Center-Kansas': 432074, 'Northeast Technology Center-Pryor': 418339, 'Northeast Technology Center-System Office': 461087, 'Northeast Texas Community College': 227225, 'Northeast Wisconsin Technical College': 239488, 'Northeastern Illinois University': 147776, 'Northeastern Junior College': 127732, 'Northeastern Oklahoma A&M College': 207290, 'Northeastern Seminary': 439817, 'Northeastern State University': 207263, 'Northeastern Technical College': 217837, 'Northeastern University': 167358, 'Northeastern University Lifelong Learning Network': 482705, 'Northern Arizona University': 105330, 'Northern Baptist Theological Seminary': 147697, 'Northern Career Institute': 418223, 'Northern Essex Community College': 167376, 'Northern Illinois University': 147703, 'Northern Institute of Cosmetology': 204431, 'Northern Kentucky University': 157447, 'Northern Maine Community College': 161484, 'Northern Marianas College': 240790, 'Northern Michigan University': 171456, 'Northern New Mexico College': 188058, 'Northern Oklahoma College': 207281, 'Northern State University': 219259, 'Northern Technical College': 490744, 'Northern Tier Career Center': 418588, 'Northern Vermont University': 230913, 'Northern Virginia Community College': 232946, 'Northern Virginia School of Therapeutic Massage': 461412, 'Northern Wyoming Community College District': 240666, 'Northland College': 239512, 'Northland Community and Technical College': 174473, 'Northland Pioneer College': 105349, 'Northpoint Bible College': 217606, 'Northshore Technical Community College': 160667, 'NorthShore University HealthSystem School of Nurse Anesthesia': 443030, 'NorthWest Arkansas Community College': 367459, 'Northwest Career College': 445948, 'Northwest Christian University': 209409, 'Northwest College': 240657, 'Northwest College of Art & Design': 377546, 'Northwest College-Beaverton': 209083, 'Northwest College-Clackamas': 209205, 'Northwest College-Eugene': 468246, 'Northwest College-Hillsboro': 441168, 'Northwest College-Medford': 484950, 'Northwest College-Tualatin': 468255, 'Northwest Educational Center': 369686, 'Northwest Florida State College': 136233, 'Northwest HVAC/R Training Center': 434362, 'Northwest Indian College': 380377, 'Northwest Iowa Community College': 154129, 'Northwest Kansas Technical College': 155618, 'Northwest Louisiana Technical College': 160010, 'Northwest Mississippi Community College': 176178, 'Northwest Missouri State University': 178624, 'Northwest Nazarene University': 142461, 'Northwest School of Wooden Boat Building': 458140, 'Northwest State Community College': 204440, 'Northwest Suburban College': 488086, 'Northwest Technical College': 173115, 'Northwest Technical Institute': 107488, 'Northwest Technology Center-Alva': 366623, 'Northwest Technology Center-Fairview': 407601, 'Northwest University': 236133, 'Northwest University-College of Adult and Professional Studies': 487603, 'Northwest Vista College': 420398, 'Northwest-Shoals Community College': 101736, 'Northwestern College': 260992, 'Northwestern Connecticut Community College': 130040, 'Northwestern Health Sciences University': 174507, 'Northwestern Michigan College': 171483, 'Northwestern Oklahoma State University': 207306, 'Northwestern Polytechnic University': 120166, 'Northwestern State University of Louisiana': 160038, 'Northwestern Technological Institute': 168573, 'Northwestern University': 147767, 'Northwood University': 171492, 'Norwalk Community College': 130004, 'Norwich University': 230995, 'Nossi College of Art': 368452, 'Notre Dame College': 204468, 'Notre Dame de Namur University': 120184, 'Notre Dame of Maryland University': 163578, 'Nouvelle Institute': 409032, 'Nova Academy of Cosmetology': 459426, 'Nova College de Puerto Rico': 428055, 'Nova Southeastern University': 136215, 'NTMA Training Centers of Southern California': 443207, 'Nueta Hidatsa Sahnish College': 200086, 'Nunez Community College': 158884, 'Nuvani Institute': 377281, 'Nuvo College of Cosmetology': 447980, 'Nyack College': 194161, 'O C Collins Career Center': 203614, "O'Briens Aveda Institute": 231004, 'Oak Hills Christian College': 174525, 'Oakland City University': 152099, 'Oakland Community College': 171535, 'Oakland University': 171571, 'Oakton Community College': 147800, 'Oakwood University': 101912, 'Oberlin College': 204501, 'Oblate School of Theology': 227289, 'Occidental College': 120254, 'Ocean Corporation': 227298, 'Ocean County College': 185873, 'Ocean County Vocational-Technical School': 431716, 'Oconee Fall Line Technical College': 420431, 'Odessa College': 227304, 'Oehrlein School of Cosmetology': 147819, 'Ogden-Weber Technical College': 230490, 'Ogeechee Technical College': 366465, 'Oglala Lakota College': 219277, 'Ogle School Hair Skin Nails-Arlington': 227313, 'Ogle School Hair Skin Nails-Dallas': 381404, 'Ogle School Hair Skin Nails-Denton': 478591, 'Ogle School Hair Skin Nails-Ft Worth': 227322, 'Ogle School Hair Skin Nails-Hurst': 248703, 'Ogle School Hair Skin Nails-North Dallas': 460978, 'Ogle School Hair Skin Nails-San Antonio': 480125, 'Ogle School Hair Skin Nails-Stafford': 484604, 'Oglethorpe University': 140696, 'Ohel Margulia Seminary': 493646, 'Ohio Business College-Sandusky': 203739, 'Ohio Business College-Sheffield': 203720, 'Ohio Christian University': 201964, 'Ohio Dominican University': 204617, 'Ohio Institute of Allied Health': 483647, 'Ohio Media School-Cincinnati': 418269, 'Ohio Media School-Valley View': 410797, 'Ohio Medical Career College': 453792, 'Ohio Northern University': 204635, 'Ohio State Beauty Academy': 204714, 'Ohio State College of Barber Styling': 204723, 'Ohio State School of Cosmetology': 405021, 'Ohio State School of Cosmetology-Canal Winchester': 204778, 'Ohio State School of Cosmetology-Heath': 405012, 'Ohio State University Agricultural Technical Institute': 204662, 'Ohio State University-Lima Campus': 204671, 'Ohio State University-Main Campus': 204796, 'Ohio State University-Mansfield Campus': 204680, 'Ohio State University-Marion Campus': 204699, 'Ohio State University-Newark Campus': 204705, 'Ohio Technical Center at Vantage Career Center': 418278, 'Ohio Technical College': 204608, 'Ohio University-Chillicothe Campus': 204820, 'Ohio University-Eastern Campus': 204802, 'Ohio University-Lancaster Campus': 204848, 'Ohio University-Main Campus': 204857, 'Ohio University-Southern Campus': 204839, 'Ohio University-Zanesville Campus': 204866, 'Ohio Valley College of Technology': 204884, 'Ohio Valley Hospital School of Nursing': 214476, 'Ohio Valley University': 237640, 'Ohio Wesleyan University': 204909, 'Ohlone College': 120290, 'Ohr Hameir Theological Seminary': 194189, 'Oikos University': 491491, 'Okaloosa Technical College': 433068, 'Oklahoma Baptist University': 207403, 'Oklahoma Christian University': 207324, 'Oklahoma City Community College': 207449, 'Oklahoma City University': 207458, 'Oklahoma Panhandle State University': 207351, 'Oklahoma State University Center for Health Sciences': 207315, 'Oklahoma State University Institute of Technology': 207564, 'Oklahoma State University-Main Campus': 207388, 'Oklahoma State University-Oklahoma City': 207397, 'Oklahoma Technical College': 469629, 'Oklahoma Wesleyan University': 206835, 'Old Dominion University': 232982, 'Old Town Barber College-Wichita': 155353, 'Oliver Finley Academy of Cosmetology': 455859, 'Olivet College': 171599, 'Olivet Nazarene University': 147828, 'Olney Central College': 145707, 'Olympian Academy of Cosmetology': 187505, 'Olympic College': 236188, 'Omega Graduate School': 461120, 'Omega Institute of Cosmetology': 439844, "Omega Studios' School of Applied Recording Arts & Sciences": 455026, 'Omnitech Institute': 444796, 'Onondaga Community College': 194222, 'Onondaga Cortland Madison BOCES': 440730, 'Onondaga School of Therapeutic Massage-Rochester': 460455, 'Onondaga School of Therapeutic Massage-Syracuse': 457846, 'Opelousas School of Cosmetology': 159601, 'Oral Roberts University': 207582, 'Orange Coast College': 120342, 'Orange County Community College': 194240, 'Orange Technical College-Mid Florida Campus': 135735, 'Orange Technical College-Orlando Campus': 136303, 'Orange Technical College-Westside Campus': 138372, 'Orange Technical College-Winter Park Campus': 138488, 'Orange Ulster BOCES-Practical Nursing Program': 417992, 'Orangeburg Calhoun Technical College': 218487, 'Oregon Coast Community College': 423652, 'Oregon College of Art and Craft': 209533, 'Oregon College of Oriental Medicine': 369659, 'Oregon Health & Science University': 209490, 'Oregon Institute of Technology': 209506, 'Oregon State University': 209542, 'Oregon State University-Cascades Campus': 440828, 'Orion Institute': 444635, 'Orleans Niagara BOCES-Practical Nursing Program': 441593, 'Orleans Technical College': 214528, 'Orlo School of Hair Design and Cosmetology': 407434, 'Osceola Technical College': 427991, 'Oswego County BOCES': 364964, 'Otero Junior College': 127778, 'Otis College of Art and Design': 120403, 'Otsego Area BOCES-Practical Nursing Program': 194259, 'Ottawa University-Kansas City': 155636, 'Ottawa University-Milwaukee': 428259, 'Ottawa University-Online': 454582, 'Ottawa University-Ottawa': 155627, 'Ottawa University-Phoenix': 105367, 'Ottawa University-Surprise': 464226, 'Otterbein University': 204936, 'Ouachita Baptist University': 107512, 'Our Lady of the Lake University': 227331, 'Owens Community College': 204945, 'Owensboro Community and Technical College': 247940, 'Oxford Academy of Hair Design Inc': 455798, 'Oxnard College': 120421, 'Ozark Christian College': 178679, 'Ozarka College': 107549, 'Ozarks Technical Community College': 177472, 'P B Cosmetology Education Center': 185970, 'P C Age-Jersey City': 443216, 'P&A Scholars Beauty School': 391005, 'Pace University': 194310, 'Pacific Bible College': 407610, 'Pacific College': 422695, 'Pacific College of Health Science-Chicago': 442842, 'Pacific College of Oriental Medicine-New York': 414595, 'Pacific College of Oriental Medicine-San Diego': 378576, 'Pacific Islands University': 439862, 'Pacific Lutheran University': 236230, 'Pacific Northwest College of Art': 209603, 'Pacific Northwest University of Health Sciences': 455406, 'Pacific Oaks College': 120768, 'Pacific Rim Christian University': 457484, 'Pacific School of Religion': 120795, 'Pacific States University': 120838, 'Pacific Union College': 120865, 'Pacific University': 209612, 'Pacifica Graduate Institute': 115746, 'Paier College of Art Inc': 130110, 'Paine College': 140720, 'Palace Beauty College': 447731, 'Palau Community College': 243647, 'Palladium Technical Academy Inc': 447722, 'Palm Beach Academy of Health & Beauty': 449490, 'Palm Beach Atlantic University': 136330, 'Palm Beach State College': 136358, 'Palmer College of Chiropractic': 154174, 'Palmetto Beauty School': 475538, 'Palo Alto College': 246354, 'Palo Alto University': 120698, 'Palo Verde College': 120953, 'Palomar College': 120971, 'Palomar Institute of Cosmetology': 365125, 'Pamlico Community College': 199263, 'Panache Academy of Beauty': 475413, 'Panola College': 227386, 'Paradise Valley Community College': 364016, 'Paramount Beauty Academy': 204963, 'Pardee RAND Graduate School': 121628, 'Paris Junior College': 227401, 'Parisian Beauty School': 186016, 'Parisian Spa Institute': 483896, 'Park Place Premier Barber School': 484190, 'Park University': 178721, 'Parker University': 243823, 'Parkland College': 147916, 'Paroba College of Cosmetology': 235158, 'Pasadena City College': 121044, 'Pasco-Hernando State College': 136400, 'Passaic County Community College': 186034, 'Pat Goins Benton Road Beauty School': 160117, 'Patrick Henry College': 451927, 'Patrick Henry Community College': 233019, 'Paul D Camp Community College': 233037, 'Paul Mitchell the School-Ardmore': 483665, 'Paul Mitchell the School-Arkansas': 107789, 'Paul Mitchell the School-Arlington': 475486, 'Paul Mitchell the School-Atlanta': 454926, 'Paul Mitchell the School-Austin': 451565, 'Paul Mitchell the School-Birmingham': 454652, 'Paul Mitchell the School-Boise': 260929, 'Paul Mitchell the School-Bradley': 143376, 'Paul Mitchell the School-Charleston': 467872, 'Paul Mitchell the School-Chicago': 458274, 'Paul Mitchell the School-Cincinnati': 455284, 'Paul Mitchell the School-Cleveland': 456065, 'Paul Mitchell the School-Colorado Springs': 459286, 'Paul Mitchell the School-Columbia': 467863, 'Paul Mitchell the School-Columbus': 456074, 'Paul Mitchell the School-Costa Mesa': 442240, 'Paul Mitchell the School-Delaware': 459301, 'Paul Mitchell the School-Denver': 482176, 'Paul Mitchell the School-East Bay': 459231, 'Paul Mitchell the School-Esani': 454607, 'Paul Mitchell The School-Farmington Hills': 484093, 'Paul Mitchell the School-Fayetteville': 199689, 'Paul Mitchell the School-Fort Myers': 475547, 'Paul Mitchell the School-Fresno': 459198, 'Paul Mitchell the School-Gastonia': 444486, 'Paul Mitchell the School-Grand Rapids': 172680, 'Paul Mitchell the School-Great Lakes': 446288, 'Paul Mitchell the School-Greenville': 483337, 'Paul Mitchell the School-Honolulu': 461591, 'Paul Mitchell the School-Houston': 249238, 'Paul Mitchell the School-Huntsville': 417008, 'Paul Mitchell the School-Indianapolis': 461917, 'Paul Mitchell the School-Jacksonville': 136109, 'Paul Mitchell the School-Jersey Shore': 481508, 'Paul Mitchell the School-Jessup': 488749, 'Paul Mitchell the School-Knoxville': 248660, 'Paul Mitchell the School-Lansing': 484118, 'Paul Mitchell the School-Las Vegas': 462008, 'Paul Mitchell the School-Lexington': 156426, 'Paul Mitchell the School-Logan': 448220, 'Paul Mitchell the School-Lombard': 483328, 'Paul Mitchell the School-Louisville': 156842, 'Paul Mitchell the School-Madison': 486983, 'Paul Mitchell the School-Memphis': 456029, 'Paul Mitchell the School-Merrillville': 484109, 'Paul Mitchell the School-Miami': 451121, 'Paul Mitchell the School-Michigan': 449977, 'Paul Mitchell the School-Milwaukee': 459578, 'Paul Mitchell the School-Missouri Columbia': 177685, 'Paul Mitchell the School-Modesto': 459170, 'Paul Mitchell the School-Murfreesboro': 220491, 'Paul Mitchell the School-Nampa': 488998, 'Paul Mitchell the School-Normal': 457545, 'Paul Mitchell the School-North Haven': 129349, 'Paul Mitchell the School-Ogden': 476294, 'Paul Mitchell the School-Orlando': 445212, 'Paul Mitchell the School-Overland Park': 476984, 'Paul Mitchell the School-Pasadena': 454768, 'Paul Mitchell the School-Phoenix': 459116, 'Paul Mitchell the School-Portland': 208187, 'Paul Mitchell the School-Portsmouth': 183202, 'Paul Mitchell the School-Provo': 380456, 'Paul Mitchell the School-Raleigh': 475556, 'Paul Mitchell the School-Reno': 476841, 'Paul Mitchell the School-Rexburg': 454944, 'Paul Mitchell the School-Rhode Island': 443641, 'Paul Mitchell the School-Richland': 234924, 'Paul Mitchell the School-Roanoke': 231280, 'Paul Mitchell the School-Sacramento': 455761, 'Paul Mitchell the School-Salt Lake City': 230214, 'Paul Mitchell the School-San Antonio': 451714, 'Paul Mitchell the School-San Diego': 449968, 'Paul Mitchell the School-San Jose': 494454, 'Paul Mitchell the School-Schenectady': 484011, 'Paul Mitchell the School-Sherman Oaks': 449986, 'Paul Mitchell the School-Spokane': 462071, 'Paul Mitchell the School-Springfield': 455080, 'Paul Mitchell the School-St Louis': 461421, 'Paul Mitchell the School-St. George': 421610, 'Paul Mitchell the School-Tampa': 449959, 'Paul Mitchell the School-Temecula': 457323, 'Paul Mitchell the School-Toledo': 485032, 'Paul Mitchell the School-Tulsa': 486567, 'Paul Mitchell the School-Tysons Corner': 449995, 'Paul Mitchell the School-Webster': 488989, 'Paul Mitchell the School-Wichita': 408066, 'Paul Mitchell the School-Woodbridge': 480930, 'Paul Quinn College': 227429, 'Paul Smiths College of Arts and Science': 194392, 'Payne Theological Seminary': 204990, 'PC AGE-Metropark': 443225, 'PCCenter': 455345, 'PCI Academy-Ames': 154208, 'PCI Academy-Plymouth': 443979, 'PCI College': 439871, 'PCI Health Training Center': 369783, 'Pearl River Community College': 176239, 'Peirce College': 214883, 'Pellissippi State Community College': 221643, 'Peloton College': 490735, 'Peninsula College': 236258, 'Penn Commercial Business/Technical School': 214892, 'Pennco Tech-Blackwood': 186052, 'Pennco Tech-Bristol': 214944, 'Pennsylvania Academy of the Fine Arts': 214971, 'Pennsylvania College of Art and Design': 215053, 'Pennsylvania College of Health Sciences': 442356, 'Pennsylvania College of Technology': 366252, 'Pennsylvania Gunsmith School': 215008, 'Pennsylvania Highlands Community College': 414911, 'Pennsylvania Institute of Health and Technology': 261861, 'Pennsylvania Institute of Technology': 214582, 'Pennsylvania State System of Higher Education-Central Office': 214661, 'Pennsylvania State University-College of Medicine': 214616, 'Pennsylvania State University-Dickinson Law': 212018, 'Pennsylvania State University-Main Campus': 214777, 'Pennsylvania State University-Penn State Abington': 214801, 'Pennsylvania State University-Penn State Altoona': 214689, 'Pennsylvania State University-Penn State Beaver': 214698, 'Pennsylvania State University-Penn State Berks': 214704, 'Pennsylvania State University-Penn State Brandywine': 214731, 'Pennsylvania State University-Penn State DuBois': 214740, 'Pennsylvania State University-Penn State Erie-Behrend College': 214591, 'Pennsylvania State University-Penn State Fayette- Eberly': 214759, 'Pennsylvania State University-Penn State Great Valley': 214607, 'Pennsylvania State University-Penn State Greater Allegheny': 214786, 'Pennsylvania State University-Penn State Harrisburg': 214713, 'Pennsylvania State University-Penn State Hazleton': 214768, 'Pennsylvania State University-Penn State Lehigh Valley': 214670, 'Pennsylvania State University-Penn State Mont Alto': 214795, 'Pennsylvania State University-Penn State New Kensington': 214625, 'Pennsylvania State University-Penn State Schuylkill': 214810, 'Pennsylvania State University-Penn State Scranton': 214652, 'Pennsylvania State University-Penn State Shenango': 214634, 'Pennsylvania State University-Penn State Wilkes-Barre': 214643, 'Pennsylvania State University-Penn State York': 214829, 'Pennsylvania State University-World Campus': 479956, 'Penrose Academy': 460914, 'Pensacola School of Massage Therapy & Health Careers': 449533, 'Pensacola State College': 136473, 'Penta County Joint Vocational School': 418199, 'Pentecostal Theological Seminary': 219842, 'Pepperdine University': 121150, 'Peralta Community College System Office': 121178, 'Perry Technical Institute': 236212, 'Peru State College': 181534, 'Pets Playground Grooming School': 491534, 'Pfeiffer University': 199306, 'Phagans Beauty College': 209667, 'Phagans Central Oregon Beauty College': 209676, 'Phagans Grants Pass College of Beauty': 208859, 'Phagans Medford Beauty School': 209153, 'Phagans School of Beauty': 209694, 'Phagans School of Hair Design': 209700, 'Philadelphia College of Osteopathic Medicine': 215123, 'Philadelphia Technician Training': 483823, 'Philander Smith College': 107600, 'Phillips Community College of the University of Arkansas': 107619, 'Phillips School of Nursing at Mount Sinai Beth Israel': 189282, 'Phillips Theological Seminary': 414966, 'Phipps Academy of Barbering': 488396, 'Phoenix College': 105428, 'Phoenix Institute of Herbal Medicine & Acupuncture': 447698, 'Phoenix Seminary': 381459, 'PiBerry Institute': 488147, 'Pickaway Ross Joint Vocational School District': 407513, 'Pickens Technical College': 128151, 'Piedmont College': 140818, 'Piedmont Community College': 199324, 'Piedmont International University': 489937, 'Piedmont Technical College': 218520, 'Piedmont Virginia Community College': 233116, 'Pierce College-Fort Steilacoom': 235237, 'Pierce College-Puyallup': 439145, 'Pierpont Community and Technical College': 443492, 'Pike County Joint Vocational School District': 409537, 'Pike-Lincoln Technical Center': 261773, 'Pikes Peak Community College': 127820, 'Pillar College': 440794, 'Pima Community College': 105525, 'Pima Medical Institute-Albuquerque': 105543, 'Pima Medical Institute-Albuquerque West': 442967, 'Pima Medical Institute-Aurora': 461689, 'Pima Medical Institute-Chula Vista': 434140, 'Pima Medical Institute-Colorado Springs': 442134, 'Pima Medical Institute-Denver': 404912, 'Pima Medical Institute-Dillon': 489812, 'Pima Medical Institute-East Valley': 456038, 'Pima Medical Institute-El Paso': 486813, 'Pima Medical Institute-Houston': 460136, 'Pima Medical Institute-Las Vegas': 445230, 'Pima Medical Institute-Mesa': 260691, 'Pima Medical Institute-Phoenix': 486822, 'Pima Medical Institute-Renton': 449074, 'Pima Medical Institute-San Marcos': 492449, 'Pima Medical Institute-Seattle': 368629, 'Pima Medical Institute-Tucson': 105534, 'Pima Medical Institution-San Antonio': 494588, 'Pine Manor College': 167455, 'Pine Technical & Community College': 174570, 'Pinellas Technical College-Clearwater': 136491, 'Pinellas Technical College-St. Petersburg': 137087, 'Pineville Beauty School': 160199, 'Pinnacle Career Institute-North Kansas City': 453109, 'Pinnacle Career Institute-South Kansas City': 177302, 'Pinnacle Institute of Cosmetology': 408163, 'Pioneer Career and Technology Center': 407522, 'Pioneer Pacific College': 210076, 'Pioneer Technology Center': 364627, 'Pipo Academy of Hair Design': 418913, 'PITC Institute': 444811, 'Pitt Community College': 199333, 'Pittsburg State University': 155681, 'Pittsburgh Career Institute': 216782, 'Pittsburgh Institute of Aeronautics': 215381, 'Pittsburgh Institute of Mortuary Science Inc': 215390, 'Pittsburgh Technical College': 215415, 'Pittsburgh Theological Seminary': 215424, 'Pitzer College': 121257, 'Pivot Point Academy': 373216, "PJ's College of Cosmetology-Bowling Green": 156310, "PJ's College of Cosmetology-Clarksville": 150853, "PJ's College of Cosmetology-Glasgow": 156754, "PJ's College of Cosmetology-Richmond": 152150, 'Platt College': 245962, 'Platt College-Anaheim': 490878, 'Platt College-Arizona Automotive Institute Arizona': 103963, 'Platt College-Aurora': 260813, 'Platt College-Berks Technical Institute': 213534, 'Platt College-Edge Tech Academy': 491394, 'Platt College-Lawton': 428143, 'Platt College-Los Angeles': 260789, 'Platt College-McCann-Allentown': 456579, 'Platt College-McCann-Lewisburg': 438221, 'Platt College-McCann-Monroe': 367112, 'Platt College-Miller-Motte Technical-Augusta': 460826, 'Platt College-Miller-Motte Technical-Charleston': 441025, 'Platt College-Miller-Motte Technical-Chattanooga': 443650, 'Platt College-Miller-Motte Technical-Columbus': 458441, 'Platt College-Miller-Motte Technical-Conway': 460835, 'Platt College-Miller-Motte Technical-Macon': 475060, 'Platt College-Miller-Motte-Cary': 449117, 'Platt College-Miller-Motte-Fayetteville': 458405, 'Platt College-Miller-Motte-Jacksonville': 460817, 'Platt College-Miller-Motte-Raleigh': 456205, 'Platt College-Miller-Motte-Wilmington': 198978, 'Platt College-Moore': 447379, 'Platt College-OKC-Memorial': 445258, 'Platt College-Ontario': 432384, 'Platt College-Riverside': 480204, 'Platt College-San Diego': 121275, 'Platt College-STVT-Corpus Christi': 456931, 'Platt College-STVT-McAllen': 228219, 'Platt College-STVT-San Antonio': 460172, 'Plaza College': 194499, 'Plymouth State University': 183080, 'PMCA Pittsburgh Multicultural Cosmetology Academy': 493576, 'Point Loma Nazarene University': 121309, 'Point Park University': 215442, 'Point University': 138868, 'Polaris Career Center': 390905, 'Polk State College': 136516, 'Polytech Adult Education': 491473, 'Polytechnic University of Puerto Rico-Miami': 456481, 'Polytechnic University of Puerto Rico-Orlando': 456490, 'Pomeroy College of Nursing at Crouse Hospital': 190451, 'Pomona College': 121345, 'Pomona Unified School District Adult and Career Education': 372082, 'Ponca City Beauty College': 245980, 'Ponce Health Sciences University': 243081, 'Ponce Health Sciences University-Centro Universitario de San Juan': 492704, 'Ponce Health Sciences University-East': 494807, 'Ponce Health Sciences University-St Louis': 494010, 'Ponce Paramedical College Inc': 243072, 'Pontifical Catholic University of Puerto Rico-Arecibo': 241395, 'Pontifical Catholic University of Puerto Rico-Mayaguez': 243586, 'Pontifical Catholic University of Puerto Rico-Ponce': 241410, 'Pontifical College Josephinum': 205027, 'Pontifical Faculty of the Immaculate Conception at the Dominican House of Studies': 131405, 'Pontifical John Paul II Institute for Studies on Marriage and Family': 455813, 'Pontotoc Technology Center': 206905, 'Pope St John XXIII National Seminary': 167464, 'Poplar Bluff Technical Career Center': 178828, 'Port Huron Cosmetology College': 171775, 'Portage Lakes Career Center': 364636, 'Porter and Chester Institute of Hamden': 129002, 'Porter and Chester Institute of Stratford': 130174, 'Porterville College': 121363, 'Portland Actors Conservatory': 457925, 'Portland Community College': 209746, 'Portland State University': 209807, 'Post University': 130183, 'Potomac State College of West Virginia University': 237701, 'Poway Adult School': 492315, 'PPG Technical College': 486576, 'Prairie State College': 148007, 'Prairie View A & M University': 227526, 'Pratt Community College': 155715, 'Pratt Institute-Main': 194578, 'Praxis Institute': 430582, 'Precision Manufacturing Institute': 446455, 'Premier Academy of Cosmetology': 493691, 'Premier Barber Institute': 488369, 'Premiere Career College': 416458, 'Premiere International College': 493488, 'Preparing People Barber Styling College': 484154, 'Presbyterian College': 218539, 'Presbyterian Theological Seminary in America': 490045, 'Prescott College': 105589, 'Presentation College': 219295, 'Presidio Graduate School': 486433, 'Prestige Health & Beauty Sciences Academy': 481368, "Prince George's Community College": 163657, 'Princess Beauty School': 486327, 'Princess Institute of Beauty': 491853, 'Princeton Theological Seminary': 186122, 'Princeton University': 186131, 'Principia College': 148016, 'Prism Career Institute-Cherry Hill': 420130, 'Prism Career Institute-Philadelphia': 417840, 'Prism Career Institute-West Atlantic City': 430403, 'Pro Beauty Academy': 493628, 'Pro Way Hair School': 139506, 'Professional Academy of Cosmetology': 486105, 'Professional Career Training Institute': 458016, 'Professional Cosmetology Education Center': 107655, 'Professional Golfers Career College': 437750, 'Professional Hands Institute': 454908, 'Professional Institute of Beauty': 121433, 'Professional Skills Institute': 205054, 'Professional Technical Institution Inc': 409193, "Professional's Choice Hair Design Academy": 148098, 'Profile Institute of Barber-Styling': 457466, 'Protege Academy': 487083, 'Providence Christian College': 455770, 'Providence College': 217402, 'Provo College': 380438, 'Pryor Beauty College': 436067, 'Pueblo Community College': 127884, 'Puerto Rico School of Nurse Anesthetists': 493673, 'Purdue University Fort Wayne': 151102, 'Purdue University Global': 489779, 'Purdue University Global-Augusta': 480064, 'Purdue University Global-Cedar Falls': 260910, 'Purdue University Global-Cedar Rapids': 153418, 'Purdue University Global-Davenport': 260901, 'Purdue University Global-Des Moines': 367024, 'Purdue University Global-Hagerstown': 162681, 'Purdue University Global-Lewiston': 160940, 'Purdue University Global-Lincoln': 181242, 'Purdue University Global-Mason City': 153409, 'Purdue University Global-Milwaukee': 489788, 'Purdue University Global-Omaha': 181400, 'Purdue University Global-St. Louis': 490771, 'Purdue University Northwest': 490805, 'Purdue University-Main Campus': 243780, 'Pure Aesthetics Natural Skincare School': 461713, 'Putnam Career and Technical Center': 419420, 'Quality Technical and Beauty College': 418764, 'Queen City College': 376677, 'Queens University of Charlotte': 199412, 'Quest College': 439507, 'Quincy College': 167525, 'Quincy University': 148131, 'Quinebaug Valley Community College': 130217, 'Quinnipiac University': 130226, 'Quinsigamond Community College': 167534, 'Rabbi Jacob Joseph School': 384421, 'Rabbinical Academy Mesivta Rabbi Chaim Berlin': 194657, 'Rabbinical College Beth Shraga': 194693, 'Rabbinical College Bobover Yeshiva Bnei Zion': 194666, 'Rabbinical College of America': 186186, 'Rabbinical College of Long Island': 194736, 'Rabbinical College of Ohr Shimon Yisroel': 405854, 'Rabbinical College Ohr Yisroel': 484871, 'Rabbinical College Telshe': 205124, 'Rabbinical Seminary of America': 194763, 'Radford M Locklin Technical College': 136659, 'Radford University': 233277, 'Radford University-Carilion': 231837, 'Radiological Technologies University VT': 488776, 'Rainy River Community College': 174604, 'Ralph R Willis Career and Technical Center': 237491, 'Ramapo College of New Jersey': 186201, 'Rancho Santiago Community College District Office': 438665, 'Randall University': 207157, 'Randolph College': 233301, 'Randolph Community College': 199421, 'Randolph Technical Center': 486406, 'Randolph-Macon College': 233295, 'Ranger College': 227687, 'Ranken Technical College': 178891, "Raphael's School of Beauty Culture Inc-Alliance": 363147, "Raphael's School of Beauty Culture Inc-Boardman": 407568, "Raphael's School of Beauty Culture Inc-Brunswick": 363882, "Raphael's School of Beauty Culture Inc-Niles": 205142, 'Rappahannock Community College': 233310, 'Raritan Valley Community College': 186645, 'Rasmussen College-Florida': 138309, 'Rasmussen College-Illinois': 448673, 'Rasmussen College-Kansas': 480657, 'Rasmussen College-Minnesota': 175014, 'Rasmussen College-North Dakota': 200013, 'Rasmussen College-Wisconsin': 450571, 'Ravenscroft Beauty College': 152275, "Ray J's College of Hair": 490531, 'Reading Area Community College': 215585, 'Reading Hospital School of Health Sciences': 215594, 'Reconstructionist Rabbinical College': 215619, 'Red Lake Nation College': 491844, 'Red River Technology Center': 250993, 'Red Rocks Community College': 127909, 'Redlands Community College': 207069, 'Redondo Beach Beauty College': 114637, 'Reed College': 209922, 'Reedley College': 117052, 'Reflections Academy of Beauty': 475653, 'Reformed Presbyterian Theological Seminary': 215628, 'Reformed University': 490230, 'Refrigeration School Inc': 105659, 'Regan Career Institute': 490197, 'Regent University': 231651, 'Regina Webb Academy': 488183, 'Regional Center for Border Health': 487889, 'Regis College': 167598, 'Regis University': 127918, 'Reid State Technical College': 101994, 'Reinhardt University': 140872, 'Reiss-Davis Graduate Center': 492209, 'Relay Graduate School of Education': 475033, 'Remington College-Baton Rouge Campus': 440271, 'Remington College-Cleveland Campus': 375416, 'Remington College-Columbia Campus': 457174, 'Remington College-Dallas Campus': 223463, 'Remington College-Fort Worth Campus': 377111, 'Remington College-Heathrow Campus': 460783, 'Remington College-Honolulu Campus': 372958, 'Remington College-Houston Southeast Campus': 451857, 'Remington College-Lafayette Campus': 160524, 'Remington College-Little Rock Campus': 438869, 'Remington College-Memphis Campus': 412599, 'Remington College-Mobile Campus': 366535, 'Remington College-Nashville Campus': 445249, 'Remington College-North Houston Campus': 445203, 'Remington College-Shreveport Campus': 451866, 'Renaissance Academie': 458104, 'Rend Lake College': 148256, 'Rensselaer at Hartford': 129428, 'Rensselaer Polytechnic Institute': 194824, 'Renton Technical College': 236382, 'Research College of Nursing': 178989, 'Resurrection University': 149763, 'Rexburg College of Massage Therapy': 491701, 'Rhode Island College': 217420, 'Rhode Island School of Design': 217493, 'Rhodes College': 221351, "Ricci's Academy of Cosmetology": 484127, 'Rice University': 227757, 'Richard Bland College': 233338, 'Richland College': 227766, 'Richland Community College': 148292, 'Richmond Community College': 199449, 'Richmont Graduate University': 441104, 'Richport Technical College': 242413, 'Rider University': 186283, 'Ridge Technical College': 136765, 'Ridgewater College': 175236, 'Ringling College of Art and Design': 136774, 'Rio Grande Valley College': 476726, 'Rio Hondo College': 121886, 'Rio Salado College': 105668, 'Ripon College': 239628, 'River Parishes Community College': 436304, 'River Valley Community College': 183114, 'River Valley Cosmetology Institute': 483717, 'River Valley School of Massage': 485704, 'Riverland Community College': 173063, 'Riveroak Technical College': 137713, 'Riverside City College': 121901, 'Riverside College of Health Careers': 233408, 'Riverside County Office of Education-School of Career Education': 481191, 'Rivertown School of Beauty Barber Skin Care and Nails': 419235, 'Rivier University': 183211, 'Rizzieri Aveda School for Beauty and Wellness': 185466, 'Rizzieri Institute': 481447, 'Roane State Community College': 221397, 'Roane-Jackson Technical Center': 364575, 'Roanoke College': 233426, 'Roanoke-Chowan Community College': 199467, 'Rob Roy Academy-Fall River': 165750, 'Rob Roy Academy-New Bedford': 167039, 'Rob Roy Academy-Taunton': 168032, 'Rob Roy Academy-Worcester': 373696, 'Robert Fiance Beauty Schools': 186274, 'Robert Fiance Beauty Schools-North Plainfield': 383279, 'Robert Fiance Beauty Schools-West New York': 185767, 'Robert Morgan Educational Center and Technical College': 136826, 'Robert Morris University': 215655, 'Robert Morris University Illinois': 148335, 'Robert Paul Academy of Cosmetology Arts & Sciences': 163754, 'Roberto-Venn School of Luthiery': 105677, 'Roberts Wesleyan College': 194958, 'Robeson Community College': 199476, 'Rochester Community and Technical College': 174738, 'Rochester Institute of Technology': 195003, 'Rochester University': 170967, 'Rock Valley College': 148380, 'Rockefeller University': 195049, 'Rockford University': 148405, 'Rockhurst University': 179043, 'Rockingham Community College': 199485, 'Rockland Community College': 195058, 'Rockland County BOCES-Practical Nursing Program': 418083, 'Rocky Mountain College': 180595, 'Rocky Mountain College of Art and Design': 127945, 'Rocky Mountain University of Health Professions': 475495, 'Rocky Vista University': 480790, 'Roger Williams University': 217518, 'Roger Williams University School of Law': 409616, 'Rogers Academy of Hair Design': 152309, 'Rogers State University': 207661, 'Rogue Community College': 209940, 'Rolf Institute of Structural Integration': 262466, 'Rolla Technical Institute/Center': 179052, 'Rollins College': 136950, 'Roosevelt University': 148487, 'Rosalind Franklin University of Medicine and Science': 145558, 'Rose State College': 207670, 'Rose-Hulman Institute of Technology': 152318, 'Rosedale Bible College': 439899, 'Rosedale Technical College': 215682, 'Rosel School of Cosmetology': 369446, 'Roseman University of Health Sciences': 445735, 'Rosemead Beauty School': 121992, 'Rosemont College': 215691, 'Ross College-Canton': 490832, 'Ross College-Grand Rapids North': 490841, 'Ross College-Hopkinsville': 421513, 'Ross College-Quad Cities': 373085, 'Ross College-Sylvania': 452081, 'Ross Medical Education Center - Kalamazoo': 490814, 'Ross Medical Education Center-Ann Arbor': 261685, 'Ross Medical Education Center-Battle Creek': 456515, 'Ross Medical Education Center-Bowling Green': 480550, 'Ross Medical Education Center-Brighton': 261676, 'Ross Medical Education Center-Canton': 460127, 'Ross Medical Education Center-Charleston': 481906, 'Ross Medical Education Center-Cincinnati': 203234, 'Ross Medical Education Center-Davison': 460093, 'Ross Medical Education Center-Dayton': 480523, 'Ross Medical Education Center-Elyria': 488952, 'Ross Medical Education Center-Erlanger': 481890, 'Ross Medical Education Center-Evansville': 484349, 'Ross Medical Education Center-Flint': 172015, 'Ross Medical Education Center-Fort Wayne': 456506, 'Ross Medical Education Center-Granger': 460109, 'Ross Medical Education Center-Huntsville': 486707, 'Ross Medical Education Center-Johnson City': 484358, 'Ross Medical Education Center-Kentwood': 365833, 'Ross Medical Education Center-Knoxville': 486716, 'Ross Medical Education Center-Kokomo': 481863, 'Ross Medical Education Center-Lafayette': 488961, 'Ross Medical Education Center-Lansing': 171988, 'Ross Medical Education Center-Madison Heights': 171997, 'Ross Medical Education Center-Midland': 488970, 'Ross Medical Education Center-Morgantown': 476230, 'Ross Medical Education Center-Muncie': 486752, 'Ross Medical Education Center-New Baltimore': 452072, 'Ross Medical Education Center-Niles': 460118, 'Ross Medical Education Center-Ontario': 480532, 'Ross Medical Education Center-Owensboro': 484330, 'Ross Medical Education Center-Port Huron': 363013, 'Ross Medical Education Center-Roosevelt Park': 365824, 'Ross Medical Education Center-Saginaw': 247409, 'Ross Medical Education Center-Taylor': 367158, 'Rosslyn Training Academy of Cosmetology': 446516, 'Rowan College at Burlington County': 183877, 'Rowan College of South Jersey Gloucester Campus': 184791, 'Rowan University': 184782, 'Rowan-Cabarrus Community College': 199494, 'Roxborough Memorial Hospital School of Nursing': 213932, 'Roxbury Community College': 167631, 'Royale College of Beauty and Barbering': 382267, "Rudae's School of Beauty Culture-Ft Wayne": 437857, 'Rudy & Kelly Academy-A Paul Mitchell Partner School': 441876, 'Rush University': 148511, 'Rust College': 176318, 'Rutgers University-Camden': 186371, 'Rutgers University-New Brunswick': 186380, 'Rutgers University-Newark': 186399, 'SABER College': 449506, 'Sacramento City College': 122180, 'Sacramento Ultrasound Institute': 490160, 'Sacred Heart Major Seminary': 172033, 'Sacred Heart Seminary and School of Theology': 239637, 'Sacred Heart University': 130253, 'Saddleback College': 122205, 'SAE Expression College': 447458, 'SAE Institute of Technology-Atlanta': 476948, 'SAE Institute of Technology-Chicago': 485139, 'SAE Institute of Technology-Los Angeles': 476911, 'SAE Institute of Technology-Miami': 476966, 'SAE Institute of Technology-Nashville': 446525, 'SAE Institute of Technology-New York': 459462, 'Sage School of Massage & Esthetics': 459499, 'Saginaw Chippewa Tribal College': 441070, 'Saginaw Valley State University': 172051, 'Saint Ambrose University': 154235, 'Saint Anselm College': 183239, 'Saint Anthony College of Nursing': 149028, 'Saint Augustine College': 148876, "Saint Augustine's University": 199582, 'Saint Charles Borromeo Seminary-Overbrook': 216047, 'Saint Cloud State University': 174783, "Saint Edward's University": 227845, 'Saint Elizabeth College of Nursing': 195702, 'Saint Elizabeth School of Nursing': 152497, 'Saint Francis Medical Center College of Nursing': 148575, 'Saint Francis Medical Center School of Nursing': 186423, 'Saint Francis University': 215743, 'Saint John Fisher College': 195720, 'Saint John Vianney College Seminary': 137272, "Saint John's Seminary": 167677, 'Saint Johns River State College': 137281, 'Saint Johns University': 174792, 'Saint Joseph Seminary College': 160409, "Saint Joseph's College of Maine": 161518, "Saint Joseph's University": 215770, 'Saint Leo University': 137032, 'Saint Louis Christian College': 179256, 'Saint Louis Community College': 179308, 'Saint Louis University': 179159, "Saint Luke's College of Health Sciences": 179450, "Saint Martin's University": 236452, "Saint Mary's College": 152390, "Saint Mary's College of California": 123554, "Saint Mary's University of Minnesota": 174817, 'Saint Mary-of-the-Woods College': 152381, 'Saint Meinrad School of Theology': 152451, 'Saint Michael College of Allied Health': 486424, "Saint Michael's College": 231059, 'Saint Norbert College': 239716, 'Saint Paul College': 175041, 'Saint Paul School of Theology': 179317, "Saint Peter's University": 186432, 'Saint Vincent College': 215798, 'Saint Vincent de Paul Regional Seminary': 136701, 'Saint Vincent Seminary': 215813, 'Saint Vladimirs Orthodox Theological Seminary': 195580, 'Saint Xavier University': 148627, 'Salem College': 199607, 'Salem College of Hairstyling': 179195, 'Salem Community College': 186469, 'Salem State University': 167729, 'Salem University': 237783, 'Salina Area Technical College': 155830, 'Saline County Career Center': 417646, 'Salisbury University': 163851, 'Salish Kootenai College': 180647, 'Salon & Spa Institute': 459532, 'Salon Boutique Academy': 485874, 'Salon Institute-Toledo Campus': 476629, 'Salon Professional Academy of San Antonio': 491835, 'Salon Success Academy-Corona': 121868, 'Salon Success Academy-Fontana': 456588, 'Salon Success Academy-Redlands': 456597, 'Salon Success Academy-Riverside': 115357, 'Salon Success Academy-Upland': 121859, 'Salon Success Academy-West Covina': 492953, 'Salt Lake Community College': 230746, 'Salter College-Chicopee': 466523, 'Salter College-West Boylston': 167738, 'Salus University': 214564, 'Salve Regina University': 217536, 'Sam Houston State University': 227881, 'Samaritan Hospital School of Nursing': 195289, 'Samford University': 102049, 'Sampson Community College': 199625, 'Samuel Merritt University': 122296, 'San Antonio College': 227924, 'San Bernardino Beauty College': 491543, 'San Bernardino Community College District': 428426, 'San Bernardino Valley College': 123527, 'San Diego Christian College': 112084, 'San Diego City College': 122339, 'San Diego Community College District-District Office': 122320, 'San Diego Culinary Institute': 457244, 'San Diego Global Knowledge University': 493512, 'San Diego Mesa College': 122375, 'San Diego Miramar College': 122384, 'San Diego State University': 122409, 'San Francisco Art Institute': 122454, 'San Francisco Conservatory of Music': 122506, 'San Francisco Film School': 486372, 'San Francisco Institute of Esthetics & Cosmetology Inc': 454777, 'San Francisco State University': 122597, 'San Francisco Theological Seminary': 122603, 'San Ignacio University': 486239, 'San Jacinto Community College': 227979, 'San Joaquin College of Law': 122649, 'San Joaquin Delta College': 122658, 'San Joaquin Valley College-Central Administrative Office': 448381, 'San Joaquin Valley College-Visalia': 122685, 'San Jose City College': 122746, 'San Jose State University': 122755, 'San Jose-Evergreen Community College District': 122737, 'San Juan Bautista School of Medicine': 430670, 'San Juan College': 188100, 'San Mateo County Community College District Office': 122782, 'Sandhills Community College': 199634, 'Sandra Academy of Salon Services  Inc': 486442, 'Sandusky Career Center': 383330, 'Sanford Medical Center': 219392, 'SANS Technology Institute': 493895, 'Santa Ana Beauty Academy': 461500, 'Santa Ana Beauty College': 481128, 'Santa Ana College': 121619, 'Santa Barbara Business College-Bakersfield': 122834, 'Santa Barbara Business College-Santa Maria': 122852, 'Santa Barbara City College': 122889, 'Santa Clara University': 122931, 'Santa Fe College': 137096, 'Santa Fe Community College': 188137, 'Santa Monica College': 122977, 'Santa Rosa Junior College': 123013, 'Santiago Canyon College': 399212, 'Sarah Lawrence College': 195304, 'Sarasota School of Massage Therapy': 406149, 'Sauk Valley Community College': 148672, 'Savannah College of Art and Design': 140951, 'Savannah Law School': 480301, 'Savannah State University': 140960, 'Savannah Technical College': 140942, 'Saybrook University': 123095, 'Schenectady County Community College': 195322, 'Schiller International University': 404338, 'Schilling-Douglas School of Hair Design LLC': 131061, 'School of Architecture at Taliesin': 104665, 'School of Automotive Machinists & Technology': 377218, 'School of Missionary Aviation Technology': 480727, 'School of Professional Horticulture  New York Botanical Garden': 392354, 'School of the Art Institute of Chicago': 143048, 'School of Visual Arts': 197151, 'Schoolcraft College': 172200, 'Schreiner University': 228042, 'Schuyler Steuben Chemung Tioga Allegany BOCES': 406325, 'Schuylkill Technology Center': 215886, 'Scioto County Career Technical Center': 407577, 'Scott College of Cosmetology': 201982, 'Scottsdale Community College': 105747, 'Scripps College': 123165, 'Searcy Beauty College': 107831, 'Seattle Central College': 236513, 'Seattle Film Institute': 488448, 'Seattle Institute of East Asian Medicine': 439914, 'Seattle Pacific University': 236577, 'Seattle University': 236595, 'Sebring Career Schools-Houston': 369695, 'Sebring Career Schools-Huntsville': 246406, 'Seguin Beauty School-New Braunfels': 368540, 'Seguin Beauty School-Seguin': 228088, 'Selma University': 102058, "Seminar L'moros Bais Yaakov": 386153, 'Seminario Evangelico de Puerto Rico': 243498, 'Seminary Bnos Chaim': 491817, 'Seminole State College': 207740, 'Seminole State College of Florida': 137209, 'Sentara College of Health Sciences': 232885, 'Sessions College for Professional Design': 475839, 'Seton Hall University': 186584, 'Seton Hill University': 215947, 'Setting the Standard Barbering and Natural Hair Academy': 483939, 'Seward County Community College': 155858, "Sh'or Yoshuv Rabbinical College": 195438, 'Sharon Regional School of Nursing': 215983, 'Sharp Edgez Barber Institute': 481331, 'Sharps Academy of Hair Styling': 391759, 'Shasta Bible College and Graduate School': 123280, 'Shasta College': 123299, 'Shasta School of Cosmetology': 121637, 'Shaw University': 199643, 'Shawnee Beauty College': 439932, 'Shawnee Community College': 148821, 'Shawnee State University': 205443, 'Shawsheen Valley School of Practical Nursing': 412535, 'Shear Ego International School of Hair Design': 412544, 'Shear Excellence Hair Academy': 451167, 'Shear Finesse Beauty Academy': 480842, 'Shear Perfection Academy of Cosmetology': 493789, 'Shelton State Community College': 102067, 'Shenandoah University': 233541, 'Shepherd University': 237792, 'Shepherds College': 481137, 'Shepherds Theological Seminary': 461485, 'Sheridan Technical College': 137245, 'Sherman College of Chiropractic': 218751, "Sherrill's University of Barber & Cosmetology": 199670, 'Shiloh University': 480499, 'Shippensburg University of Pennsylvania': 216010, 'Shoreline Community College': 236610, 'Shorter College': 107840, 'Shorter University': 140988, 'Siena College': 195474, 'Siena Heights University': 172264, 'Sierra College': 123341, 'Sierra College of Beauty': 123350, 'Sierra Nevada College': 182458, 'Signature Healthcare Brockton Hospital School of Nursing': 165060, 'Sikeston Career and Technology Center': 179238, 'Simmons College of Kentucky': 461759, 'Simmons University': 167783, 'Simpson College': 154350, 'Simpson University': 123457, 'Sinclair Community College': 205470, 'Sinte Gleska University': 219374, 'Sioux Falls Seminary': 219240, 'Sisseton Wahpeton College': 219408, 'Sistema Universitario Ana G. Mendez': 242060, 'SIT Graduate Institute': 231068, 'Sitting Bull College': 200466, 'Skagit Valley College': 236638, 'Skidmore College': 195526, 'Skin Institute': 460932, 'Skin Science Institute': 455381, 'Skinworks School of Advanced Skincare': 444857, 'Skokie Institute of Allied Health and Technology': 492227, 'Skyline College': 123509, 'Slippery Rock University of Pennsylvania': 216038, 'Smith College': 167835, 'Snead State Community College': 102076, 'Snow College': 230597, 'Sofia University': 110778, 'Soka University of America': 399911, 'Solano Community College': 123563, 'Soma Institute-The National School of Clinical Massage Therapy': 445957, 'Somerset Community College': 157711, 'Somerset County Technology Center': 457943, 'Sonoma State University': 123572, 'Sonoran Desert Institute': 488077, "Sotheby's Institute of Art-NY": 481094, 'South Arkansas Community College': 107974, 'South Baylo University': 123633, 'South Carolina State University': 218733, 'South Central Career Center': 417637, 'South Central College': 173911, 'South Central Louisiana Technical College': 160913, 'South Coast College': 123642, 'South College': 220552, 'South Dade Technical College-South Dade Skills Center Campus': 488891, 'South Dakota School of Mines and Technology': 219347, 'South Dakota State University': 219356, 'South Eastern Beauty Academy': 493637, 'South Florida Bible College and Theological Seminary': 366003, 'South Florida Institute of Technology': 443252, 'South Florida State College': 137315, 'South Georgia State College': 482699, 'South Georgia Technical College': 141006, 'South Hills Beauty Academy': 216074, 'South Hills School of Business & Technology': 216083, 'South Louisiana Community College': 434061, 'South Mountain Community College': 105792, 'South Orange County Community College District': 432144, 'South Piedmont Community College': 197850, 'South Plains College': 228158, 'South Puget Sound Community College': 236656, 'South Seattle College': 236504, 'South Suburban College': 149365, 'South Texas Barber College Inc': 228185, 'South Texas College': 409315, 'South Texas College of Law Houston': 228194, 'South Texas Training Center': 455974, 'South Texas Vocational Technical Institute-Brownsville': 456922, 'South Texas Vocational Technical Institute-Weslaco': 228200, 'South University-Austin': 480073, 'South University-Cleveland': 480082, 'South University-Columbia': 251312, 'South University-High Point': 481720, 'South University-Montgomery': 101116, 'South University-Novi': 468024, 'South University-Savannah': 139579, 'South University-Tampa': 449898, 'South University-West Palm Beach': 133465, 'South University–Richmond': 459259, 'South University–Savannah Online': 475121, 'South University–Virginia Beach': 459268, 'Southcentral Kentucky Community and Technical College': 156338, 'Southeast Arkansas College': 107637, 'Southeast Community College Area': 181640, 'Southeast Kentucky Community and Technical College': 157739, 'Southeast Missouri Hospital College of Nursing and Health Sciences': 417734, 'Southeast Missouri State University': 179557, 'Southeast Technical Institute': 219426, 'Southeast Texas Career Institute': 449807, 'Southeastern Baptist College': 176336, 'Southeastern Baptist Theological Seminary': 199759, 'Southeastern College-West Palm Beach': 428170, 'Southeastern Community College': 154378, 'Southeastern Esthetics Institute': 491923, 'Southeastern Free Will Baptist Bible College': 233602, 'Southeastern Illinois College': 148937, 'Southeastern Institute-Charleston': 443261, 'Southeastern Institute-Charlotte': 451352, 'Southeastern Institute-Columbia': 444866, 'Southeastern Louisiana University': 160612, 'Southeastern Oklahoma State University': 207847, 'Southeastern Technical College': 368911, 'Southeastern Technical Institute': 167871, 'Southeastern University': 137564, 'Southern Adventist University': 221661, 'Southern Arkansas University Main Campus': 107983, 'Southern Arkansas University Tech': 107992, 'Southern California Health Institute': 461856, 'Southern California Institute of Architecture': 123952, 'Southern California Institute of Technology': 399869, 'Southern California Seminary': 117575, 'Southern California University of Health Sciences': 117672, 'Southern Careers Institute-Austin': 226903, 'Southern Careers Institute-Brownsville': 459967, 'Southern Careers Institute-Corpus Christi': 405076, 'Southern Careers Institute-Harlingen': 459985, 'Southern Careers Institute-Pharr': 408385, 'Southern Careers Institute-San Antonio': 482015, 'Southern Careers Institute-Waco': 493992, 'Southern College of Optometry': 221670, 'Southern Connecticut State University': 130493, 'Southern Crescent Technical College': 139986, 'Southern Illinois University-Carbondale': 149222, 'Southern Illinois University-Edwardsville': 149231, 'Southern Illinois University-System Office': 149240, 'Southern Maine Community College': 161545, 'Southern Methodist University': 228246, 'Southern Nazarene University': 206862, 'Southern New Hampshire University': 183026, 'Southern Oklahoma Technology Center': 365198, 'Southern Oregon University': 210146, 'Southern Regional Technical College': 487162, 'Southern School of Beauty Inc': 207786, 'Southern State Community College': 205966, 'Southern States University': 490063, 'Southern Technical College': 366553, 'Southern Texas Careers Academy': 481322, 'Southern Union State Community College': 251260, 'Southern University and A & M College': 160621, 'Southern University at New Orleans': 160630, 'Southern University at Shreveport': 160649, 'Southern University Law Center': 440916, 'Southern University-Board and System': 160533, 'Southern Utah University': 230603, 'Southern Vermont College': 231086, 'Southern Virginia University': 233611, 'Southern Wesleyan University': 217776, 'Southern West Virginia Community and Technical College': 237817, 'Southern Westchester BOCES-Practical Nursing Program': 193122, 'Southern Worcester County Regional Vocational School District': 457624, 'Southside College of Health Sciences': 233082, 'Southside Virginia Community College': 233639, 'Southwest Acupuncture College-Boulder': 436261, 'Southwest Acupuncture College-Santa Fe': 366605, 'Southwest Baptist University': 179326, 'Southwest College of Naturopathic Medicine & Health Sciences': 420246, 'Southwest Collegiate Institute for the Deaf': 382911, 'Southwest Institute of Healing Arts': 442879, 'Southwest Minnesota State University': 175078, 'Southwest Mississippi Community College': 176354, 'Southwest School of Business and Technical Careers-San Antonio': 228282, 'Southwest Technical College': 449816, 'Southwest Technology Center': 368364, 'Southwest Tennessee Community College': 221485, 'Southwest Texas Junior College': 228316, 'Southwest University at El Paso': 451556, 'Southwest University of Visual Arts-Albuquerque': 402776, 'Southwest University of Visual Arts-Tucson': 104188, 'Southwest Virginia Community College': 233648, 'Southwest Wisconsin Technical College': 239910, 'Southwestern Adventist University': 228468, 'Southwestern Assemblies of God University': 228325, 'Southwestern Baptist Theological Seminary': 494603, 'Southwestern Christian College': 228486, 'Southwestern Christian University': 207856, 'Southwestern College': 155900, 'Southwestern Community College': 199731, 'Southwestern Illinois College': 143215, 'Southwestern Indian Polytechnic Institute': 188216, 'Southwestern Law School': 123970, 'Southwestern Michigan College': 172307, 'Southwestern Oklahoma State University': 207865, 'Southwestern Oregon Community College': 210155, 'Southwestern University': 228343, 'Sovah School of Health Professions': 232724, 'SOWELA Technical Community College': 160579, 'Spa Tech Institute-Ipswich': 445638, 'Spa Tech Institute-Plymouth': 445656, 'Spa Tech Institute-Westboro': 445647, 'Spa Tech Institute-Westbrook': 161527, 'Spalding University': 157757, 'Spartan College of Aeronautics & Technology': 413680, 'Spartan College of Aeronautics and Technology': 207254, 'Spartanburg Community College': 218830, 'Spartanburg Methodist College': 218821, 'Specs Howard School of Media Arts': 172325, 'Spelman College': 141060, 'Spertus College': 148982, 'Spokane Community College': 236692, 'Spokane Falls Community College': 236708, 'Spoon River College': 148991, 'Spring Arbor University': 172334, 'Spring Hill College': 102234, 'Springfield College': 167899, 'Springfield College-Regional  Online  and Continuing Education': 475273, 'Springfield Technical Community College': 167905, "St Bernard's School of Theology and Ministry": 195155, 'St Bonaventure University': 195164, 'St Catherine University': 175005, 'St Charles Community College': 262031, 'St Clair County Community College': 172291, 'St Cloud Technical and Community College': 174756, 'St Francis College': 195173, 'St Francis Medical Center-School of Radiologic Technology': 186405, "St John's Seminary": 123855, "St John's University-New York": 195809, 'St Joseph School of Nursing': 217572, 'St Lawrence University': 195216, 'St Louis College of Health Careers-Fenton': 442426, 'St Louis College of Health Careers-St Louis': 179511, "St Luke's College": 154262, 'St Lukes Hospital School of Nursing': 216162, 'St Margaret School of Nursing': 213622, 'St Olaf College': 174844, "St Paul's School of Nursing-Queens": 189811, "St Paul's School of Nursing-Staten Island": 195784, 'St Petersburg College': 137078, "St Philip's College": 227854, 'St. Andrews University': 199698, "St. John's College": 163976, "St. John's College-Department of Nursing": 148593, "St. Joseph's College of Nursing": 195191, "St. Joseph's College-Long Island": 195562, "St. Joseph's College-New York": 195544, 'St. Louis College of Pharmacy': 179265, "St. Mary's College of Maryland": 163912, "St. Mary's University": 228149, "St. Peter's Hospital College of Nursing": 192961, 'St. Thomas Aquinas College': 195243, 'St. Thomas University': 137476, 'Stacey James Institute': 491792, 'Stage One-The Hair School': 407151, 'Stanbridge University': 446561, 'Stanbridge University-Los Angeles': 493318, 'Standard Healthcare Services-College of Nursing': 483814, 'Stanford University': 243744, 'Stanly Community College': 199740, 'Star College of Cosmetology 2': 382902, 'Stark State College': 205841, 'Starr King School for the Ministry': 123916, 'State Career College': 462053, 'State Center Community College District': 123925, 'State College of Beauty Culture Inc': 239877, 'State College of Florida-Manatee-Sarasota': 135391, 'State Fair Community College': 179539, 'State Technical College of Missouri': 177977, 'State University of New York at New Paltz': 196176, 'Staunton School of Cosmetology': 233666, 'Stautzenberger College-Brecksville': 448600, 'Stautzenberger College-Maumee': 205887, 'Stautzenberger College-Rockford Career College': 494852, 'Stellar Career College': 444529, 'Stephen F Austin State University': 228431, 'Stephens College': 179548, 'Sterling College': 155937, 'Stetson University': 137546, 'Steven Papageorge Hair Academy': 146807, 'Stevens Institute of Technology': 186867, 'Stevens-Henager College': 460899, 'Stevens-The Institute of Business & Arts': 178767, 'Stevenson University': 164173, 'Stevensons Academy of Hair Design': 160597, 'Stewart School': 219453, 'Stillman College': 102270, 'Stockton Christian Life College': 112093, 'Stockton University': 186876, 'Stone Academy-East Hartford': 448619, 'Stone Academy-Waterbury': 413778, 'Stone Academy-West Haven': 130509, 'Stone Child College': 366340, 'Stonehill College': 167996, 'Stony Brook University': 196097, 'Strand College of Hair Design': 434496, 'Strand Institute of Beauty & Esthetics': 491066, 'Stratford School for Aviation Maintenance Technicians': 417275, 'Stratford University': 438498, 'Strayer University-Alabama': 450377, 'Strayer University-Arkansas': 458885, 'Strayer University-Delaware': 450298, 'Strayer University-District of Columbia': 131803, 'Strayer University-Florida': 449038, 'Strayer University-Georgia': 458919, 'Strayer University-Global Region': 459994, 'Strayer University-Maryland': 430184, 'Strayer University-Mississippi': 458955, 'Strayer University-New Jersey': 453215, 'Strayer University-North Carolina': 453163, 'Strayer University-Pennsylvania': 443784, 'Strayer University-South Carolina': 458964, 'Strayer University-Tennessee': 443766, 'Strayer University-Texas': 458973, 'Strayer University-Virginia': 233684, 'Strayer University-West Virginia': 456621, 'Studio Academy of Beauty': 455725, 'Studio Beauty School': 485476, 'Studio Incamminati': 485856, 'Studio Jewelers': 430564, 'Stylemaster College of Hair Design': 236744, 'Suffolk Beauty Academy': 231721, 'Suffolk County Community College': 366395, 'Suffolk University': 168005, 'Sul Ross State University': 228501, 'Sullivan County Community College': 195988, 'Sullivan University': 157793, 'SUM Bible College and Theological Seminary': 447953, 'Summit Academy Opportunities Industrialization Center': 175120, 'Summit Christian College': 181543, 'Summit College': 400080, 'Summit Salon Academy': 459550, 'Summit Salon Academy Kansas City': 177603, 'Summit Salon Academy-Gainesville': 457439, 'Summit Salon Academy-Kokomo': 462017, 'Summit Salon Academy-Lexington': 156967, 'Summit Salon Academy-Perrysburg': 457916, 'Summit Salon Academy-Portland': 209719, 'Sumner College': 208512, 'Sumter Beauty College': 218867, 'Suncoast Technical College': 137120, 'Suncoast Technical Education Center': 491783, 'Sunstate Academy': 372718, 'Sunstate Academy-Jones Technical Institute': 487311, 'SUNY at Albany': 196060, 'SUNY at Fredonia': 196158, 'SUNY at Purchase College': 196219, 'SUNY Broome Community College': 189547, 'SUNY Buffalo State': 196130, 'SUNY College at Brockport': 196121, 'SUNY College at Geneseo': 196167, 'SUNY College at Old Westbury': 196237, 'SUNY College at Oswego': 196194, 'SUNY College at Plattsburgh': 196246, 'SUNY College at Potsdam': 196200, 'SUNY College of Agriculture and Technology at Cobleskill': 196033, 'SUNY College of Environmental Science and Forestry': 196103, 'SUNY College of Optometry': 196228, 'SUNY College of Technology at Alfred': 196006, 'SUNY College of Technology at Canton': 196015, 'SUNY College of Technology at Delhi': 196024, 'SUNY Corning Community College': 190442, 'SUNY Cortland': 196149, 'SUNY Downstate Health Sciences University': 196255, 'SUNY Empire State College': 196264, 'SUNY Maritime College': 196291, 'SUNY Morrisville': 196051, 'SUNY Oneonta': 196185, 'SUNY Polytechnic Institute': 196112, 'SUNY Westchester Community College': 197294, 'SUNY-System Office': 195827, 'Surry Community College': 199768, 'Susquehanna County Career and Technology Center': 441672, 'Susquehanna University': 216278, 'Sussex County Community College': 247603, 'Sutter Beauty College': 483610, 'Swarthmore College': 216287, 'Swedish Institute a College of Health Sciences': 196389, 'Sweet Briar College': 233718, 'Sylvain Melloul International Hair Academy': 233286, 'Syracuse University': 196413, 'Tabor College': 155973, 'Tacoma Community College': 236753, 'Taft College': 124113, 'Taft University System': 454689, 'Talladega College': 102298, 'Tallahassee Community College': 137759, 'Talmudic College of Florida': 137777, 'Talmudical Academy-New Jersey': 186900, 'Talmudical Institute of Upstate New York': 196440, 'Talmudical Seminary of Bobov': 451404, 'Talmudical Seminary Oholei Torah': 196431, 'Talmudical Yeshiva of Philadelphia': 216311, 'Tarleton State University': 228529, 'Tarrant County College District': 228547, 'Taylor Andrews Academy of Hair Design-Provo': 484394, 'Taylor Andrews Academy of Hair Design-West Jordan': 461494, 'Taylor Andrews Academy-St George': 461926, 'Taylor Business Institute': 149310, 'Taylor College': 449524, 'Taylor Institute of Cosmetology': 151564, 'Taylor University': 152530, 'Taylortown School of Beauty Inc': 261719, 'TDDS Technical Institute': 249566, 'Teachers College at Columbia University': 196468, 'Teachers College of San Joaquin': 488800, 'Technical College of the Lowcountry': 217712, 'Technical College of the Rockies': 126915, 'Technical Learning Centers Inc': 444893, 'Telshe Yeshiva-Chicago': 149329, 'Temple College': 228608, 'Temple University': 216339, 'Tenaj Salon Institute': 457448, 'Tennessee Board of Regents': 409379, 'Tennessee Career Institute': 448150, 'Tennessee College of Applied Technology Nashville': 248925, 'Tennessee College of Applied Technology-Athens': 219596, 'Tennessee College of Applied Technology-Covington': 219921, 'Tennessee College of Applied Technology-Crossville': 221591, 'Tennessee College of Applied Technology-Crump': 221430, 'Tennessee College of Applied Technology-Dickson': 219994, 'Tennessee College of Applied Technology-Elizabethton': 220127, 'Tennessee College of Applied Technology-Harriman': 220251, 'Tennessee College of Applied Technology-Hartsville': 220279, 'Tennessee College of Applied Technology-Hohenwald': 220321, 'Tennessee College of Applied Technology-Jacksboro': 220394, 'Tennessee College of Applied Technology-Jackson': 221616, 'Tennessee College of Applied Technology-Knoxville': 221625, 'Tennessee College of Applied Technology-Livingston': 220640, 'Tennessee College of Applied Technology-McKenzie': 220756, 'Tennessee College of Applied Technology-McMinnville': 221607, 'Tennessee College of Applied Technology-Memphis': 220853, 'Tennessee College of Applied Technology-Morristown': 221050, 'Tennessee College of Applied Technology-Murfreesboro': 221102, 'Tennessee College of Applied Technology-Newbern': 221236, 'Tennessee College of Applied Technology-Oneida-Huntsville': 221582, 'Tennessee College of Applied Technology-Paris': 221281, 'Tennessee College of Applied Technology-Pulaski': 221333, 'Tennessee College of Applied Technology-Ripley': 221388, 'Tennessee College of Applied Technology-Shelbyville': 221494, 'Tennessee College of Applied Technology-Whiteville': 221634, 'Tennessee School of Beauty of Knoxville Inc': 221829, 'Tennessee State University': 221838, 'Tennessee Technological University': 221847, 'Tennessee Wesleyan University': 221731, 'Terra State Community College': 206011, 'Teterboro School of Aeronautics': 187000, 'Texarkana College': 228699, 'Texas A & M International University': 226152, 'Texas A & M University-College Station': 228723, 'Texas A & M University-Commerce': 224554, 'Texas A & M University-Corpus Christi': 224147, 'Texas A & M University-Kingsville': 228705, 'Texas A & M University-System Office': 228732, 'Texas A&M University-Central Texas': 483036, 'Texas A&M University-San Antonio': 459949, 'Texas A&M University-Texarkana': 224545, 'Texas Barber College': 440989, 'Texas Beauty College': 458061, 'Texas Chiropractic College Foundation Inc': 228866, 'Texas Christian University': 228875, 'Texas College': 228884, 'Texas College of Cosmetology-Abilene': 377315, 'Texas College of Cosmetology-Lubbock': 487232, 'Texas College of Cosmetology-San Angelo': 419633, 'Texas County Technical College': 441487, 'Texas Health and Science University': 430704, 'Texas Health School': 448196, 'Texas Healthtech Institute': 494694, 'Texas Lutheran University': 228981, 'Texas Southern University': 229063, 'Texas Southmost College': 227377, 'Texas State Technical College': 487320, 'Texas State University': 228459, 'Texas Tech University': 229115, 'Texas Tech University Health Sciences Center': 229337, 'Texas Tech University Health Sciences Center-El Paso': 492689, 'Texas Tech University System Administration': 439154, 'Texas Wesleyan University': 229160, "Texas Woman's University": 229179, 'Textures Institute of Cosmetology': 488129, 'Thaddeus Stevens College of Technology': 216296, 'Thanh Le College School of Cosmetology': 368832, 'The  Beauty Institute': 210711, 'The Academy of Hair Design Six': 438674, 'The Academy of Radio and TV Broadcasting': 108348, 'The Ailey School': 188669, 'The Art Institute of Atlanta': 138813, 'The Art Institute of Austin': 451820, 'The Art Institute of Cincinnati-AIC College of Design': 200624, 'The Art Institute of Houston': 222938, 'The Art Institute of Las Vegas': 182111, 'The Art Institute of San Antonio': 458982, 'The Art Institute of Virginia Beach': 458496, 'The Baptist College of Florida': 132408, 'The Barber School': 476708, 'The Beauty Institute': 444404, 'The Beauty Institute-Ambler': 210784, 'The Beauty School': 485731, 'The Catholic University of America': 131283, 'The Chicago School of Professional Psychology at Chicago': 143978, 'The Chicago School of Professional Psychology at Irvine': 455433, 'The Chicago School of Professional Psychology at Los Angeles': 455664, 'The Chicago School of Professional Psychology at San Diego': 491190, 'The Chicago School of Professional Psychology at Washington DC': 459745, 'The Chicago School of Professional Psychology at Xavier University of Louisiana': 487153, 'The Christ College of Nursing and Health Sciences': 201821, 'The Chrysm Insitute of Esthetics': 481526, 'The Collective School Of Music': 461157, 'The College of Health Care Professions-Austin': 437635, 'The College of Health Care Professions-Dallas': 480824, 'The College of Health Care Professions-Fort Worth': 480833, 'The College of Health Care Professions-McAllen Campus': 489283, 'The College of Health Care Professions-Northwest': 392257, 'The College of Health Care Professions-San Antonio': 449250, 'The College of Health Care Professions-South San Antonio': 492722, 'The College of Health Care Professions-Southwest Houston': 447591, 'The College of Idaho': 142294, 'The College of New Jersey': 187134, 'The College of New Rochelle': 193645, 'The College of Saint Rose': 195234, 'The College of Saint Scholastica': 174899, 'The College of the Florida Keys': 133960, 'The College of Westchester': 197285, 'The College of Wooster': 206589, 'The Continents State University': 492087, 'The Creative Center': 430485, 'The Creative Circus': 141015, 'The Culinary School of Fort Worth': 491251, 'The Esthetic Institute': 490443, 'The Evergreen State College': 235167, 'The Fab School': 483230, 'The General Theological Seminary': 191320, 'The Hair Academy': 452009, 'The Hair Academy LLC': 220163, 'The Healthcare Institute': 482972, 'The Institute of Beauty and Wellness': 450650, 'The International Culinary Center': 191287, 'The John Marshall Law School': 146241, 'The Juilliard School': 192110, "The King's College": 454184, "The King's University": 439701, 'The Landing School': 161208, "The Master's University and Seminary": 117751, 'The Modern College of Design': 205391, 'The New England Conservatory of Music': 167057, 'The New School': 193654, 'The New School Center for Media': 193672, 'The North Coast College': 206394, 'The Ohio Media School-Columbus': 453756, 'The Professional Hair Design Academy': 238810, 'The Recording Conservatory of Austin': 485953, 'The Restaurant School at Walnut Hill College': 215637, 'The Sage Colleges': 195128, 'The Salon Professional Academy-Altoona': 215530, 'The Salon Professional Academy-Appleton': 454537, 'The Salon Professional Academy-Battle Creek': 451307, 'The Salon Professional Academy-Cedar Falls': 154545, 'The Salon Professional Academy-Colorado Springs': 459295, 'The Salon Professional Academy-Delray Beach': 492360, 'The Salon Professional Academy-Evansville': 459392, 'The Salon Professional Academy-Fargo': 448026, 'The Salon Professional Academy-Ft Myers': 459347, 'The Salon Professional Academy-Georgetown': 491996, 'The Salon Professional Academy-Grand Junction': 126164, 'The Salon Professional Academy-Huntsville': 480976, 'The Salon Professional Academy-Kenosha': 461908, 'The Salon Professional Academy-Lewisville': 458098, 'The Salon Professional Academy-Melbourne': 385132, 'The Salon Professional Academy-Nampa': 247047, 'The Salon Professional Academy-Nashville': 481340, 'The Salon Professional Academy-North Little Rock': 460987, 'The Salon Professional Academy-Onalaska': 458168, 'The Salon Professional Academy-Rochester': 461546, 'The Salon Professional Academy-San Jose': 484206, 'The Salon Professional Academy-Shorewood': 462345, 'The Salon Professional Academy-St Charles': 460996, 'The Salon Professional Academy-Tonawanda': 457837, 'The Salon Professional Academy-Washington DC': 494232, 'The Salter School-Malden Campus': 442815, 'The Santa Barbara and Ventura Colleges of Law at Santa Barbara': 475228, 'The Santa Barbara and Ventura Colleges of Law at Ventura': 125037, 'The Seattle School of Theology & Psychology': 441131, 'The Southern Baptist Theological Seminary': 157748, 'The Spa School': 204769, 'The Temple Annapolis-A Paul Mitchell Partner School': 487676, 'The Temple-A Paul Mitchell Partner School': 455901, 'The Training Domain': 486521, 'The University of Aesthetics & Cosmetology': 454962, 'The University of Alabama': 100751, 'The University of America': 475237, 'The University of Findlay': 202763, 'The University of Montana': 180489, 'The University of Montana-Western': 180692, 'The University of Tampa': 137847, 'The University of Tennessee Health Science Center': 487010, 'The University of Tennessee System Office': 492263, 'The University of Tennessee-Chattanooga': 221740, 'The University of Tennessee-Knoxville': 221759, 'The University of Tennessee-Martin': 221768, 'The University of Texas at Arlington': 228769, 'The University of Texas at Austin': 228778, 'The University of Texas at Dallas': 228787, 'The University of Texas at El Paso': 228796, 'The University of Texas at San Antonio': 229027, 'The University of Texas at Tyler': 228802, 'The University of Texas Health Science Center at Houston': 229300, 'The University of Texas Health Science Center at San Antonio': 228644, 'The University of Texas MD Anderson Cancer Center': 416801, 'The University of Texas Medical Branch at Galveston': 228653, 'The University of Texas of the Permian Basin': 229018, 'The University of Texas Rio Grande Valley': 227368, 'The University of Texas System Office': 229090, 'The University of the Arts': 215105, 'The University of the South': 221519, "The University of Virginia's College at Wise": 233897, 'The University of West Florida': 138354, 'The Vocational Nursing Institute Inc': 485360, "The Workforce Institute's City College": 214023, 'The Wright Institute': 126012, 'Theatre of Arts': 486123, 'Theological Seminary of the Reformed Episcopal Church': 216348, 'Thiel College': 216357, 'Thomas Aquinas College': 124292, 'Thomas College': 161563, 'Thomas Edison State University': 187046, 'Thomas Jefferson School of Law': 126049, 'Thomas Jefferson University': 216366, 'Thomas More College of Liberal Arts': 183275, 'Thomas More University': 157809, 'Thomas Nelson Community College': 233754, 'Thomas University': 141167, 'Three Rivers College': 179645, 'Three Rivers Community College': 129808, 'Tidewater Community College': 233772, 'Tidewater Tech-Trades': 232919, 'Tiffin Academy of Hair Design': 206039, 'Tiffin University': 206048, 'Tillamook Bay Community College': 420723, 'Tint School of Makeup & Cosmetology-Seattle': 484826, 'Tint School of Makeup and Cosmetology-Dallas': 418968, 'Tint School of Makeup and Cosmetology-Irving': 227058, 'Toccoa Falls College': 141185, "Tohono O'Odham Community College": 442781, 'Toledo Academy of Beauty Culture-East': 375540, 'Toledo Public Schools Adult and Continuing Education': 204459, 'Tom P Haney Technical Center': 137865, "Tomorrow's Image Barber And Beauty Academy of Virginia": 476568, 'Tompkins Cortland Community College': 196565, 'Toni & Guy Hairdressing Academy-Albuquerque': 457776, 'Toni & Guy Hairdressing Academy-Atlanta': 413945, 'Toni & Guy Hairdressing Academy-Colorado Springs': 443289, 'Toni & Guy Hairdressing Academy-Cranston': 455965, 'Toni & Guy Hairdressing Academy-Idaho': 492397, 'Toni & Guy Hairdressing Academy-Plano': 436775, 'Toni & Guy Hairdressing Academy-Rio Rancho': 493372, 'Toni & Guy Hairdressing Academy-Santa Monica': 116350, 'Toni & Guy Hairdressing Academy-Shoreline': 235352, 'Toni & Guy Hairdressing Academy-Worcester': 434344, 'Tonsorial Arts Barber College': 494719, 'Tooele Technical College': 475723, 'Top Nails & Hair Beauty School': 481100, 'Top of the Line Barber College': 487807, 'Torah Temimah Talmudical Seminary': 196583, 'Total Image Beauty Academy': 455187, 'Total Transformation Institute of Cosmetology': 483735, 'Totally Cosmo School of Modern Cosmetology': 488828, 'Tougaloo College': 176406, 'Touro College': 196592, 'Touro University California': 459736, 'Touro University Nevada': 459824, 'Touro University Worldwide': 459727, 'Towson University': 164076, 'Toyota Technological Institute at Chicago': 445054, 'Transformed Barber and Cosmetology Academy': 457703, 'Transitions Career Institute School of Nursing': 491774, 'Transylvania University': 157818, 'Traviss Technical College': 135522, 'Traxlers School of Hair': 245281, 'Treasure Coast Technical College': 486150, 'Treasure Valley Community College': 210234, 'Trend Barber College': 443298, 'Trend Setters School': 451316, "Trend Setters' Academy of Beauty Culture-Elizabethtown": 245069, "Trend Setters' Academy of Beauty Culture-Louisville": 468705, 'Trendsetters School of Beauty & Barbering': 447865, 'Trenz Beauty Academy': 482167, 'Trevecca Nazarene University': 221892, 'Tri County Regional Vocational Technical High School': 459408, 'Tri-Community Adult Education': 484233, 'Tri-County Adult Career Center': 206172, 'Tri-County Beauty Academy': 149499, 'Tri-County Community College': 199795, 'Tri-County Technical College': 218885, 'Tri-Rivers Career Center': 206181, 'Tri-State Barber College': 487913, 'Tri-State Bible College': 206154, 'Tri-State Cosmetology Institute': 402800, 'Triangle Tech Inc-Bethlehem': 448859, 'Triangle Tech Inc-Dubois': 216454, 'Triangle Tech Inc-Erie': 216427, 'Triangle Tech Inc-Greensburg': 216445, 'Triangle Tech Inc-Pittsburgh': 216436, 'Triangle Tech Inc-Sunbury': 443377, 'Tricoci University of Beauty Culture-Bridgeview': 455895, 'Tricoci University of Beauty Culture-Chicago NE': 470393, 'Tricoci University of Beauty Culture-Chicago NW': 454971, 'Tricoci University of Beauty Culture-Danville': 144573, 'Tricoci University of Beauty Culture-Elgin': 487533, 'Tricoci University of Beauty Culture-Glendale Heights': 454980, 'Tricoci University of Beauty Culture-Highland': 150303, 'Tricoci University of Beauty Culture-Indianapolis': 414869, 'Tricoci University of Beauty Culture-Janesville': 491224, 'Tricoci University of Beauty Culture-Lafayette': 151607, 'Tricoci University of Beauty Culture-Libertyville': 455886, 'Tricoci University of Beauty Culture-Peoria': 454999, 'Tricoci University of Beauty Culture-Rockford': 455008, 'Tricoci University of Beauty Culture-Urbana': 143181, 'Tricoci University of Beauty Cuture LLC-Bloomington': 367088, 'Trident Technical College': 218894, 'Trident University International': 450979, 'Trine University': 152567, 'Trine University-Regional/Non-Traditional Campuses': 414878, 'Trinidad State Junior College': 128258, 'Trinity Baptist College': 137953, 'Trinity Bible College and Graduate School': 200484, 'Trinity Christian College': 149505, 'Trinity College': 130590, 'Trinity College of Florida': 137962, 'Trinity College of Nursing & Health Sciences': 146755, 'Trinity College of Puerto Rico': 431929, 'Trinity Episcopal School for Ministry': 216463, 'Trinity Health System School of Nursing': 204893, 'Trinity International University-Florida': 135610, 'Trinity International University-Illinois': 149514, 'Trinity Law School': 123448, 'Trinity School of Health and Allied Sciences': 459161, 'Trinity University': 229267, 'Trinity Valley Community College': 225308, 'Trinity Washington University': 131876, 'Triton College': 149532, 'Trocaire College': 196653, 'Troy University': 102368, 'Truckee Meadows Community College': 182500, 'Truett McConnell University': 141237, 'Truman State University': 178615, 'Trumbull Career & Technical Center': 407595, 'Tuana European Beauty Academy': 493910, 'Tucson College of Beauty': 447704, 'Tufts University': 168148, 'Tulane University of Louisiana': 160755, 'Tulsa Community College': 207935, 'Tulsa Technology Center': 488934, 'Tulsa Welding School-Houston': 486798, 'Tulsa Welding School-Jacksonville': 476063, 'Tulsa Welding School-Tulsa': 207962, 'Tunxis Community College': 130606, 'Turning Point Beauty College': 444936, 'Turtle Mountain Community College': 200527, 'Tusculum University': 221953, 'Tuskegee University': 102377, 'Twin City Beauty College': 172495, 'Tyler Junior College': 229355, 'U S Grant Joint Vocational School': 375568, 'U.S. Truck Driver Training School': 488837, 'UCAS Univeristy of Cosmetology Arts & Sciences-La Joya': 475662, 'UCAS University of Cosemtology Arts & Sciences-McAllen': 229425, 'UCAS University of Cosmetology Arts & Sciences': 377193, 'UCAS University of Cosmetology Arts & Sciences-Harlingen': 407683, 'UCAS University of Cosmetology Arts & Sciences-San Antonio 410': 246415, 'UEI College-Bakersfield': 482291, 'UEI College-Fresno': 397942, 'UEI College-Gardena': 393649, 'UEI College-Riverside': 470038, 'UEI College-Sacramento': 494357, 'Uintah Basin Technical College': 230676, 'Ukiah Adult School': 481182, 'Ulster BOCES-School of Practical Nursing': 418056, 'Ulster County Community College': 196699, 'Ultimate Medical Academy-Clearwater': 441371, 'Ultrasound Medical Institute': 481252, 'Umpqua Community College': 210270, 'Unification Theological Seminary': 246789, 'Unilatina International College': 486354, 'Union Bible College': 491525, 'Union College': 157863, 'Union County College': 187198, 'Union County Vocational Technical School': 417831, 'Union Institute & University': 206279, 'Union Presbyterian Seminary': 233842, 'Union Theological Seminary in the City of New York': 196884, 'Union University': 221971, 'Unitech Training Academy-Alexandria': 469911, 'Unitech Training Academy-Baton Rouge': 491084, 'Unitech Training Academy-Houma': 448646, 'Unitech Training Academy-Lafayette': 444945, 'Unitech Training Academy-Lake Charles': 469920, 'Unitech Training Academy-New Orleans': 487047, 'Unitech Training Academy-West Monroe': 447467, 'United Beauty College': 461810, 'United Education Institute - UEI College - Phoenix': 487481, 'United Education Institute-Anaheim': 468909, 'United Education Institute-Chula Vista': 447607, 'United Education Institute-Encino': 384245, 'United Education Institute-Huntington Park Campus': 124681, 'United Education Institute-Morrow': 413893, 'United Education Institute-Ontario': 384236, 'United Education Institute-UEI College San Marcos': 468848, 'United Education Institute-UEI College Stockton': 480471, 'United Education Institute-West Covina': 447616, 'United Lutheran Seminary': 213631, 'United States Air Force Academy': 128328, 'United States Coast Guard Academy': 130624, 'United States Merchant Marine Academy': 197027, 'United States Military Academy': 197036, 'United States Naval Academy': 164155, 'United States Sports Academy': 102395, 'United States University': 447050, 'United Talmudical Seminary': 197018, 'United Technical Center': 419031, 'United Theological Seminary': 206288, 'United Theological Seminary of the Twin Cities': 175139, 'United Tribes Technical College': 200554, 'Unitek College': 459204, 'Unity College': 161572, 'UnityPoint Health-Des Moines School of Radiologic Technology': 153542, 'Universal Career School': 446589, 'Universal College of Beauty Inc-Los Angeles 2': 372240, 'Universal College of Healing Arts': 446598, 'Universal Healthcare Careers College': 485573, 'Universal Spa Training Academy': 459374, 'Universal Technical Institute of Arizona Inc': 106041, 'Universal Technical Institute of Arizona Inc-Motorcycle Mechanics Institute Division': 105215, 'Universal Technical Institute of California Inc': 438504, 'Universal Technical Institute of Illinois Inc': 366191, 'Universal Technical Institute of Massachusetts Inc': 447403, 'Universal Technical Institute of Northern California Inc': 448433, 'Universal Technical Institute of Pennsylvania Inc': 445799, 'Universal Technical Institute of Texas Inc.': 229416, 'Universal Technical Institute-Auto Motorcycle & Marine Mechanics Institute Division-Orlando': 369400, 'Universal Technical Institute-Bloomfield': 493132, 'Universal Technical Institute-Dallas Fort Worth': 460543, 'Universal Technical Institute-Southern California': 487597, 'Universal Technology College of Puerto Rico': 376385, 'Universal Therapeutic Massage Institute': 439996, 'Universal Training Institute': 481429, 'Universal Trinity College': 494579, 'Universidad Adventista de las Antillas': 241191, 'Universidad Ana G. Mendez-Carolina Campus': 243346, 'Universidad Ana G. Mendez-Cupey Campus': 241739, 'Universidad Ana G. Mendez-Gurabo Campus': 243601, 'Universidad Ana G. Mendez-Online Campus': 483595, 'Universidad Central de Bayamon': 241225, 'Universidad Central Del Caribe': 243568, 'Universidad del Sagrado Corazon': 243443, 'Universidad Pentecostal Mizpa': 441690, 'Universidad Politecnica de Puerto Rico': 243577, 'Universidad Teologica del Caribe': 241614, 'University Academy of Hair Design': 476805, 'University at Buffalo': 196088, 'University of Advancing Technology': 363934, 'University of Aesthetics & Cosmetology': 454953, 'University of Akron Main Campus': 200800, 'University of Akron Wayne College': 200846, 'University of Alabama at Birmingham': 100663, 'University of Alabama in Huntsville': 100706, 'University of Alabama System Office': 100733, 'University of Alaska Anchorage': 102553, 'University of Alaska Fairbanks': 102614, 'University of Alaska Southeast': 102632, 'University of Alaska System of Higher Education': 103529, 'University of Antelope Valley': 442930, 'University of Arizona': 104179, 'University of Arizona-South': 487296, 'University of Arkansas': 106397, 'University of Arkansas at Little Rock': 106245, 'University of Arkansas at Monticello': 106485, 'University of Arkansas at Pine Bluff': 106412, 'University of Arkansas Community College Rich Mountain': 107743, 'University of Arkansas Community College-Batesville': 106999, 'University of Arkansas Community College-Morrilton': 107585, 'University of Arkansas eVersity': 493725, 'University of Arkansas for Medical Sciences': 106263, 'University of Arkansas System Office': 108056, 'University of Arkansas-Fort Smith': 108092, 'University of Arkansas-Pulaski Technical College': 107664, 'University of Arknsas Hope-Texarkana': 107725, 'University of Baltimore': 161873, 'University of Bridgeport': 128744, 'University of California-Berkeley': 110635, 'University of California-Davis': 110644, 'University of California-Hastings College of Law': 110398, 'University of California-Irvine': 110653, 'University of California-Los Angeles': 110662, 'University of California-Merced': 445188, 'University of California-Riverside': 110671, 'University of California-San Diego': 110680, 'University of California-San Francisco': 110699, 'University of California-Santa Barbara': 110705, 'University of California-Santa Cruz': 110714, 'University of California-System Administration Central Office': 124557, 'University of Central Arkansas': 106704, 'University of Central Florida': 132903, 'University of Central Missouri': 176965, 'University of Central Oklahoma': 206941, 'University of Charleston': 237312, 'University of Chicago': 144050, 'University of Cincinnati-Blue Ash College': 201955, 'University of Cincinnati-Clermont College': 201946, 'University of Cincinnati-Main Campus': 201885, 'University of Colorado Boulder': 126614, 'University of Colorado Colorado Springs': 126580, 'University of Colorado Denver/Anschutz Medical Campus': 126562, 'University of Colorado System Office': 128300, 'University of Connecticut': 129020, 'University of Connecticut-Avery Point': 436827, 'University of Connecticut-Hartford Campus': 463056, 'University of Connecticut-Stamford': 436836, 'University of Connecticut-Waterbury Campus': 436818, 'University of Dallas': 224323, 'University of Dayton': 202480, 'University of Delaware': 130943, 'University of Denver': 127060, 'University of Detroit Mercy': 169716, 'University of Dubuque': 153278, 'University of East-West Medicine': 447801, 'University of Evansville': 150534, 'University of Florida': 134130, 'University of Florida-Online': 484473, 'University of Fort Lauderdale': 457402, 'University of Georgia': 139959, 'University of Guam': 240754, 'University of Hartford': 129525, 'University of Hawaii at Hilo': 141565, 'University of Hawaii at Manoa': 141574, 'University of Hawaii Maui College': 141839, 'University of Hawaii System Office': 141963, 'University of Hawaii-West Oahu': 141981, 'University of Holy Cross': 160065, 'University of Houston': 225511, 'University of Houston-Clear Lake': 225414, 'University of Houston-Downtown': 225432, 'University of Houston-System Administration': 229407, 'University of Houston-Victoria': 225502, 'University of Idaho': 142285, 'University of Illinois at Chicago': 145600, 'University of Illinois at Springfield': 148654, 'University of Illinois at Urbana-Champaign': 145637, 'University of Illinois University Administration': 149587, 'University of Indianapolis': 151263, 'University of Iowa': 153658, 'University of Jamestown': 200156, 'University of Kansas': 155317, 'University of Kentucky': 157085, 'University of La Verne': 117140, 'University of Louisiana at Lafayette': 160658, 'University of Louisiana at Monroe': 159993, 'University of Louisiana-System Administration': 247083, 'University of Louisville': 157289, 'University of Lynchburg': 232609, 'University of Maine': 161253, 'University of Maine at Augusta': 161217, 'University of Maine at Farmington': 161226, 'University of Maine at Fort Kent': 161235, 'University of Maine at Machias': 161244, 'University of Maine at Presque Isle': 161341, 'University of Maine-System Central Office': 161280, 'University of Management and Technology': 437097, 'University of Mary': 200217, 'University of Mary Hardin-Baylor': 226471, 'University of Mary Washington': 232681, 'University of Maryland Eastern Shore': 163338, 'University of Maryland Global Campus': 163204, 'University of Maryland  Baltimore': 163259, 'University of Maryland-Baltimore County': 163268, 'University of Maryland-College Park': 163286, 'University of Massachusetts Medical School Worcester': 166708, 'University of Massachusetts-Amherst': 166629, 'University of Massachusetts-Boston': 166638, 'University of Massachusetts-Central Office': 166665, 'University of Massachusetts-Dartmouth': 167987, 'University of Massachusetts-Lowell': 166513, 'University of Memphis': 220862, 'University of Miami': 135726, 'University of Michigan-Ann Arbor': 170976, 'University of Michigan-Dearborn': 171137, 'University of Michigan-Flint': 171146, 'University of Minnesota-Crookston': 174075, 'University of Minnesota-Duluth': 174233, 'University of Minnesota-Morris': 174251, 'University of Minnesota-Rochester': 456959, 'University of Minnesota-Twin Cities': 174066, 'University of Mississippi': 176017, 'University of Missouri-Columbia': 178396, 'University of Missouri-Kansas City': 178402, 'University of Missouri-St Louis': 178420, 'University of Missouri-System Office': 178439, 'University of Mobile': 101693, 'University of Montevallo': 101709, 'University of Mount Olive': 199069, 'University of Mount Union': 204185, 'University of Nebraska at Kearney': 181215, 'University of Nebraska at Omaha': 181394, 'University of Nebraska Medical Center': 181428, 'University of Nebraska-Central Administration System Office': 181747, 'University of Nebraska-Lincoln': 181464, 'University of Nevada-Las Vegas': 182281, 'University of Nevada-Reno': 182290, 'University of New England': 161457, 'University of New Hampshire at Manchester': 183071, 'University of New Hampshire-Franklin Pierce School of Law': 182829, 'University of New Hampshire-Main Campus': 183044, 'University of New Haven': 129941, 'University of New Mexico-Gallup Campus': 187958, 'University of New Mexico-Los Alamos Campus': 187976, 'University of New Mexico-Main Campus': 187985, 'University of New Mexico-Taos Campus': 188225, 'University of New Mexico-Valencia County Campus': 188049, 'University of New Orleans': 159939, 'University of North Alabama': 101879, 'University of North Carolina at Asheville': 199111, 'University of North Carolina at Chapel Hill': 199120, 'University of North Carolina at Charlotte': 199139, 'University of North Carolina at Greensboro': 199148, 'University of North Carolina at Pembroke': 199281, 'University of North Carolina School of the Arts': 199184, 'University of North Carolina System': 199175, 'University of North Carolina Wilmington': 199218, 'University of North Dakota': 200280, 'University of North Florida': 136172, 'University of North Georgia': 482680, 'University of North Texas': 227216, 'University of North Texas at Dallas': 484905, 'University of North Texas Health Science Center': 228909, 'University of North Texas System': 443711, 'University of Northern Colorado': 127741, 'University of Northern Iowa': 154095, 'University of Northwestern Ohio': 204486, 'University of Northwestern-St Paul': 174491, 'University of Notre Dame': 152080, 'University of Oklahoma-Health Sciences Center': 207342, 'University of Oklahoma-Norman Campus': 207500, 'University of Oregon': 209551, 'University of Pennsylvania': 215062, 'University of Phoenix-Arizona': 484613, 'University of Phoenix-California': 484631, 'University of Phoenix-Colorado': 484640, 'University of Phoenix-Florida': 484668, 'University of Phoenix-Georgia': 484677, 'University of Phoenix-Hawaii': 420042, 'University of Phoenix-Illinois': 442161, 'University of Phoenix-Louisiana': 484686, 'University of Phoenix-Michigan': 484695, 'University of Phoenix-Nevada': 484710, 'University of Phoenix-New Jersey': 445300, 'University of Phoenix-New Mexico': 405997, 'University of Phoenix-North Carolina': 484729, 'University of Phoenix-Pennsylvania': 484783, 'University of Phoenix-Tennessee': 484747, 'University of Phoenix-Texas': 484756, 'University of Phoenix-Utah': 380465, 'University of Phoenix-Virginia': 484765, 'University of Phoenix-Washington': 432223, 'University of Pikeville': 157535, 'University of Pittsburgh Medical Center-Shadyside School of Nursing': 215974, 'University of Pittsburgh-Bradford': 215266, 'University of Pittsburgh-Greensburg': 215275, 'University of Pittsburgh-Johnstown': 215284, 'University of Pittsburgh-Pittsburgh Campus': 215293, 'University of Pittsburgh-Titusville': 215309, 'University of Portland': 209825, 'University of Providence': 180258, 'University of Puerto Rico-Aguadilla': 243106, 'University of Puerto Rico-Arecibo': 243115, 'University of Puerto Rico-Bayamon': 243133, 'University of Puerto Rico-Carolina': 243142, 'University of Puerto Rico-Cayey': 243151, 'University of Puerto Rico-Central Administration': 243160, 'University of Puerto Rico-Humacao': 243179, 'University of Puerto Rico-Mayaguez': 243197, 'University of Puerto Rico-Medical Sciences': 243203, 'University of Puerto Rico-Ponce': 243212, 'University of Puerto Rico-Rio Piedras': 243221, 'University of Puerto Rico-Utuado': 243188, 'University of Puget Sound': 236328, 'University of Redlands': 121691, 'University of Rhode Island': 217484, 'University of Richmond': 233374, 'University of Rio Grande': 205203, 'University of Rochester': 195030, 'University of Saint Francis-Fort Wayne': 152336, 'University of Saint Joseph': 130314, 'University of Saint Katherine': 488785, 'University of Saint Mary': 155812, 'University of Saint Mary of the Lake': 148885, 'University of San Diego': 122436, 'University of San Francisco': 122612, 'University of Science and Arts of Oklahoma': 207722, 'University of Scranton': 215929, 'University of Sioux Falls': 219383, 'University of South Alabama': 102094, 'University of South Carolina Aiken': 218645, 'University of South Carolina Beaufort': 218654, 'University of South Carolina-Columbia': 218663, 'University of South Carolina-Lancaster': 218672, 'University of South Carolina-Salkehatchie': 218681, 'University of South Carolina-Sumter': 218690, 'University of South Carolina-Union': 218706, 'University of South Carolina-Upstate': 218742, 'University of South Dakota': 219471, 'University of South Florida-Main Campus': 137351, 'University of South Florida-Sarasota-Manatee': 451671, 'University of South Florida-St Petersburg': 448840, 'University of Southern California': 123961, 'University of Southern Indiana': 151306, 'University of Southern Maine': 161554, 'University of Southern Mississippi': 176372, 'University of Spa & Cosmetology Arts': 149550, 'University of St Francis': 148584, 'University of St Thomas': 174914, 'University of St. Augustine for Health Sciences': 367954, 'University of Texas Health Science Center at Tyler': 485537, 'University of Texas Southwestern Medical Center': 228635, 'University of the Cumberlands': 156541, 'University of the District of Columbia': 131399, 'University of the District of Columbia-David A Clarke School of Law': 363721, 'University of the Incarnate Word': 225627, 'University of the Ozarks': 107558, 'University of the Pacific': 120883, 'University of the People': 488846, 'University of the Potomac-VA Campus': 442639, 'University of the Potomac-Washington DC Campus': 384412, 'University of the Sciences': 215132, 'University of the Southwest': 188182, 'University of the Virgin Islands': 243665, 'University of the West': 449870, 'University of Toledo': 206084, 'University of Tulsa': 207971, 'University of Utah': 230764, 'University of Valley Forge': 216542, 'University of Vermont': 231174, 'University of Virginia-Main Campus': 234076, 'University of Washington-Bothell Campus': 377555, 'University of Washington-Seattle Campus': 236948, 'University of Washington-Tacoma Campus': 377564, 'University of West Alabama': 101587, 'University of West Georgia': 141334, 'University of West Los Angeles': 484862, 'University of Western States': 210438, 'University of Wisconsin Colleges Flex': 491303, 'University of Wisconsin-Eau Claire': 240268, 'University of Wisconsin-Green Bay': 240277, 'University of Wisconsin-La Crosse': 240329, 'University of Wisconsin-Madison': 240444, 'University of Wisconsin-Milwaukee': 240453, 'University of Wisconsin-Milwaukee Flex': 491288, 'University of Wisconsin-Oshkosh': 240365, 'University of Wisconsin-Parkside': 240374, 'University of Wisconsin-Parkside Flex': 491297, 'University of Wisconsin-Platteville': 240462, 'University of Wisconsin-River Falls': 240471, 'University of Wisconsin-Stevens Point': 240480, 'University of Wisconsin-Stout': 240417, 'University of Wisconsin-Superior': 240426, 'University of Wisconsin-System Administration': 240435, 'University of Wisconsin-Whitewater': 240189, 'University of Wyoming': 240727, 'University System of Maryland': 164146, 'University System of Maryland-Research Centers': 404480, 'University System of New Hampshire System Office': 183327, 'Unlimited Cosmetology School': 491233, 'UPMC Jameson School of Nursing': 213163, 'UPMC Mercy School of Nursing': 431600, 'Upper Cape Cod Regional Technical School': 373711, 'Upper Iowa University': 154493, 'Upper Valley Career Center': 206321, 'Upper Valley Educators Institute': 440004, 'Upstate Medical University': 196307, 'UR Beauty & Barber Academy': 491747, 'Urban 113 School of Cosmetology': 457493, 'Urban Barber College': 491756, 'Urban College of Boston': 429128, 'Urbana University': 206330, 'Urshan College': 494685, 'Urshan Graduate School of Theology': 455099, 'Ursinus College': 216524, 'Ursuline College': 206349, 'Uta Mesivta of Kiryas Joel': 446604, 'Utah State University': 230728, 'Utah Valley University': 230737, 'Utica College': 197045, 'Valdosta State University': 141264, 'Valencia College': 138187, 'Valley City State University': 200572, 'Valley College of Medical Careers': 449445, 'Valley College-Beckley': 377652, 'Valley College-Cleveland': 494250, 'Valley College-Martinsburg': 377661, 'Valley College-Princeton': 377670, 'Valley Forge Military College': 216551, 'Valley Grande Institute for Academic Studies': 443322, 'Valor Christian College': 486257, 'Valparaiso University': 152600, 'Vance-Granville Community College': 199838, 'Vanderbilt University': 221999, 'VanderCook College of Music': 149639, 'Vanguard College of Cosmetology-Baton Rouge': 456825, 'Vanguard College of Cosmetology-Metairie': 468893, 'Vanguard College of Cosmetology-Slidell': 160445, 'Vanguard University of Southern California': 123651, 'Vanguard-Sentinel Adult Career and Technology Center': 421717, 'Vassar College': 197133, 'Vaughn Beauty College': 176433, 'Vaughn College of Aeronautics and Technology': 188340, 'Veeb Nassau County School of Practical Nursing': 417910, 'Velvatex College of Beauty Culture': 108065, 'Venango County Area Vocational Technical School': 418524, 'Ventura Adult and Continuing Education': 417123, 'Ventura College': 125028, 'Ventura County Community College System Office': 125019, 'Venus Beauty Academy': 216579, 'Veritas Baptist College': 482228, 'Vermilion Community College': 175157, 'Vermont College of Fine Arts': 455992, 'Vermont Law School': 231147, 'Vermont State Colleges-Office of the Chancellor': 231156, 'Vermont Technical College': 231165, 'Vernon College': 229504, 'Verve College': 481085, 'Vet Tech Institute': 213914, 'Vet Tech Institute of Houston': 223472, 'VH Barber & Styling Academy': 485962, 'Vibe Barber College': 483744, 'VICI Beauty School': 238175, 'Victor Valley College': 125091, 'Victoria Beauty College Inc': 229522, 'Victoria College': 229540, "Victoria's Academy of Cosmetology": 451626, 'Victory Career College': 491899, 'Villa Maria College': 197142, 'Villanova University': 216597, 'Vincennes Beauty College': 152628, 'Vincennes University': 152637, "Virgil's Beauty College": 208017, 'Virginia Beach City Public Schools School of Practical Nursing': 377485, 'Virginia Beach Theological Seminary': 449834, 'Virginia Commonwealth University': 234030, 'Virginia Highlands Community College': 233903, 'Virginia International University': 460376, 'Virginia Military Institute': 234085, 'Virginia Polytechnic Institute & State University': 459082, 'Virginia Polytechnic Institute and State University': 233921, 'Virginia School of Hair Design': 234119, 'Virginia Sewing Machines and School Center': 431956, 'Virginia State University': 234155, 'Virginia Union University': 234164, 'Virginia University of Integrative Medicine': 490106, 'Virginia University of Lynchburg': 234137, 'Virginia Wesleyan University': 234173, 'Virginia Western Community College': 233949, 'Visible Music College': 449764, 'Vista Adult School': 492324, 'Vista College': 365204, 'Vista College-Online': 377342, 'Viterbo University': 240107, 'Vogue Beauty and Barber School': 431965, 'Vogue College of Cosmetology': 476559, 'Vogue College of Cosmetology-McAllen': 229656, 'Vogue College of Cosmetology-San Antonio Fredericksburg': 476540, 'Vogue College of Cosmetology-Santa Fe': 188289, 'Vogue International Academy': 491871, 'Volunteer State Community College': 222053, 'Voorhees College': 218919, 'Vski Cosmetology School': 493770, 'W L Bonner College': 446613, 'Wabash College': 152673, 'Wabash Valley College': 403487, 'Wade College': 226879, 'Wade Gordon Hairdressing Academy': 492591, 'Wade Gordon Hairdressing Academy-Lubbock': 487065, 'Wagner College': 197197, 'Wake Forest University': 199847, 'Wake Technical Community College': 199856, 'Walden University': 125231, 'Waldorf University': 154518, 'Walla Walla Community College': 236887, 'Walla Walla University': 236896, 'Walsh College': 172608, 'Walsh University': 206437, 'Walters State Community College': 222062, 'Warner Pacific University': 210304, 'Warner Pacific University Professional and Graduate Studies': 480198, 'Warner University': 138275, 'Warren County Career Center': 407832, 'Warren County Community College': 245625, 'Warren Wilson College': 199865, 'Warrensburg Area Career Center': 417655, 'Wartburg College': 154527, 'Wartburg Theological Seminary': 154536, 'Washburn Institute of Technology': 155423, 'Washburn University': 156082, 'Washington & Jefferson College': 216667, 'Washington Adventist University': 162210, 'Washington and Lee University': 234207, 'Washington Barber College Inc': 457192, 'Washington College': 164216, 'Washington County Career Center-Adult Technical Training': 418250, 'Washington County Community College': 161581, 'Washington Hospital School of Nursing': 216630, 'Washington Saratoga Warren Hamilton Essex BOCES-Practical Nursing Program': 418029, 'Washington State Community College': 206446, 'Washington State University': 236939, 'Washington University in St Louis': 179867, 'Washtenaw Community College': 172617, 'Watkins College of Art Design & Film': 392840, 'Watts School of Nursing': 199883, 'Waubonsee Community College': 149727, 'Waukesha County Technical College': 240125, 'Wave Leadership College': 486594, 'Wayland Baptist University': 229780, 'Wayne Community College': 199892, 'Wayne County Community College District': 172635, 'Wayne County Schools Career Center': 433138, 'Wayne Finger Lakes BOCES-Practical Nursing Program': 418001, 'Wayne State College': 181783, 'Wayne State University': 172644, 'Waynes College of Beauty': 125310, 'Waynesburg University': 216694, 'Waynesville Career Center': 365505, 'Weatherford College': 229799, 'Webb Institute': 197221, 'Webber International University': 138293, 'Weber State University': 230782, 'Webster University': 179894, 'Weill Cornell Medical College': 190424, 'Welch College': 220206, 'Welder Training and Testing Institute': 216746, 'Wellesley College': 168218, 'Wells College': 197230, 'WellSpring School of Allied Health-Kansas City': 447999, 'WellSpring School of Allied Health-Lawrence': 470047, 'WellSpring School of Allied Health-Springfield': 493451, 'WellSpring School of Allied Health-Wichita': 494898, 'Wenatchee Valley College': 236975, 'Wentworth Institute of Technology': 168227, 'Wes Watkins Technology Center': 418357, 'Wesley Biblical Seminary': 176451, 'Wesley College': 131098, 'Wesley Theological Seminary': 131973, 'Wesleyan College': 141325, 'Wesleyan University': 130697, 'West Chester University of Pennsylvania': 216764, 'West Coast Ultrasound Institute': 441229, 'West Coast University-Center for Graduate Studies': 489858, 'West Coast University-Dallas': 477039, 'West Coast University-Los Angeles': 443331, 'West Coast University-Miami': 485272, 'West Coast University-Ontario': 458229, 'West Coast University-Orange County': 458210, 'West Georgia Technical College': 139278, 'West Hills College-Coalinga': 125462, 'West Hills College-Lemoore': 448594, 'West Hills Community College District': 448637, 'West Kentucky Community and Technical College': 157483, 'West Liberty University': 237932, 'West Los Angeles College': 125471, 'West Michigan College of Barbering and Beauty': 152044, 'West Shore Community College': 172671, 'West Texas A & M University': 229814, 'West Valley College': 125499, 'West Valley Mission Community College District Office': 125222, 'West Virginia Junior College-Bridgeport': 442383, 'West Virginia Junior College-Charleston': 237987, 'West Virginia Junior College-Morgantown': 237996, 'West Virginia Junior College-United Career Institute': 494755, 'West Virginia Northern Community College': 238014, 'West Virginia School of Osteopathic Medicine': 237880, 'West Virginia State University': 237899, 'West Virginia University': 238032, 'West Virginia University at Parkersburg': 237686, 'West Virginia University Hospital Departments of Rad Tech and Nutrition': 237905, 'West Virginia University Institute of Technology': 237950, 'West Virginia Wesleyan College': 237969, 'Westchester College of Nursing & Allied Health': 486141, 'Westchester School for Dental Assistant': 485801, 'Westchester School of Beauty Culture': 197337, 'Westcliff University': 490133, 'Western Area Career & Technology Center': 368407, 'Western Carolina University': 200004, 'Western Colorado University': 128391, 'Western Connecticut State University': 130776, 'Western Dakota Technical Institute': 219480, 'Western Governors University': 433387, 'Western Illinois University': 149772, 'Western Iowa Tech Community College': 154572, 'Western Kentucky University': 157951, 'Western Michigan University': 172699, 'Western Michigan University Homer Stryker M.D. School of Medicine': 490373, 'Western Michigan University-Thomas M. Cooley Law School': 172477, 'Western Nebraska Community College': 181817, 'Western Nevada College': 182564, 'Western New England University': 168254, 'Western New Mexico University': 188304, 'Western Oklahoma State College': 208035, 'Western Oregon University': 210429, 'Western Pennsylvania Hospital School of Nursing': 216773, 'Western Piedmont Community College': 199908, 'Western Seminary': 210368, 'Western Suffolk BOCES': 420468, 'Western Technical College': 224660, 'Western Technology Center': 418302, 'Western Texas College': 229832, 'Western Theological Seminary': 172705, 'Western University of Health Sciences': 112525, 'Western Washington University': 237011, 'Western Wyoming Community College': 240693, 'Westfield State University': 168263, 'Westminster College': 216807, 'Westminster Theological Seminary': 216816, 'Westminster Theological Seminary in California': 125718, 'Westmont College': 125727, 'Westmoreland County Community College': 216825, 'Wharton County Junior College': 229841, 'Whatcom Community College': 237039, 'Wheaton College': 149781, 'Wheeling University': 238078, 'White Earth Tribal and Community College': 434751, 'White Mountains Community College': 183105, 'Whitman College': 237057, 'Whittier College': 125763, 'Whitworth University': 237066, 'Whitworth University-Adult Degree Programs': 475200, 'Wichita State University': 156125, 'Wichita State University-Campus of Applied Sciences and Technology': 156107, 'Wichita Technical Institute': 156134, 'Widener University': 216852, 'Wilberforce University': 206491, 'Wiley College': 229887, 'Wilkes Community College': 199926, 'Wilkes University': 216931, 'Wilkes-Barre Area Career and Technical Center Practical Nursing': 365383, 'Willamette University': 210401, 'William & Mary': 231624, 'William Carey University': 176479, 'William Edge Institute': 226860, 'William James College': 166717, 'William Jessup University': 122728, 'William Jewell College': 179955, 'William Moore College of Technology': 222105, 'William Paterson University of New Jersey': 187444, 'William Peace University': 199272, 'William Penn University': 154590, 'William Rainey Harper College': 149842, 'William T McFatter Technical College': 138479, 'William Woods University': 179964, 'Williams Baptist University': 107877, 'Williams College': 168342, 'Williamsburg Technical College': 218955, 'Williamson Christian College': 443340, 'Williamson College of the Trades': 216940, 'Williston State College': 200341, 'Wilmington College': 206507, 'Wilmington University': 131113, 'Wilson College': 217013, 'Wilson Community College': 199953, 'Windward Community College': 141990, 'Winebrenner Theological Seminary': 206516, 'Wingate University': 199962, 'Winona State University': 175272, "Winonah's International School of Cosmetology": 491905, 'Winston Salem Barber School': 199980, 'Winston-Salem State University': 199999, 'Winthrop University': 218964, 'Wiregrass Georgia Technical College': 141255, 'Wisconsin Academy a Paul Mitchell Partner Group-PMTS Lincoln': 486859, 'Wisconsin Indianhead Technical College': 240198, 'Wisconsin Lutheran College': 240338, 'Wisconsin School of Professional Psychology': 240213, 'Withlacoochee Technical College': 138497, 'Wittenberg University': 206525, 'Wofford College': 218973, "Women's Institute of Torah Seminary": 491631, 'Won Institute of Graduate Studies': 442064, 'Wongu University of Oriental Medicine': 488907, 'Wood County School of Practical Nursing': 238096, 'Woodbury University': 125897, 'Woodland Community College': 455512, 'Woodruff Medical Training and Testing': 455840, 'Wor-Wic Community College': 164313, 'Worcester Polytechnic Institute': 168421, 'Worcester State University': 168430, 'Word of Life Bible Institute': 197531, 'World Class Academy of Beauty Careers': 490142, 'World Mission University': 401223, 'Worsham College of Mortuary Science': 369455, 'Wright Beauty Academy': 172802, 'Wright Graduate University for the Realization of Human Potential': 486460, 'Wright State University-Lake Campus': 206613, 'Wright State University-Main Campus': 206604, 'WyoTech': 240718, 'Wytheville Community College': 234377, 'Xavier College School of Nursing': 481289, 'Xavier University': 206622, 'Xavier University of Louisiana': 160904, 'Xenon International Academy-Omaha': 407355, 'Xtylo Beauty College': 494700, 'Yahweh Beauty Academy': 484136, 'Yakima Valley College': 237109, 'Yale University': 130794, 'Yavapai College': 106148, 'Yeshiva Bais Aharon': 490319, 'Yeshiva Chemdas Hatorah': 491622, 'Yeshiva College of the Nations Capital': 434937, "Yeshiva D'monsey Rabbinical College": 420325, 'Yeshiva Derech Chaim': 197647, 'Yeshiva Gedola Ohr Yisrael': 486017, 'Yeshiva Gedola Tiferes Yaakov Yitzchok': 493716, 'Yeshiva Gedola Tiferes Yerachmiel': 491914, "Yeshiva Gedolah Imrei Yosef D'spinka": 375230, 'Yeshiva Gedolah Keren Hatorah': 491640, 'Yeshiva Gedolah Kesser Torah': 481410, 'Yeshiva Gedolah of Cliffwood': 491710, 'Yeshiva Gedolah of Greater Detroit': 247773, 'Yeshiva Gedolah of Woodlake Village': 493707, 'Yeshiva Gedolah Shaarei Shmuel': 488350, 'Yeshiva Gedolah Tiferes Boruch': 491613, 'Yeshiva Gedolah Zichron Leyma': 476692, 'Yeshiva Karlin Stolin': 197601, 'Yeshiva Kollel Tifereth Elizer': 491057, 'Yeshiva of Far Rockaway Derech Ayson Rabbinical Seminary': 190752, 'Yeshiva of Machzikai Hadas': 455257, 'Yeshiva of Nitra Rabbinical College': 197674, 'Yeshiva of Ocean': 493594, 'Yeshiva of the Telshe Alumni': 431983, 'Yeshiva Ohr Elchonon Chabad West Coast Talmudical Seminary': 126076, 'Yeshiva Ohr Naftoli': 490504, 'Yeshiva Shaar Ephraim': 490276, 'Yeshiva Shaar Hatorah': 197692, 'Yeshiva Shaarei Torah of Rockland': 441609, 'Yeshiva Sholom Shachna': 486026, 'Yeshiva Toras Chaim': 451398, 'Yeshiva University': 197708, 'Yeshiva Yesoda Hatorah Vetz Chaim': 494737, 'Yeshiva Yesodei Hatorah': 481438, 'Yeshiva Zichron Aryeh': 487746, 'Yeshivah Gedolah Rabbinical College': 363712, "Yeshivas Be'er Yitzchok": 451370, 'Yeshivas Emek Hatorah': 491765, "Yeshivas Maharit D'Satmar": 488101, 'Yeshivas Novominsk': 405058, 'Yeshivat Hechal Shemuel': 493664, 'Yeshivath Beth Moshe': 217040, 'Yeshivath Viznitz': 197735, 'Yeshivath Zichron Moshe': 197744, 'Yo San University of Traditional Chinese Medicine': 401250, 'York College': 181853, 'York College of Pennsylvania': 217059, 'York County Community College': 420440, 'York County School of Technology-Adult & Continuing Education': 418409, 'York Technical College': 218991, 'Yosemite Community College District Office': 126100, 'Young Americans College of the Performing Arts': 493619, 'Young Harris College': 141361, 'Youngstown State University': 206695, 'YTI Career Institute-Altoona': 375939, 'YTI Career Institute-York': 217077, 'Yuba College': 126119, 'Yukon Beauty College Inc': 413820, 'Z Hair Academy': 451237, 'Zane State College': 204255, 'Zaytuna College': 458575, 'ZMS': 486248}}
    master = pd.DataFrame.from_dict(dictionary).reset_index()
    master.columns = ('institution_ipeds', 'unitid')
    master = master[['unitid', 'institution_ipeds']]
    var_name = dta.columns[0]
    user_list = list(dta.iloc[:, 0])
    ipeds_list = list(master.institution_ipeds)

    new = pd.DataFrame()
    new.append(dta)

    for x in range(0, len(user_list)):
        new[x] = user_list[x]

    new['institution'] = ipeds_list
    user_list.append('institution')
    new.columns = user_list

    user_list = user_list[:-1]

    max_cosine = []
    i = 0
    for x in user_list:
        cosine_list = []
        user_inst = x
        for z in ipeds_list:
            ipeds_inst = z
            cosine_list.append(cosine_similarity_ngrams(user_inst, ipeds_inst))
        new[user_inst] = cosine_list
        max_cosine.append(max(cosine_list))
        i = i + 1

    ipeds_names = []
    for x in user_list:
        if np.argmax(new[x]) < len(ipeds_list):
            ipeds_names.append(ipeds_list[np.argmax(new[x])])
        else:
            ipeds_names.append("No Match")

    dta['institution_ipeds'] = ipeds_names
    dta['Similarity'] = np.where(dta['institution_ipeds'] != "No Match", max_cosine, 0.0)

    dta = dta.merge(master, on = 'institution_ipeds', how = "left")

    no_match = dta[round(dta['Similarity'],2) != 1]

    matches = pd.DataFrame()
    no_match_list = no_match[var_name]
    if len(no_match_list) >= 1:
        for x in no_match_list:
            cosine_list = []
            user_inst = x
            for z in ipeds_list:
                ipeds_inst = z
                cosine_list.append(cosine_similarity_ngrams(user_inst, ipeds_inst))
            new[user_inst] = cosine_list
            i = i + 1
            no_match_df = pd.DataFrame()
            no_match_df['institution'] = no_match[var_name]
            i = 1
            top_five = np.argpartition(cosine_list, -5)[-5:]
            inst_list = []
            cos_list = []
            unitid_list = []
            another = []
            
            for x in top_five:
                inst = ipeds_list[x]
                cos = cosine_list[x]
                unitid = list(master[master['institution_ipeds'] == inst].unitid)[0]
                another.append([inst, cos, unitid])
                i = i + 1

            inst_df = pd.DataFrame(another).sort_values(by = [1], ascending = False)
            inst_df['Institution'] = user_inst
            inst_df['match'] = inst_df[1].rank(ascending = False, method = "dense")
            inst_df.columns = ['Top 5', 'similarity', 'unitid', 'institution', 'match']
            matches = matches.append(inst_df)
 
    if matches.shape[0] != 0:
        matches = matches.groupby(['institution', "match", "Top 5"]).mean()  
    else:
        matches = pd.DataFrame()
        
    dta['match'] = round(dta['Similarity'] * 100, 4)
    dta = dta.drop(columns = 'Similarity')

    return dta, matches